SdlDynamicLibraryService class

Constructors

SdlDynamicLibraryService()
factory

Properties

entries ↔ Map<String, String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(String key) → DynamicLibrary
set(String key, String filename) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited