sdl3/generated/lib_sdl_dialog library

Functions

sdlShowOpenFileDialog(Pointer<NativeFunction<SdlDialogFileCallback>> callback, Pointer<NativeType> userdata, Pointer<SdlWindow> window, Pointer<SdlDialogFileFilter> filters, int nfilters, String? defaultLocation, bool allowMany) → void
Displays a dialog that lets the user select a file on their filesystem.
sdlShowOpenFolderDialog(Pointer<NativeFunction<SdlDialogFileCallback>> callback, Pointer<NativeType> userdata, Pointer<SdlWindow> window, String? defaultLocation, bool allowMany) → void
Displays a dialog that lets the user select a folder on their filesystem.
sdlShowSaveFileDialog(Pointer<NativeFunction<SdlDialogFileCallback>> callback, Pointer<NativeType> userdata, Pointer<SdlWindow> window, Pointer<SdlDialogFileFilter> filters, int nfilters, String? defaultLocation) → void
Displays a dialog that lets the user choose a new or existing file on their filesystem.