sdlWaitEvent function

bool sdlWaitEvent(
  1. Pointer<SdlEvent> event
)

Wait indefinitely for the next available event.

If event is not NULL, the next event is removed from the queue and stored in the SDL_Event structure pointed to by event.

As this function may implicitly call SDL_PumpEvents(), you can only call this function in the thread that initialized the video subsystem.

\param event the SDL_Event structure to be filled in with the next event from the queue, or NULL. \returns true on success or false if there was an error while waiting for events; call SDL_GetError() for more information.

\threadsafety This should only be run in the thread that initialized the video subsystem, and for extra safety, you should consider only doing those things on the main thread in any case.

\since This function is available since SDL 3.1.3.

\sa SDL_PollEvent \sa SDL_PushEvent \sa SDL_WaitEventTimeout

extern SDL_DECLSPEC bool SDLCALL SDL_WaitEvent(SDL_Event *event)

Implementation

bool sdlWaitEvent(Pointer<SdlEvent> event) {
  final sdlWaitEventLookupFunction = libSdl3.lookupFunction<
      Uint8 Function(Pointer<SdlEvent> event),
      int Function(Pointer<SdlEvent> event)>('SDL_WaitEvent');
  return sdlWaitEventLookupFunction(event) == 1;
}