sdlAcquireGpuSwapchainTexture function

bool sdlAcquireGpuSwapchainTexture(
  1. Pointer<SdlGpuCommandBuffer> commandBuffer,
  2. Pointer<SdlWindow> window,
  3. Pointer<Pointer<SdlGpuTexture>> swapchainTexture,
  4. Pointer<Uint32> swapchainTextureWidth,
  5. Pointer<Uint32> swapchainTextureHeight,
)

Acquire a texture to use in presentation.

When a swapchain texture is acquired on a command buffer, it will automatically be submitted for presentation when the command buffer is submitted. The swapchain texture should only be referenced by the command buffer used to acquire it. The swapchain texture handle can be filled in with NULL under certain conditions. This is not necessarily an error. If this function returns false then there is an error.

The swapchain texture is managed by the implementation and must not be freed by the user. You MUST NOT call this function from any thread other than the one that created the window.

When using SDL_GPU_PRESENTMODE_VSYNC, this function will block if too many frames are in flight. Otherwise, this function will fill the swapchain texture handle with NULL if too many frames are in flight. The best practice is to call SDL_CancelGPUCommandBuffer if the swapchain texture handle is NULL to avoid enqueuing needless work on the GPU.

\param command_buffer a command buffer. \param window a window that has been claimed. \param swapchain_texture a pointer filled in with a swapchain texture handle. \param swapchain_texture_width a pointer filled in with the swapchain texture width, may be NULL. \param swapchain_texture_height a pointer filled in with the swapchain texture height, may be NULL. \returns true on success, false on error; call SDL_GetError() for more information.

\since This function is available since SDL 3.1.3.

\sa SDL_GPUPresentMode \sa SDL_ClaimWindowForGPUDevice \sa SDL_SubmitGPUCommandBuffer \sa SDL_SubmitGPUCommandBufferAndAcquireFence \sa SDL_CancelGPUCommandBuffer \sa SDL_GetWindowSizeInPixels

extern SDL_DECLSPEC bool SDLCALL SDL_AcquireGPUSwapchainTexture( SDL_GPUCommandBuffer *command_buffer, SDL_Window *window, SDL_GPUTexture **swapchain_texture, Uint32 *swapchain_texture_width, Uint32 *swapchain_texture_height)

Implementation

bool sdlAcquireGpuSwapchainTexture(
    Pointer<SdlGpuCommandBuffer> commandBuffer,
    Pointer<SdlWindow> window,
    Pointer<Pointer<SdlGpuTexture>> swapchainTexture,
    Pointer<Uint32> swapchainTextureWidth,
    Pointer<Uint32> swapchainTextureHeight) {
  final sdlAcquireGpuSwapchainTextureLookupFunction = libSdl3.lookupFunction<
          Uint8 Function(
              Pointer<SdlGpuCommandBuffer> commandBuffer,
              Pointer<SdlWindow> window,
              Pointer<Pointer<SdlGpuTexture>> swapchainTexture,
              Pointer<Uint32> swapchainTextureWidth,
              Pointer<Uint32> swapchainTextureHeight),
          int Function(
              Pointer<SdlGpuCommandBuffer> commandBuffer,
              Pointer<SdlWindow> window,
              Pointer<Pointer<SdlGpuTexture>> swapchainTexture,
              Pointer<Uint32> swapchainTextureWidth,
              Pointer<Uint32> swapchainTextureHeight)>(
      'SDL_AcquireGPUSwapchainTexture');
  return sdlAcquireGpuSwapchainTextureLookupFunction(commandBuffer, window,
          swapchainTexture, swapchainTextureWidth, swapchainTextureHeight) ==
      1;
}