sdl3/generated/lib_sdl_init library

Functions

sdlGetAppMetadataProperty(String? name) String?
Get metadata about your app.
sdlInit(int flags) bool
Initialize the SDL library.
sdlInitSubSystem(int flags) bool
Compatibility function to initialize the SDL library.
sdlQuit() → void
Clean up all initialized subsystems.
sdlQuitSubSystem(int flags) → void
Shut down specific SDL subsystems.
sdlSetAppMetadata(String? appname, String? appversion, String? appidentifier) bool
Specify basic metadata about your app.
sdlSetAppMetadataProperty(String? name, String? value) bool
Specify metadata about your app through a set of properties.
sdlWasInit(int flags) int
Get a mask of the specified subsystems which are currently initialized.