sdlTextInputActive function

bool sdlTextInputActive(
  1. Pointer<SdlWindow> window
)

Check whether or not Unicode text input events are enabled for a window.

\param window the window to check. \returns true if text input events are enabled else false.

\since This function is available since SDL 3.1.3.

\sa SDL_StartTextInput

extern SDL_DECLSPEC bool SDLCALL SDL_TextInputActive(SDL_Window *window)

Implementation

bool sdlTextInputActive(Pointer<SdlWindow> window) {
  final sdlTextInputActiveLookupFunction = libSdl3.lookupFunction<
      Uint8 Function(Pointer<SdlWindow> window),
      int Function(Pointer<SdlWindow> window)>('SDL_TextInputActive');
  return sdlTextInputActiveLookupFunction(window) == 1;
}