sdlGetCursor function
Get the active cursor.
This function returns a pointer to the current cursor which is owned by the library. It is not necessary to free the cursor with SDL_DestroyCursor().
\returns the active cursor or NULL if there is no mouse.
\since This function is available since SDL 3.1.3.
\sa SDL_SetCursor
extern SDL_DECLSPEC SDL_Cursor * SDLCALL SDL_GetCursor(void)
Implementation
Pointer<SdlCursor> sdlGetCursor() {
final sdlGetCursorLookupFunction = libSdl3.lookupFunction<
Pointer<SdlCursor> Function(),
Pointer<SdlCursor> Function()>('SDL_GetCursor');
return sdlGetCursorLookupFunction();
}