sdlDestroyTexture function
Destroy the specified texture.
Passing NULL or an otherwise invalid texture will set the SDL error message to "Invalid texture".
\param texture the texture to destroy.
\threadsafety You may only call this function from the main thread.
\since This function is available since SDL 3.1.3.
\sa SDL_CreateTexture \sa SDL_CreateTextureFromSurface
extern SDL_DECLSPEC void SDLCALL SDL_DestroyTexture(SDL_Texture *texture)
Implementation
void sdlDestroyTexture(Pointer<SdlTexture> texture) {
final sdlDestroyTextureLookupFunction = libSdl3.lookupFunction<
Void Function(Pointer<SdlTexture> texture),
void Function(Pointer<SdlTexture> texture)>('SDL_DestroyTexture');
return sdlDestroyTextureLookupFunction(texture);
}