sdlRestoreWindow function

bool sdlRestoreWindow(
  1. Pointer<SdlWindow> window
)

Request that the size and position of a minimized or maximized window be restored.

On some windowing systems this request is asynchronous and the new window state may not have have been applied immediately upon the return of this function. If an immediate change is required, call SDL_SyncWindow() to block until the changes have taken effect.

When the window state changes, an SDL_EVENT_WINDOW_RESTORED event will be emitted. Note that, as this is just a request, the windowing system can deny the state change.

\param window the window to restore. \returns true on success or false on failure; call SDL_GetError() for more information.

\since This function is available since SDL 3.1.3.

\sa SDL_MaximizeWindow \sa SDL_MinimizeWindow \sa SDL_SyncWindow

extern SDL_DECLSPEC bool SDLCALL SDL_RestoreWindow(SDL_Window *window)

Implementation

bool sdlRestoreWindow(Pointer<SdlWindow> window) {
  final sdlRestoreWindowLookupFunction = libSdl3.lookupFunction<
      Uint8 Function(Pointer<SdlWindow> window),
      int Function(Pointer<SdlWindow> window)>('SDL_RestoreWindow');
  return sdlRestoreWindowLookupFunction(window) == 1;
}