SdlAsyncIoPointerEx extension

on

Methods

close(Pointer<SdlAsyncIoQueue> queue, Pointer<NativeType> userdata, {bool flush = false}) bool asyncio

Available on Pointer<SdlAsyncIo>, provided by the SdlAsyncIoPointerEx extension

Close and free any allocated resources for an async I/O object.
getSize() int asyncio

Available on Pointer<SdlAsyncIo>, provided by the SdlAsyncIoPointerEx extension

Use this function to get the size of the data stream in an SDL_AsyncIO.
read(Pointer<NativeType> ptr, int offset, int size, Pointer<SdlAsyncIoQueue> queue, Pointer<NativeType> userdata) bool asyncio

Available on Pointer<SdlAsyncIo>, provided by the SdlAsyncIoPointerEx extension

Start an async read.
write(Pointer<NativeType> ptr, int offset, int size, Pointer<SdlAsyncIoQueue> queue, Pointer<NativeType> userdata) bool asyncio

Available on Pointer<SdlAsyncIo>, provided by the SdlAsyncIoPointerEx extension

Start an async write.