create static method

Create a task queue for tracking multiple I/O operations.

Async I/O operations are assigned to a queue when started. The queue can be checked for completed tasks thereafter.

\returns a new task queue object or NULL if there was an error; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

\sa SDL_DestroyAsyncIOQueue \sa SDL_GetAsyncIOResult \sa SDL_WaitAsyncIOResult

extern SDL_DECLSPEC SDL_AsyncIOQueue * SDLCALL SDL_CreateAsyncIOQueue(void)

Implementation

static Pointer<SdlAsyncIoQueue> create() => sdlCreateAsyncIoQueue();