SdlAsyncIoQueuePointerEx extension

on

Methods

destroy() → void asyncio

Available on Pointer<SdlAsyncIoQueue>, provided by the SdlAsyncIoQueuePointerEx extension

Destroy a previously-created async I/O task queue.
getResult(SdlxAsyncIoOutcome outcome) bool asyncio

Available on Pointer<SdlAsyncIoQueue>, provided by the SdlAsyncIoQueuePointerEx extension

Query an async I/O task queue for completed tasks.
loadFile(String file, Pointer<NativeType> userdata) bool asyncio

Available on Pointer<SdlAsyncIoQueue>, provided by the SdlAsyncIoQueuePointerEx extension

Load all the data from a file path, asynchronously.
signal() → void asyncio

Available on Pointer<SdlAsyncIoQueue>, provided by the SdlAsyncIoQueuePointerEx extension

Wake up any threads that are blocking in SDL_WaitAsyncIOResult().
waitResult(SdlxAsyncIoOutcome outcome, int timeoutMS) bool asyncio

Available on Pointer<SdlAsyncIoQueue>, provided by the SdlAsyncIoQueuePointerEx extension

Block until an async I/O task queue has a completed task.