create static method

Create a new audio stream.

Note that src_spec or dst_spec may be NULL, but any attempts to put or get data from an audio stream will fail until it has valid specs assigned to both ends of the stream. Specs can be assigned later through SDL_SetAudioStreamFormat(), or binding the stream to an audio device (which will set the format of only the input or output, depending on what kind of device the stream was bound to).

\param src_spec the format details of the input audio. May be NULL. \param dst_spec the format details of the output audio. May be NULL. \returns a new audio stream on success or NULL on failure; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

\sa SDL_PutAudioStreamData \sa SDL_GetAudioStreamData \sa SDL_GetAudioStreamAvailable \sa SDL_FlushAudioStream \sa SDL_ClearAudioStream \sa SDL_SetAudioStreamFormat \sa SDL_DestroyAudioStream

extern SDL_DECLSPEC SDL_AudioStream * SDLCALL SDL_CreateAudioStream(const SDL_AudioSpec *src_spec, const SDL_AudioSpec *dst_spec)

Implementation

static Pointer<SdlAudioStream> create(
  Pointer<SdlAudioSpec> srcSpec,
  Pointer<SdlAudioSpec> dstSpec,
) => sdlCreateAudioStream(srcSpec, dstSpec);