SdlCameraPointerEx extension

on

Methods

acquireFrame() → ({Pointer<SdlSurface> surface, int timestampNs})? camera

Available on Pointer<SdlCamera>, provided by the SdlCameraPointerEx extension

Acquire a frame.
close() → void camera

Available on Pointer<SdlCamera>, provided by the SdlCameraPointerEx extension

Use this function to shut down camera processing and close the camera device.
getFormat(SdlxCameraSpec spec) bool camera

Available on Pointer<SdlCamera>, provided by the SdlCameraPointerEx extension

Get the spec that a camera is using when generating images.
getId() int camera

Available on Pointer<SdlCamera>, provided by the SdlCameraPointerEx extension

Get the instance ID of an opened camera.
getPermissionState() int camera

Available on Pointer<SdlCamera>, provided by the SdlCameraPointerEx extension

Query if camera access has been approved by the user.
getProperties(Pointer<SdlCamera> camera) int camera

Available on Pointer<SdlCamera>, provided by the SdlCameraPointerEx extension

Get the properties associated with an opened camera.
releaseFrame(Pointer<SdlSurface> frame) → void camera

Available on Pointer<SdlCamera>, provided by the SdlCameraPointerEx extension

Release a frame of video acquired from a camera.