close method
void
close()
Use this function to shut down camera processing and close the camera device.
\param camera opened camera device.
\threadsafety It is safe to call this function from any thread, but no
thread may reference device once this function is called.
\since This function is available since SDL 3.2.0.
\sa SDL_OpenCamera
extern SDL_DECLSPEC void SDLCALL SDL_CloseCamera(SDL_Camera *camera)
Implementation
void close() => sdlCloseCamera(this);