getId method

int getId()

Get the instance ID of an opened camera.

\param camera an SDL_Camera to query. \returns the instance ID of the specified camera on success or 0 on failure; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

\sa SDL_OpenCamera

extern SDL_DECLSPEC SDL_CameraID SDLCALL SDL_GetCameraID(SDL_Camera *camera)

Implementation

int getId() => sdlGetCameraId(this);