SdlEnvironmentPointerEx extension
Methods
-
destroy(
) → void stdinc -
Available on Pointer<
Destroy a set of environment variables.SdlEnvironment> , provided by the SdlEnvironmentPointerEx extension -
getVariable(
String name) → String? stdinc -
Available on Pointer<
Get the value of a variable in the environment.SdlEnvironment> , provided by the SdlEnvironmentPointerEx extension -
getVariables(
) → List< stdincString> -
Available on Pointer<
Get all variables in the environment.SdlEnvironment> , provided by the SdlEnvironmentPointerEx extension -
setVariable(
String name, String value, bool overwrite) → bool stdinc -
Available on Pointer<
Set the value of a variable in the environment.SdlEnvironment> , provided by the SdlEnvironmentPointerEx extension -
unsetVariable(
String name) → bool stdinc -
Available on Pointer<
Clear a variable from the environment.SdlEnvironment> , provided by the SdlEnvironmentPointerEx extension