destroy method

void destroy()

Destroy a set of environment variables.

\param env the environment to destroy.

\threadsafety It is safe to call this function from any thread, as long as the environment is no longer in use.

\since This function is available since SDL 3.2.0.

\sa SDL_CreateEnvironment

extern SDL_DECLSPEC void SDLCALL SDL_DestroyEnvironment(SDL_Environment *env)

Implementation

void destroy() => sdlDestroyEnvironment(this);