unsetVariable method

bool unsetVariable(
  1. String name
)

Clear a variable from the environment.

\param env the environment to modify. \param name the name of the variable to unset. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

\sa SDL_GetEnvironment \sa SDL_CreateEnvironment \sa SDL_GetEnvironmentVariable \sa SDL_GetEnvironmentVariables \sa SDL_SetEnvironmentVariable \sa SDL_UnsetEnvironmentVariable

extern SDL_DECLSPEC bool SDLCALL SDL_UnsetEnvironmentVariable(SDL_Environment *env, const char *name)

Implementation

bool unsetVariable(String name) => sdlUnsetEnvironmentVariable(this, name);