SdlEventEx extension

on

Static Methods

flush(int type) → void events

Available on SdlEvent, provided by the SdlEventEx extension

Clear events of a specific type from the event queue.
flushs(int minType, int maxType) → void events

Available on SdlEvent, provided by the SdlEventEx extension

Clear events of a range of types from the event queue.
has(int minType, int maxType) → bool events

Available on SdlEvent, provided by the SdlEventEx extension

Check for the existence of certain event types in the event queue.
have(int type) → bool events

Available on SdlEvent, provided by the SdlEventEx extension

Check for the existence of a certain event type in the event queue.
pumps() → void events

Available on SdlEvent, provided by the SdlEventEx extension

Pump the event loop, gathering events from the input devices.