SdlGamepadEx extension

on

Static Methods

addMapping(String? mappingString) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Add support for gamepads that SDL is unaware of or change the binding of an existing gamepad.
addMappingFromFile(String? file) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Load a set of gamepad mappings from a file.
addMappingsFromIo(Pointer<SdlIoStream> src, bool freerw) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Load a set of gamepad mappings from an SDL_IOStream.
eventsEnabled() bool gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Query the state of gamepad event processing.
getAxisFromString(String? str) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Convert a string into SDL_GamepadAxis enum.
getButtonFromString(String? str) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Convert a string into an SDL_GamepadButton enum.
getButtonLabelForType(int type, int button) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the label of a button on a gamepad.
getFromId(int instanceId) Pointer<SdlGamepad> gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the SDL_Gamepad associated with a joystick instance ID, if it has been opened.
getFromPlayerIndex(int playerIndex) Pointer<SdlGamepad> gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the SDL_Gamepad associated with a player index.
getGuidForId(int instanceId) SdlGuid gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the implementation-dependent GUID of a gamepad.
getMappingForGuid(SdlGuid guid) Pointer<Int8> gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the gamepad mapping string for a given GUID.
getMappingForId(int instanceId) Pointer<Int8> gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the mapping of a gamepad.
getMappings(Pointer<Int32> count) Pointer<Pointer<Int8>> gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the current gamepad mappings.
getNameForId(int instanceId) String? gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the implementation dependent name of a gamepad.
getPathForId(int instanceId) String? gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the implementation dependent path of a gamepad.
getPlayerIndexForId(int instanceId) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the player index of a gamepad.
getProductForId(int instanceId) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the USB product ID of a gamepad, if available.
getProductVersionForId(int instanceId) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the product version of a gamepad, if available.
getRealTypeForId(int instanceId) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the type of a gamepad, ignoring any mapping override.
gets(Pointer<Int32> count) Pointer<Uint32> gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get a list of currently connected gamepads.
getStringForAxis(int axis) String? gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Convert from an SDL_GamepadAxis enum to a string.
getStringForButton(int button) String? gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Convert from an SDL_GamepadButton enum to a string.
getStringForType(int type) String? gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Convert from an SDL_GamepadType enum to a string.
getTypeForId(int instanceId) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the type of a gamepad.
getTypeFromString(String? str) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Convert a string into SDL_GamepadType enum.
getVendorForId(int instanceId) int gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Get the USB vendor ID of a gamepad, if available.
isGamepad(int instanceId) bool gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Check if the given joystick is supported by the gamepad interface.
open(int instanceId) Pointer<SdlGamepad> gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Open a gamepad for use.
reloadMappings() bool gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Reinitialize the SDL mapping database to its initial state.
setEventsEnabled(bool enabled) → void gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Set the state of gamepad event processing.
setMapping(int instanceId, String? mapping) bool gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Set the current mapping of a joystick or gamepad.
updates() → void gamepad

Available on SdlGamepad, provided by the SdlGamepadEx extension

Manually pump gamepad updates if not using the loop.