SdlGpuCommandBufferPointerEx extension

on

Methods

acquireSwapchainTexture(Pointer<SdlWindow> window) → ({int height, Pointer<SdlGpuTexture> texture, int width})? gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Acquire a texture to use in presentation.
beginComputePass({List<SdlxGpuStorageTextureReadWriteBinding>? textures, List<SdlxGpuStorageBufferReadWriteBinding>? buffers}) Pointer<SdlGpuComputePass> gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Begins a compute pass on a command buffer.
beginCopyPass() Pointer<SdlGpuCopyPass> gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Begins a copy pass on a command buffer.
beginRenderPass(List<SdlxGpuColorTargetInfo> colorTargetInfo, {SdlxGpuDepthStencilTargetInfo? depthStencilTargetInfo}) Pointer<SdlGpuRenderPass> gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Begins a render pass on a command buffer.
blitTexture(SdlxGpuBlitInfo info) → void gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Blits from a source texture region to a destination texture region.
cancel() bool gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Cancels a command buffer.
generateMipmapsForTexture(Pointer<SdlGpuTexture> texture) → void gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Generates mipmaps for the given texture.
insertDebugLabel(String text) → void gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Inserts an arbitrary string label into the command buffer callstream.
popDebugGroup() → void gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Ends the most-recently pushed debug group.
pushComputeUniformData(int slotIndex, Pointer<Void> data, int length) → void gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Pushes data to a uniform slot on the command buffer.
pushDebugGroup(String name) → void gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Begins a debug group with an arbitrary name.
pushFragmentUniformData(int slotIndex, Pointer<Void> data, int length) → void gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Pushes data to a fragment uniform slot on the command buffer.
pushVertexUniformData(int slotIndex, Pointer<Void> data, int length) → void gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Pushes data to a vertex uniform slot on the command buffer.
submit() bool gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Submits a command buffer so its commands can be processed on the GPU.
submitAndAcquireFence() Pointer<SdlGpuFence> gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Submits a command buffer so its commands can be processed on the GPU, and acquires a fence associated with the command buffer.
waitAndAcquireSwapchainTexture(Pointer<SdlWindow> window) → ({int height, Pointer<SdlGpuTexture> texture, int width})? gpu

Available on Pointer<SdlGpuCommandBuffer>, provided by the SdlGpuCommandBufferPointerEx extension

Blocks the thread until a swapchain texture is available to be acquired, and then acquires it.