beginCopyPass method

Pointer<SdlGpuCopyPass> beginCopyPass()

Begins a copy pass on a command buffer.

All operations related to copying to or from buffers or textures take place inside a copy pass. You must not begin another copy pass, or a render pass or compute pass before ending the copy pass.

\param command_buffer a command buffer. \returns a copy pass handle.

\since This function is available since SDL 3.2.0.

\sa SDL_EndGPUCopyPass

extern SDL_DECLSPEC SDL_GPUCopyPass * SDLCALL SDL_BeginGPUCopyPass( SDL_GPUCommandBuffer *command_buffer)

Implementation

Pointer<SdlGpuCopyPass> beginCopyPass() => sdlBeginGpuCopyPass(this);