insertDebugLabel method

void insertDebugLabel(
  1. String text
)

Inserts an arbitrary string label into the command buffer callstream.

Useful for debugging.

On Direct3D 12, using SDL_InsertGPUDebugLabel requires WinPixEventRuntime.dll to be in your PATH or in the same directory as your executable. See here for instructions on how to obtain it.

\param command_buffer a command buffer. \param text a UTF-8 string constant to insert as the label.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC void SDLCALL SDL_InsertGPUDebugLabel( SDL_GPUCommandBuffer *command_buffer, const char *text)

Implementation

void insertDebugLabel(String text) => sdlInsertGpuDebugLabel(this, text);