popDebugGroup method

void popDebugGroup()

Ends the most-recently pushed debug group.

On Direct3D 12, using SDL_PopGPUDebugGroup requires WinPixEventRuntime.dll to be in your PATH or in the same directory as your executable. See here for instructions on how to obtain it.

\param command_buffer a command buffer.

\since This function is available since SDL 3.2.0.

\sa SDL_PushGPUDebugGroup

extern SDL_DECLSPEC void SDLCALL SDL_PopGPUDebugGroup( SDL_GPUCommandBuffer *command_buffer)

Implementation

void popDebugGroup() => sdlPopGpuDebugGroup(this);