SdlGpuComputePassPointerEx extension

on

Methods

bindPipeline(Pointer<SdlGpuComputePipeline> computePipeline) → void gpu

Available on Pointer<SdlGpuComputePass>, provided by the SdlGpuComputePassPointerEx extension

Binds a compute pipeline on a command buffer for use in compute dispatch.
bindSamplers(List<SdlxGpuTextureSamplerBinding> bindings, {int firstSlot = 0}) → void gpu

Available on Pointer<SdlGpuComputePass>, provided by the SdlGpuComputePassPointerEx extension

Binds texture-sampler pairs for use on the compute shader.
bindStorageBuffers(List<Pointer<SdlGpuBuffer>> storageBuffers, {int firstSlot = 0}) → void gpu

Available on Pointer<SdlGpuComputePass>, provided by the SdlGpuComputePassPointerEx extension

Binds storage buffers as readonly for use on the compute pipeline.
bindStorageTextures(List<Pointer<SdlGpuTexture>> storageTextures, {int firstSlot = 0}) → void gpu

Available on Pointer<SdlGpuComputePass>, provided by the SdlGpuComputePassPointerEx extension

Binds storage textures as readonly for use on the compute pipeline.
dispatch(int groupcountX, int groupcountY, int groupcountZ) → void gpu

Available on Pointer<SdlGpuComputePass>, provided by the SdlGpuComputePassPointerEx extension

Dispatches compute work.
dispatchIndirect(Pointer<SdlGpuBuffer> buffer, int offset) → void gpu

Available on Pointer<SdlGpuComputePass>, provided by the SdlGpuComputePassPointerEx extension

Dispatches compute work with parameters set from a buffer.
end() → void gpu

Available on Pointer<SdlGpuComputePass>, provided by the SdlGpuComputePassPointerEx extension

Ends the current compute pass.