SdlGpuCopyPassPointerEx extension

on

Methods

copyBufferToBuffer(SdlxGpuBufferLocation source, SdlxGpuBufferLocation destination, int size, {bool cycle = false}) → void gpu

Available on Pointer<SdlGpuCopyPass>, provided by the SdlGpuCopyPassPointerEx extension

Performs a buffer-to-buffer copy.
copyTextureToTexture(SdlxGpuTextureLocation source, SdlxGpuTextureLocation destination, int w, int h, int d, {bool cycle = false}) → void gpu

Available on Pointer<SdlGpuCopyPass>, provided by the SdlGpuCopyPassPointerEx extension

Performs a texture-to-texture copy.
downloadFromBuffer(SdlxGpuBufferRegion source, SdlxGpuTransferBufferLocation destination) → void gpu

Available on Pointer<SdlGpuCopyPass>, provided by the SdlGpuCopyPassPointerEx extension

Copies data from a buffer to a transfer buffer on the GPU timeline.
downloadFromTexture(SdlxGpuTextureRegion source, SdlxGpuTextureTransferInfo destination) → void gpu

Available on Pointer<SdlGpuCopyPass>, provided by the SdlGpuCopyPassPointerEx extension

Copies data from a texture to a transfer buffer on the GPU timeline.
end() → void gpu

Available on Pointer<SdlGpuCopyPass>, provided by the SdlGpuCopyPassPointerEx extension

Ends the current copy pass.
uploadToBuffer(SdlxGpuTransferBufferLocation source, SdlxGpuBufferRegion destination, {bool cycle = false}) → void gpu

Available on Pointer<SdlGpuCopyPass>, provided by the SdlGpuCopyPassPointerEx extension

Uploads data from a transfer buffer to a buffer.
uploadToTexture(SdlxGpuTextureTransferInfo source, SdlxGpuTextureRegion destination, {bool cycle = false}) → void gpu

Available on Pointer<SdlGpuCopyPass>, provided by the SdlGpuCopyPassPointerEx extension

Uploads data from a transfer buffer to a texture.