SdlGpuDevicePointerEx extension

on

Methods

acquireCommandBuffer() Pointer<SdlGpuCommandBuffer> gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Acquire a command buffer.
claimWindowFor(Pointer<SdlWindow> window) bool gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Claims a window, creating a swapchain structure for it.
createBuffer(SdlxGpuBufferCreateInfo createinfo) Pointer<SdlGpuBuffer> gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Creates a buffer object to be used in graphics or compute workflows.
createComputePipeline(SdlxGpuComputePipelineCreateInfo createinfo) Pointer<SdlGpuComputePipeline> gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Creates a pipeline object to be used in a compute workflow.
createGraphicsPipeline(SdlxGpuGraphicsPipelineCreateInfo createinfo) Pointer<SdlGpuGraphicsPipeline> gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Creates a pipeline object to be used in a graphics workflow.
createSampler(SdlxGpuSamplerCreateInfo createinfo) Pointer<SdlGpuSampler> gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Creates a sampler object to be used when binding textures in a graphics workflow.
createShader(SdlxGpuShaderCreateInfo createinfo) Pointer<SdlGpuShader> gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Creates a shader to be used when creating a graphics pipeline.
createTexture(SdlxGpuTextureCreateInfo createinfo) Pointer<SdlGpuTexture> gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Creates a texture object to be used in graphics or compute workflows.
createTransferBuffer(SdlxGpuTransferBufferCreateInfo createinfo) Pointer<SdlGpuTransferBuffer> gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Creates a transfer buffer to be used when uploading to or downloading from graphics resources.
destroy() → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Destroys a GPU context previously returned by SDL_CreateGPUDevice.
gdkResume() → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Call this to resume GPU operation on Xbox after receiving the SDL_EVENT_WILL_ENTER_FOREGROUND event.
gdkSuspend() → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Call this to suspend GPU operation on Xbox after receiving the SDL_EVENT_DID_ENTER_BACKGROUND event.
getDriver() String? gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Returns the name of the backend used to create this GPU context.
getProperties() int gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Get the properties associated with a GPU device.
getShaderFormats() int gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Returns the supported shader formats for this GPU context.
getSwapchainTextureFormat(Pointer<SdlWindow> window) int gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Obtains the texture format of the swapchain for the given window.
mapTransferBuffer(Pointer<SdlGpuTransferBuffer> transferBuffer, {bool cycle = false}) Pointer<Void> gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Maps a transfer buffer into application address space.
queryFence(Pointer<SdlGpuFence> fence) bool gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Checks the status of a fence.
releaseBuffer(Pointer<SdlGpuBuffer> buffer) → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Frees the given buffer as soon as it is safe to do so.
releaseComputePipeline(Pointer<SdlGpuComputePipeline> computePipeline) → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Frees the given compute pipeline as soon as it is safe to do so.
releaseFence(Pointer<SdlGpuFence> fence) → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Releases a fence obtained from SDL_SubmitGPUCommandBufferAndAcquireFence.
releaseGraphicsPipeline(Pointer<SdlGpuGraphicsPipeline> graphicsPipeline) → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Frees the given graphics pipeline as soon as it is safe to do so.
releaseSampler(Pointer<SdlGpuSampler> sampler) → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Frees the given sampler as soon as it is safe to do so.
releaseShader(Pointer<SdlGpuShader> shader) → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Frees the given shader as soon as it is safe to do so.
releaseTexture(Pointer<SdlGpuTexture> texture) → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Frees the given texture as soon as it is safe to do so.
releaseTransferBuffer(Pointer<SdlGpuTransferBuffer> transferBuffer) → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Frees the given transfer buffer as soon as it is safe to do so.
releaseWindowFrom(Pointer<SdlWindow> window) → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Unclaims a window, destroying its swapchain structure.
setAllowedFramesInFlight(int allowedFramesInFlight) bool gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Configures the maximum allowed number of frames in flight.
setBufferName(Pointer<SdlGpuBuffer> buffer, String text) → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Sets an arbitrary string constant to label a buffer.
setSwapchainParameters(Pointer<SdlWindow> window, int swapchainComposition, int presentMode) bool gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Changes the swapchain parameters for the given claimed window.
setTextureName(Pointer<SdlGpuTexture> texture, String text) → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Sets an arbitrary string constant to label a texture.
textureSupportsFormat(int format, int type, int usage) bool gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Determines whether a texture format is supported for a given type and usage.
textureSupportsSampleCount(int format, int sampleCount) bool gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Determines if a sample count for a texture format is supported.
unmapTransferBuffer(Pointer<SdlGpuTransferBuffer> transferBuffer) → void gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Unmaps a previously mapped transfer buffer.
waitForFences(List<Pointer<SdlGpuFence>> fences, {bool waitAll = true}) bool gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Blocks the thread until the given fences are signaled.
waitForIdle() bool gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Blocks the thread until the GPU is completely idle.
waitForSwapchain(Pointer<SdlWindow> window) bool gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Blocks the thread until all presenting command buffers are finished executing.
windowSupportsPresentMode(Pointer<SdlWindow> window, int presentMode) bool gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Determines whether a presentation mode is supported by the window.
windowSupportsSwapchainComposition(Pointer<SdlWindow> window, int swapchainComposition) bool gpu

Available on Pointer<SdlGpuDevice>, provided by the SdlGpuDevicePointerEx extension

Determines whether a swapchain composition is supported by the window.