getSwapchainTextureFormat method

int getSwapchainTextureFormat(
  1. Pointer<SdlWindow> window
)

Obtains the texture format of the swapchain for the given window.

Note that this format can change if the swapchain parameters change.

\param device a GPU context. \param window an SDL_Window that has been claimed. \returns the texture format of the swapchain.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC SDL_GPUTextureFormat SDLCALL SDL_GetGPUSwapchainTextureFormat( SDL_GPUDevice *device, SDL_Window *window)

Implementation

int getSwapchainTextureFormat(Pointer<SdlWindow> window) =>
    sdlGetGpuSwapchainTextureFormat(this, window);