releaseSampler method
Frees the given sampler as soon as it is safe to do so.
You must not reference the sampler after calling this function.
It is safe to pass NULL for sampler, in that case this function is a
no-op.
\param device a GPU context. \param sampler a sampler to be destroyed.
\since This function is available since SDL 3.2.0.
extern SDL_DECLSPEC void SDLCALL SDL_ReleaseGPUSampler( SDL_GPUDevice *device, SDL_GPUSampler *sampler)
Implementation
void releaseSampler(Pointer<SdlGpuSampler> sampler) =>
sdlReleaseGpuSampler(this, sampler);