releaseTexture method
Frees the given texture as soon as it is safe to do so.
You must not reference the texture after calling this function.
It is safe to pass NULL for texture, in that case this function is a
no-op.
\param device a GPU context. \param texture a texture to be destroyed.
\since This function is available since SDL 3.2.0.
extern SDL_DECLSPEC void SDLCALL SDL_ReleaseGPUTexture( SDL_GPUDevice *device, SDL_GPUTexture *texture)
Implementation
void releaseTexture(Pointer<SdlGpuTexture> texture) =>
sdlReleaseGpuTexture(this, texture);