waitForFences method

bool waitForFences(
  1. List<Pointer<SdlGpuFence>> fences, {
  2. bool waitAll = true,
})

Blocks the thread until the given fences are signaled.

\param device a GPU context. \param wait_all if 0, wait for any fence to be signaled, if 1, wait for all fences to be signaled. \param fences an array of fences to wait on. \param num_fences the number of fences in the fences array. \returns true on success, false on failure; call SDL_GetError() for more information.

\since This function is available since SDL 3.2.0.

\sa SDL_SubmitGPUCommandBufferAndAcquireFence \sa SDL_WaitForGPUIdle

extern SDL_DECLSPEC bool SDLCALL SDL_WaitForGPUFences( SDL_GPUDevice *device, bool wait_all, SDL_GPUFence *const *fences, Uint32 num_fences)

Implementation

bool waitForFences(
  List<Pointer<SdlGpuFence>> fences, {
  bool waitAll = true,
}) => sdlxWaitForGpuFences(this, fences, waitAll: waitAll);