SdlGpuRenderPassPointerEx extension

on

Methods

bindFragmentSamplers(List<SdlxGpuTextureSamplerBinding> bindings, {int firstSlot = 0}) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Binds texture-sampler pairs for use on the fragment shader.
bindFragmentStorageBuffers(List<Pointer<SdlGpuBuffer>> storageBuffers, {int firstSlot = 0}) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Binds storage buffers for use on the fragment shader.
bindFragmentStorageTextures(List<Pointer<SdlGpuTexture>> storageTextures, {int firstSlot = 0}) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Binds storage textures for use on the fragment shader.
bindGraphicsPipeline(Pointer<SdlGpuGraphicsPipeline> graphicsPipeline) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Binds a graphics pipeline on a render pass to be used in rendering.
bindIndexBuffer(SdlxGpuBufferBinding binding, int indexElementSize) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Binds an index buffer on a command buffer for use with subsequent draw calls.
bindVertexBuffers(List<SdlxGpuBufferBinding> bindings, {int firstSlot = 0}) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Binds vertex buffers on a command buffer for use with subsequent draw calls.
bindVertexSamplers(List<SdlxGpuTextureSamplerBinding> bindings, {int firstSlot = 0}) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Binds texture-sampler pairs for use on the vertex shader.
bindVertexStorageBuffers(List<Pointer<SdlGpuBuffer>> storageBuffers, {int firstSlot = 0}) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Binds storage buffers for use on the vertex shader.
bindVertexStorageTextures(List<Pointer<SdlGpuTexture>> storageTextures, {int firstSlot = 0}) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Binds storage textures for use on the vertex shader.
drawIndexedPrimitives(int numIndices, int numInstances, int firstIndex, int vertexOffset, int firstInstance) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Draws data using bound graphics state with an index buffer and instancing enabled.
drawIndexedPrimitivesIndirect(Pointer<SdlGpuBuffer> buffer, int offset, int drawCount) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Draws data using bound graphics state with an index buffer enabled and with draw parameters set from a buffer.
drawPrimitives(int numVertices, int numInstances, int firstVertex, int firstInstance) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Draws data using bound graphics state.
drawPrimitivesIndirect(Pointer<SdlGpuBuffer> buffer, int offset, int drawCount) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Draws data using bound graphics state and with draw parameters set from a buffer.
end() → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Ends the given render pass.
setBlendConstants(SdlxFColor blendConstants) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Sets the current blend constants on a command buffer.
setScissor(SdlxRect scissor) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Sets the current scissor state on a command buffer.
setStencilReference(int reference) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Sets the current stencil reference value on a command buffer.
setViewport(SdlxGpuViewport viewport) → void gpu

Available on Pointer<SdlGpuRenderPass>, provided by the SdlGpuRenderPassPointerEx extension

Sets the current viewport state on a command buffer.