bindGraphicsPipeline method

void bindGraphicsPipeline(
  1. Pointer<SdlGpuGraphicsPipeline> graphicsPipeline
)

Binds a graphics pipeline on a render pass to be used in rendering.

A graphics pipeline must be bound before making any draw calls.

\param render_pass a render pass handle. \param graphics_pipeline the graphics pipeline to bind.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC void SDLCALL SDL_BindGPUGraphicsPipeline( SDL_GPURenderPass *render_pass, SDL_GPUGraphicsPipeline *graphics_pipeline)

Implementation

void bindGraphicsPipeline(Pointer<SdlGpuGraphicsPipeline> graphicsPipeline) =>
    sdlBindGpuGraphicsPipeline(this, graphicsPipeline);