drawPrimitives method

void drawPrimitives(
  1. int numVertices,
  2. int numInstances,
  3. int firstVertex,
  4. int firstInstance,
)

Draws data using bound graphics state.

You must not call this function before binding a graphics pipeline.

Note that the first_vertex and first_instance parameters are NOT compatible with built-in vertex/instance ID variables in shaders (for example, SV_VertexID); GPU APIs and shader languages do not define these built-in variables consistently, so if your shader depends on them, the only way to keep behavior consistent and portable is to always pass 0 for the correlating parameter in the draw calls.

\param render_pass a render pass handle. \param num_vertices the number of vertices to draw. \param num_instances the number of instances that will be drawn. \param first_vertex the index of the first vertex to draw. \param first_instance the ID of the first instance to draw.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC void SDLCALL SDL_DrawGPUPrimitives( SDL_GPURenderPass *render_pass, Uint32 num_vertices, Uint32 num_instances, Uint32 first_vertex, Uint32 first_instance)

Implementation

void drawPrimitives(
  int numVertices,
  int numInstances,
  int firstVertex,
  int firstInstance,
) => sdlDrawGpuPrimitives(
  this,
  numVertices,
  numInstances,
  firstVertex,
  firstInstance,
);