SdlGpuRenderStateCreateInfo class final render

Inheritance
Implemented types
Available extensions

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
fragmentShader ↔ Pointer<SdlGpuShader>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numSamplerBindings ↔ int
getter/setter pair
numStorageBuffers ↔ int
getter/setter pair
numStorageTextures ↔ int
getter/setter pair
props ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplerBindings ↔ Pointer<SdlGpuTextureSamplerBinding>
getter/setter pair
storageBuffers ↔ Pointer<Pointer<SdlGpuBuffer>>
getter/setter pair
storageTextures ↔ Pointer<Pointer<SdlGpuTexture>>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited