SdlGpuTextureCreateInfo class final gpu

Inheritance
Implemented types
Available extensions

Constructors

SdlGpuTextureCreateInfo()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
format ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
layerCountOrDepth ↔ int
getter/setter pair
numLevels ↔ int
getter/setter pair
props ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleCount ↔ int
getter/setter pair
type ↔ int
getter/setter pair
usage ↔ int
getter/setter pair
width ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited