SdlHapticCustom class final haptic

Inheritance
Implemented types
Available extensions

Constructors

SdlHapticCustom()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
attackLength ↔ int
getter/setter pair
attackLevel ↔ int
getter/setter pair
button ↔ int
getter/setter pair
channels ↔ int
getter/setter pair
data ↔ Pointer<Uint16>
getter/setter pair
delay ↔ int
getter/setter pair
direction ↔ SdlHapticDirection
getter/setter pair
fadeLength ↔ int
getter/setter pair
fadeLevel ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interval ↔ int
getter/setter pair
length ↔ int
getter/setter pair
period ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samples ↔ int
getter/setter pair
type ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited