SdlHapticEx extension
- on
Static Methods
-
getFromId(
int instanceId) → Pointer< hapticSdlHaptic> -
Available on SdlHaptic, provided by the SdlHapticEx extension
Get the SDL_Haptic associated with an instance ID, if it has been opened. -
getIds(
) → List< hapticint> -
Available on SdlHaptic, provided by the SdlHapticEx extension
Get a list of currently connected haptic devices. -
getNameForId(
int instanceId) → String? haptic -
Available on SdlHaptic, provided by the SdlHapticEx extension
Get the implementation dependent name of a haptic device. -
isMouse(
) → bool haptic -
Available on SdlHaptic, provided by the SdlHapticEx extension
Query whether or not the current mouse has haptic capabilities. -
open(
int instanceId) → Pointer< hapticSdlHaptic> -
Available on SdlHaptic, provided by the SdlHapticEx extension
Open a haptic device for use. -
openFromMouse(
) → Pointer< hapticSdlHaptic> -
Available on SdlHaptic, provided by the SdlHapticEx extension
Try to open a haptic device from the current mouse.