getNameForId static method

String? getNameForId(
  1. int instanceId
)

Get the implementation dependent name of a haptic device.

This can be called before any haptic devices are opened.

\param instance_id the haptic device instance ID. \returns the name of the selected haptic device. If no name can be found, this function returns NULL; call SDL_GetError() for more information.

\since This function is available since SDL 3.2.0.

\sa SDL_GetHapticName \sa SDL_OpenHaptic

extern SDL_DECLSPEC const char * SDLCALL SDL_GetHapticNameForID(SDL_HapticID instance_id)

Implementation

static String? getNameForId(int instanceId) =>
    sdlGetHapticNameForId(instanceId);