SdlHapticPointerEx extension
Methods
-
close(
) → void haptic -
Available on Pointer<
Close a haptic device previously opened with SDL_OpenHaptic().SdlHaptic> , provided by the SdlHapticPointerEx extension -
createEffect(
SdlxHapticEffect effect) → int haptic -
Available on Pointer<
Create a new haptic effect on a specified device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
destroyEffect(
int effect) → void haptic -
Available on Pointer<
Destroy a haptic effect on the device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
effectSupported(
SdlxHapticEffect effect) → bool haptic -
Available on Pointer<
Check to see if an effect is supported by a haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
getEffectStatus(
int effect) → bool haptic -
Available on Pointer<
Get the status of the current effect on the specified haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
getFeatures(
) → int haptic -
Available on Pointer<
Get the haptic device's supported features in bitwise manner.SdlHaptic> , provided by the SdlHapticPointerEx extension -
getId(
) → int haptic -
Available on Pointer<
Get the instance ID of an opened haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
getMaxEffects(
) → int haptic -
Available on Pointer<
Get the number of effects a haptic device can store.SdlHaptic> , provided by the SdlHapticPointerEx extension -
getMaxEffectsPlaying(
) → int haptic -
Available on Pointer<
Get the number of effects a haptic device can play at the same time.SdlHaptic> , provided by the SdlHapticPointerEx extension -
getName(
) → String? haptic -
Available on Pointer<
Get the implementation dependent name of a haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
getNumAxes(
) → int haptic -
Available on Pointer<
Get the number of haptic axes the device has.SdlHaptic> , provided by the SdlHapticPointerEx extension -
initRumble(
) → bool haptic -
Available on Pointer<
Initialize a haptic device for simple rumble playback.SdlHaptic> , provided by the SdlHapticPointerEx extension -
pause(
) → bool haptic -
Available on Pointer<
Pause a haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
playRumble(
double strength, int length) → bool haptic -
Available on Pointer<
Run a simple rumble effect on a haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
resume(
) → bool haptic -
Available on Pointer<
Resume a haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
rumbleSupported(
) → bool haptic -
Available on Pointer<
Check whether rumble is supported on a haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
runEffect(
int effect, int iterations) → bool haptic -
Available on Pointer<
Run the haptic effect on its associated haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
setAutocenter(
int autocenter) → bool haptic -
Available on Pointer<
Set the global autocenter of the device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
setGain(
int gain) → bool haptic -
Available on Pointer<
Set the global gain of the specified haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
stopEffect(
int effect) → bool haptic -
Available on Pointer<
Stop the haptic effect on its associated haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
stopEffects(
) → bool haptic -
Available on Pointer<
Stop all the currently playing effects on a haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
stopRumble(
) → bool haptic -
Available on Pointer<
Stop the simple rumble on a haptic device.SdlHaptic> , provided by the SdlHapticPointerEx extension -
updateEffect(
int effect, SdlxHapticEffect data) → bool haptic -
Available on Pointer<
Update the properties of an effect.SdlHaptic> , provided by the SdlHapticPointerEx extension