getMaxEffectsPlaying method

int getMaxEffectsPlaying()

Get the number of effects a haptic device can play at the same time.

This is not supported on all platforms, but will always return a value.

\param haptic the SDL_Haptic device to query maximum playing effects. \returns the number of effects the haptic device can play at the same time or -1 on failure; call SDL_GetError() for more information.

\since This function is available since SDL 3.2.0.

\sa SDL_GetMaxHapticEffects \sa SDL_GetHapticFeatures

extern SDL_DECLSPEC int SDLCALL SDL_GetMaxHapticEffectsPlaying(SDL_Haptic *haptic)

Implementation

int getMaxEffectsPlaying() => sdlGetMaxHapticEffectsPlaying(this);