getNumAxes method

int getNumAxes()

Get the number of haptic axes the device has.

The number of haptic axes might be useful if working with the SDL_HapticDirection effect.

\param haptic the SDL_Haptic device to query. \returns the number of axes on success or -1 on failure; call SDL_GetError() for more information.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC int SDLCALL SDL_GetNumHapticAxes(SDL_Haptic *haptic)

Implementation

int getNumAxes() => sdlGetNumHapticAxes(this);