setGain method
Set the global gain of the specified haptic device.
Device must support the SDL_HAPTIC_GAIN feature.
The user may specify the maximum gain by setting the environment variable
SDL_HAPTIC_GAIN_MAX which should be between 0 and 100. All calls to
SDL_SetHapticGain() will scale linearly using SDL_HAPTIC_GAIN_MAX as the
maximum.
\param haptic the SDL_Haptic device to set the gain on. \param gain value to set the gain to, should be between 0 and 100 (0 - 100). \returns true on success or false on failure; call SDL_GetError() for more information.
\since This function is available since SDL 3.2.0.
\sa SDL_GetHapticFeatures
extern SDL_DECLSPEC bool SDLCALL SDL_SetHapticGain(SDL_Haptic *haptic, int gain)
Implementation
bool setGain(int gain) => sdlSetHapticGain(this, gain);