setNonblocking method

int setNonblocking(
  1. int nonblock
)

Set the device handle to be non-blocking.

In non-blocking mode calls to SDL_hid_read() will return immediately with a value of 0 if there is no data to be read. In blocking mode, SDL_hid_read() will wait (block) until there is data to read before returning.

Nonblocking can be turned on and off at any time.

\param dev a device handle returned from SDL_hid_open(). \param nonblock enable or not the nonblocking reads - 1 to enable nonblocking - 0 to disable nonblocking. \returns 0 on success or a negative error code on failure; call SDL_GetError() for more information.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC int SDLCALL SDL_hid_set_nonblocking(SDL_hid_device *dev, int nonblock)

Implementation

int setNonblocking(int nonblock) => sdlHidSetNonblocking(this, nonblock);