getSize method

int getSize()

Use this function to get the size of the data stream in an SDL_IOStream.

\param context the SDL_IOStream to get the size of the data stream from. \returns the size of the data stream in the SDL_IOStream on success or a negative error code on failure; call SDL_GetError() for more information.

\threadsafety Do not use the same SDL_IOStream from two threads at once.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC Sint64 SDLCALL SDL_GetIOSize(SDL_IOStream *context)

Implementation

int getSize() => sdlGetIoSize(this);