SdlJoyButtonEvent class final events

Inheritance
Implemented types
Available extensions

Constructors

SdlJoyButtonEvent()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
button ↔ int
getter/setter pair
down ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
padding1 ↔ int
getter/setter pair
padding2 ↔ int
getter/setter pair
reserved ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ int
getter/setter pair
type ↔ int
getter/setter pair
which ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited