SdlJoystickPointerEx extension

on

Methods

close() → void joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Close a joystick previously opened with SDL_OpenJoystick().
connected() bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the status of a specified joystick.
getAxis(int axis) int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the current state of an axis control on a joystick.
getAxisInitialState(int axis) int? joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the initial state of an axis control on a joystick.
getBall(int ball) SdlxPoint? joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the ball axis change since the last poll.
getButton(int button) bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the current state of a button on a joystick.
getConnectionState() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the connection state of a joystick.
getFirmwareVersion() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the firmware version of an opened joystick, if available.
getGuid() SdlGuid joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the implementation-dependent GUID for the joystick.
getHat(int hat) int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the current state of a POV hat on a joystick.
getId() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the instance ID of an opened joystick.
getName() String? joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the implementation dependent name of a joystick.
getNumBalls() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the number of trackballs on a joystick.
getNumButtons() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the number of buttons on a joystick.
getNumHats() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the number of POV hats on a joystick.
getNumJAxes() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the number of general axis controls on a joystick.
getPath() String? joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the implementation dependent path of a joystick.
getPlayerIndex() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the player index of an opened joystick.
getPowerInfo() → ({int percent, int state}) joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the battery state of a joystick.
getProduct() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the USB product ID of an opened joystick, if available.
getProductVersion() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the product version of an opened joystick, if available.
getProperties() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the properties associated with a joystick.
getSerial() String? joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the serial number of an opened joystick, if available.
getType() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the type of an opened joystick.
getVendor() int joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Get the USB vendor ID of an opened joystick, if available.
rumble(int lowFrequencyRumble, int highFrequencyRumble, int durationMs) bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Start a rumble effect.
rumbleTriggers(int leftRumble, int rightRumble, int durationMs) bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Start a rumble effect in the joystick's triggers.
sendVirtualSensorData(int type, int sensorTimestamp, List<double> data) bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Send a sensor update for an opened virtual joystick.
setEffect(Pointer<Void> data, int size) bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Send a joystick specific effect packet.
setLed(int red, int green, int blue) bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Update a joystick's LED color.
setPlayerIndex(int playerIndex) bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Set the player index of an opened joystick.
setVirtualAxis(int axis, int value) bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Set the state of an axis on an opened virtual joystick.
setVirtualBall(int ball, int xrel, int yrel) bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Generate ball motion on an opened virtual joystick.
setVirtualButton(int button, bool down) bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Set the state of a button on an opened virtual joystick.
setVirtualHat(int hat, int value) bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Set the state of a hat on an opened virtual joystick.
setVirtualTouchpad(int touchpad, int finger, bool down, double x, double y, double pressure) bool joystick

Available on Pointer<SdlJoystick>, provided by the SdlJoystickPointerEx extension

Set touchpad finger state on an opened virtual joystick.