getNumButtons method

int getNumButtons()

Get the number of buttons on a joystick.

\param joystick an SDL_Joystick structure containing joystick information. \returns the number of buttons on success or -1 on failure; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

\sa SDL_GetJoystickButton \sa SDL_GetNumJoystickAxes \sa SDL_GetNumJoystickBalls \sa SDL_GetNumJoystickHats

extern SDL_DECLSPEC int SDLCALL SDL_GetNumJoystickButtons(SDL_Joystick *joystick)

Implementation

int getNumButtons() => sdlGetNumJoystickButtons(this);