getPath method

String? getPath()

Get the implementation dependent path of a joystick.

\param joystick the SDL_Joystick obtained from SDL_OpenJoystick(). \returns the path of the selected joystick. If no path can be found, this function returns NULL; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

\sa SDL_GetJoystickPathForID

extern SDL_DECLSPEC const char * SDLCALL SDL_GetJoystickPath(SDL_Joystick *joystick)

Implementation

String? getPath() => sdlGetJoystickPath(this);