setVirtualBall method

bool setVirtualBall(
  1. int ball,
  2. int xrel,
  3. int yrel
)

Generate ball motion on an opened virtual joystick.

Please note that values set here will not be applied until the next call to SDL_UpdateJoysticks, which can either be called directly, or can be called indirectly through various other SDL APIs, including, but not limited to the following: SDL_PollEvent, SDL_PumpEvents, SDL_WaitEventTimeout, SDL_WaitEvent.

\param joystick the virtual joystick on which to set state. \param ball the index of the ball on the virtual joystick to update. \param xrel the relative motion on the X axis. \param yrel the relative motion on the Y axis. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

\sa SDL_SetJoystickVirtualAxis \sa SDL_SetJoystickVirtualButton \sa SDL_SetJoystickVirtualHat \sa SDL_SetJoystickVirtualTouchpad \sa SDL_SetJoystickVirtualSensorData

extern SDL_DECLSPEC bool SDLCALL SDL_SetJoystickVirtualBall(SDL_Joystick *joystick, int ball, Sint16 xrel, Sint16 yrel)

Implementation

bool setVirtualBall(int ball, int xrel, int yrel) =>
    sdlSetJoystickVirtualBall(this, ball, xrel, yrel);