SdlMouseWheelEvent class final events

Inheritance
Implemented types
Available extensions

Constructors

SdlMouseWheelEvent()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
direction ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
integerX ↔ int
getter/setter pair
integerY ↔ int
getter/setter pair
mouseX ↔ double
getter/setter pair
mouseY ↔ double
getter/setter pair
reserved ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ int
getter/setter pair
type ↔ int
getter/setter pair
which ↔ int
getter/setter pair
windowId ↔ int
getter/setter pair
x ↔ double
getter/setter pair
y ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited