SdlRendererPointerEx extension

on

Methods

addVulkanSemaphores(int waitStageMask, int waitSemaphore, int signalSemaphore) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Add a set of synchronization semaphores for the current frame.
clear() bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Clear the current rendering target with the drawing color.
clipEnabled() bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get whether clipping is enabled on the given render target.
convertEventToCoordinates(Pointer<SdlEvent> event) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Convert the coordinates in an event to render coordinates.
coordinatesFromWindow({required SdlxFPoint windowPosition, required SdlxFPoint renderPosition}) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get a point in render coordinates when given a point in window coordinates.
coordinatesToWindow({required SdlxFPoint renderPosition, required SdlxFPoint windowPosition}) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get a point in window coordinates when given a point in render coordinates.
createTexture(int format, int access, int w, int h) Pointer<SdlTexture> render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Create a texture for a rendering context.
createTextureFromSurface(Pointer<SdlSurface> surface) Pointer<SdlTexture> render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Create a texture from an existing surface.
createTextureWithProperties(int props) Pointer<SdlTexture> render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Create a texture for a rendering context with the specified properties.
debugText(double x, double y, String? str) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Draw debug text to an SDL_Renderer.
destroy() bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Destroy the rendering context for a window and free all associated textures.
fillRect(SdlxFRect? rect) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Fill a rectangle on the current rendering target with the drawing color at subpixel precision.
fillRects(List<SdlxFRect> rects) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Fill some number of rectangles on the current rendering target with the drawing color at subpixel precision.
flush() bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Force the rendering context to flush any pending commands and state.
geometry(Pointer<SdlTexture> texture, {List<SdlxVertex>? vertices, List<int>? indices}) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Render a list of triangles, optionally using a texture and indices into the vertex array.
geometryRaw(Pointer<SdlTexture> texture, Pointer<Float> xy, int xyStride, Pointer<SdlFColor> color, int colorStride, Pointer<Float> uv, int uvStride, int numVertices, Pointer<NativeType> indices, int numIndices, int sizeIndices) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Render a list of triangles, optionally using a texture and indices into the vertex arrays.
getClipRect(SdlxRect rect) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the clip rectangle for the current target.
getColorScale() double? render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the color scale used for render operations.
getCurrentOutputSize(SdlxPoint size) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the current output size in pixels of a rendering context.
getDrawBlendMode() int? render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the blend mode used for drawing operations.
getDrawColor(SdlxColor color) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the color used for drawing operations (Rect, Line and Clear).
getDrawColorFloat(SdlxFColor color) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the color used for drawing operations (Rect, Line and Clear).
getLogicalPresentation(SdlxRenderLogicalPresentationInfo info) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get device independent resolution and presentation mode for rendering.
getMetalCommandEncoder() Pointer<NativeType> render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the Metal command encoder for the current frame.
getMetalLayer() Pointer<NativeType> render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the CAMetalLayer associated with the given Metal renderer.
getOutputSize(SdlxPoint size) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the output size in pixels of a rendering context.
getProperties() int render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the properties associated with a renderer.
getSafeArea(SdlxRect rect) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the safe area for rendering within the current viewport.
getScale(SdlxFPoint scale) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the drawing scale for the current target.
getTarget() Pointer<SdlTexture> render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the current render target.
getViewport(SdlxRect rect) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the drawing area for the current target.
getVSync() int render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get VSync of the given renderer.
getWindow() Pointer<SdlWindow> render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Get the window associated with a renderer.
line(SdlxFPoint p1, SdlxFPoint p2) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Draw a line on the current rendering target at subpixel precision.
lines(List<SdlxFPoint> points) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Draw a series of connected lines on the current rendering target at subpixel precision.
point(SdlxFPoint point) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Draw a point on the current rendering target at subpixel precision.
points(List<SdlxFPoint> points) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Draw multiple points on the current rendering target at subpixel precision.
present() bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Update the screen with any rendering performed since the previous call.
readPixels(SdlxRect? rect) Pointer<SdlSurface> render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Read pixels from the current rendering target.
rect(SdlxFRect? rect) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Draw a rectangle on the current rendering target at subpixel precision.
rects(List<SdlxFRect> rects) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Draw some number of rectangles on the current rendering target at subpixel precision.
setClipRect(SdlxRect? rect) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Set the clip rectangle for rendering on the specified target.
setColorScale(double scale) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Set the color scale used for render operations.
setDrawBlendMode(int blendMode) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Set the blend mode used for drawing operations (Fill and Line).
setDrawColor(SdlxColor color) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Set the color used for drawing operations.
setDrawColorFloat(SdlxFColor color) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Set the color used for drawing operations (Rect, Line and Clear).
setLogicalPresentation(SdlxRenderLogicalPresentationInfo info) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Set a device-independent resolution and presentation mode for rendering.
setScale(SdlxFPoint scale) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Set the drawing scale for rendering on the current target.
setTarget(Pointer<SdlTexture> texture) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Set a texture as the current rendering target.
setVierport(SdlxRect? rect) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Set the drawing area for rendering on the current target.
setVSync(int vsync) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Toggle VSync of the given renderer.
texture(Pointer<SdlTexture> texture, {SdlxFRect? srcrect, SdlxFRect? dstrect}) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Copy a portion of the texture to the current rendering target at subpixel precision.
texture9Grid(Pointer<SdlRenderer> renderer, Pointer<SdlTexture> texture, {required double leftWidth, required double rightWidth, required double topHeight, required double bottomHeight, SdlxFRect? srcrect, double scale = 1, SdlxFRect? dstrect}) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Perform a scaled copy using the 9-grid algorithm to the current rendering target at subpixel precision.
textureAffine(Pointer<SdlTexture> texture, {SdlxFRect? srcrect, SdlxFPoint? origin, SdlxFPoint? right, SdlxFPoint? down}) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Copy a portion of the source texture to the current rendering target, with affine transform, at subpixel precision.
textureRotated(Pointer<SdlTexture> texture, {SdlxFRect? srcrect, SdlxFRect? dstrect, double angle = 0, SdlxFPoint? center, int flip = SdlkFlip.none}) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Copy a portion of the source texture to the current rendering target, with rotation and flipping, at subpixel precision.
textureTiled(Pointer<SdlTexture> texture, {SdlxFRect? srcrect, double scale = 1, SdlxFRect? dstrect}) bool render

Available on Pointer<SdlRenderer>, provided by the SdlRendererPointerEx extension

Tile a portion of the texture to the current rendering target at subpixel precision.