getColorScale method

double? getColorScale()

Get the color scale used for render operations.

\param renderer the rendering context. \param scale a pointer filled in with the current color scale value. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_SetRenderColorScale

extern SDL_DECLSPEC bool SDLCALL SDL_GetRenderColorScale(SDL_Renderer *renderer, float *scale)

Implementation

double? getColorScale() => sdlxGetRenderColorScale(this);