getDrawBlendMode method

int? getDrawBlendMode()

Get the blend mode used for drawing operations.

\param renderer the rendering context. \param blendMode a pointer filled in with the current SDL_BlendMode. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_SetRenderDrawBlendMode

extern SDL_DECLSPEC bool SDLCALL SDL_GetRenderDrawBlendMode(SDL_Renderer *renderer, SDL_BlendMode *blendMode)

Implementation

int? getDrawBlendMode() => sdlxGetRenderDrawBlendMode(this);