updates static method
void
updates()
Update the current state of the open sensors.
This is called automatically by the event loop if sensor events are enabled.
This needs to be called from the thread that initialized the sensor subsystem.
\since This function is available since SDL 3.2.0.
extern SDL_DECLSPEC void SDLCALL SDL_UpdateSensors(void)
Implementation
static void updates() => sdlUpdateSensors();