SdlStoragePointerEx extension

on

Methods

close() bool storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Closes and frees a storage container.
copyFile(String oldpath, String newpath) bool storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Copy a file in a writable storage container.
createDirectory(String path) bool storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Create a directory in a writable storage container.
enumerateDirectory(String path, Pointer<NativeFunction<SdlEnumerateDirectoryCallback>> callback, Pointer<Void> userdata) bool storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Enumerate a directory in a storage container through a callback function.
getFileSize(String path) int? storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Query the size of a file within a storage container.
getPathInfo(String path, SdlxPathInfo info) bool storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Get information about a filesystem path in a storage container.
getSpaceRemaining() int storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Queries the remaining space in a storage container.
globDirectory(String path, {String? pattern, int flags = 0}) List<String> storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Enumerate a directory tree, filtered by pattern, and return a list.
readFile(String path) Uint8List? storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Synchronously read a file from a storage container into a client-provided buffer.
ready() bool storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Checks if the storage container is ready to use.
removePath(String path) bool storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Remove a file or an empty directory in a writable storage container.
renamePath(String oldpath, String newpath) bool storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Rename a file or directory in a writable storage container.
writeFile(String path, Uint8List source) bool storage

Available on Pointer<SdlStorage>, provided by the SdlStoragePointerEx extension

Synchronously write a file from client memory into a storage container.