SdlSurfacePointerEx extension

on

Methods

blit(SdlxRect? srcrect, Pointer<SdlSurface> dst, SdlxRect? dstrect) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Performs a fast blit from the source surface to the destination surface with clipping.
blitUnchecked(SdlxRect srcrect, Pointer<SdlSurface> dst, SdlxRect dstrect) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Perform low-level surface blitting only.
blitUncheckedScaled(SdlxRect srcrect, Pointer<SdlSurface> dst, SdlxRect dstrect, {int scaleMode = SdlkScalemode.invalid}) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Perform low-level surface scaled blitting only.
createColorCursor(int hotX, int hotY) Pointer<SdlCursor> mouse

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Create a color cursor.
destroy() bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Free a surface.
duplicate() Pointer<SdlSurface> surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Creates a new surface identical to the existing surface.
fillRect(SdlxRect? rect, int color) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Perform a fast fill of a rectangle with a specific color.
fillRects(List<SdlxRect> rects, int color) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Perform a fast fill of a set of rectangles with a specific color.
getAlphaMod() int? surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Get the additional alpha value used in blit operations.
getBlendMode() int? surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Get the blend mode used for blit operations.
getClipRect(SdlxRect rect) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Get the clipping rectangle for a surface.
getColorKey() int? surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Get the color key (transparent pixel) for a surface.
getColorMod() int? surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Get the additional color value multiplied into blit operations.
hadColorKey() bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Returns whether the surface has a color key.
hasRre() bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Returns whether the surface is RLE enabled.
loadBmpIo(Pointer<SdlIoStream> src, bool freesrc) Pointer<SdlSurface> surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Load a BMP image from a seekable SDL data stream.
lock() bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Set up a surface for directly accessing the pixels.
saveBmp(String file) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Save a surface to a file in BMP format.
saveBmpIo(Pointer<SdlIoStream> dst, bool freedst) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Save a surface to a seekable SDL data stream in BMP format.
setAlphaMod(int alpha) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Set an additional alpha value used in blit operations.
setBlendMode(int blendMode) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Set the blend mode used for blit operations.
setClipRect([SdlxRect? rect]) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Set the clipping rectangle for a surface.
setColorKey(bool enabled, int key) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Set the color key (transparent pixel) in a surface.
setColorMod(int r, int g, int b) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Set an additional color value multiplied into blit operations.
setPalette(Pointer<SdlPalette> palette) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Set the palette used by a surface.
setRre(bool enabled) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Set the RLE acceleration hint for a surface.
unlock() → void surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Release a surface after directly accessing the pixels.
upperBlitScaled(SdlxRect? srcrect, Pointer<SdlSurface> dst, SdlxRect? dstrect, {int scaleMode = SdlkScalemode.invalid}) bool surface

Available on Pointer<SdlSurface>, provided by the SdlSurfacePointerEx extension

Perform a scaled blit to a destination surface, which may be of a different format.