blitUnchecked method

bool blitUnchecked(
  1. SdlxRect srcrect,
  2. Pointer<SdlSurface> dst,
  3. SdlxRect dstrect
)

Perform low-level surface blitting only.

This is a semi-private blit function and it performs low-level surface blitting, assuming the input rectangles have already been clipped.

\param src the SDL_Surface structure to be copied from. \param srcrect the SDL_Rect structure representing the rectangle to be copied, may not be NULL. \param dst the SDL_Surface structure that is the blit target. \param dstrect the SDL_Rect structure representing the target rectangle in the destination surface, may not be NULL. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety Only one thread should be using the src and dst surfaces at any given time.

\since This function is available since SDL 3.2.0.

\sa SDL_BlitSurface

extern SDL_DECLSPEC bool SDLCALL SDL_BlitSurfaceUnchecked(SDL_Surface *src, const SDL_Rect *srcrect, SDL_Surface *dst, const SDL_Rect *dstrect)

Implementation

bool blitUnchecked(
  SdlxRect srcrect,
  Pointer<SdlSurface> dst,
  SdlxRect dstrect,
) => sdlxBlitSurfaceUnchecked(this, srcrect, dst, dstrect);