SdlTextEditingEvent class final events

Inheritance
Implemented types
Available extensions

Constructors

SdlTextEditingEvent()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
length ↔ int
getter/setter pair
reserved ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ int
getter/setter pair
text ↔ Pointer<Utf8>
getter/setter pair
timestamp ↔ int
getter/setter pair
type ↔ int
getter/setter pair
windowId ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited