SdlTexturePointerEx extension

on

Methods

destroy() bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Destroy the specified texture.
getAlphaMod() int? render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Get the additional alpha value multiplied into render copy operations.
getAlphaModFloat() double? render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Get the additional alpha value multiplied into render copy operations.
getBlendMode() int? render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Get the blend mode used for texture copy operations.
getColorMod(SdlxColor color) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Get the additional color value multiplied into render copy operations.
getColorModFloat(SdlxFColor color) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Get the additional color value multiplied into render copy operations.
getScaleMode() int? render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Get the scale mode used for texture scale operations.
getSize(SdlxFPoint size) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Get the size of a texture, as floating point values.
lock(Pointer<SdlRect> rect, Pointer<Pointer<NativeType>> pixels, Pointer<Int32> pitch) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Lock a portion of the texture for write-only pixel access.
lockToSurface(Pointer<SdlRect> rect, Pointer<Pointer<SdlSurface>> surface) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Lock a portion of the texture for write-only pixel access, and expose it as a SDL surface.
setAlphaMod(int alpha) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Set an additional alpha value multiplied into render copy operations.
setAlphaModFloat(double alpha) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Set an additional alpha value multiplied into render copy operations.
setBlendMode(int blendMode) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Set the blend mode for a texture, used by SDL_RenderTexture().
setColorMod(SdlxColor color) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Set an additional color value multiplied into render copy operations.
setColorModFloat(SdlxFColor color) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Set an additional color value multiplied into render copy operations.
setScaleMode(int scaleMode) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Set the scale mode used for texture scale operations.
unlock() → void render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Unlock a texture, uploading the changes to video memory, if needed.
update(Pointer<NativeType> pixels, int pitch, {SdlxRect? rect}) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Update the given texture rectangle with new pixel data.
updateNv({SdlxRect? rect, List<int>? yplane, List<int>? uVplane}) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Update a rectangle within a planar NV12 or NV21 texture with new pixels.
updateYuv({SdlxRect? rect, List<int>? yplane, List<int>? uplane, List<int>? vplane}) bool render

Available on Pointer<SdlTexture>, provided by the SdlTexturePointerEx extension

Update a rectangle within a planar YV12 or IYUV texture with new pixel data.