updateYuv method

bool updateYuv({
  1. SdlxRect? rect,
  2. List<int>? yplane,
  3. List<int>? uplane,
  4. List<int>? vplane,
})

Update a rectangle within a planar YV12 or IYUV texture with new pixel data.

You can use SDL_UpdateTexture() as long as your pixel data is a contiguous block of Y and U/V planes in the proper order, but this function is available if your pixel data is not contiguous.

\param texture the texture to update. \param rect a pointer to the rectangle of pixels to update, or NULL to update the entire texture. \param Yplane the raw pixel data for the Y plane. \param Ypitch the number of bytes between rows of pixel data for the Y plane. \param Uplane the raw pixel data for the U plane. \param Upitch the number of bytes between rows of pixel data for the U plane. \param Vplane the raw pixel data for the V plane. \param Vpitch the number of bytes between rows of pixel data for the V plane. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_UpdateNVTexture \sa SDL_UpdateTexture

extern SDL_DECLSPEC bool SDLCALL SDL_UpdateYUVTexture(SDL_Texture *texture, const SDL_Rect *rect, const Uint8 *Yplane, int Ypitch, const Uint8 *Uplane, int Upitch, const Uint8 *Vplane, int Vpitch)

Implementation

bool updateYuv({
  SdlxRect? rect,
  List<int>? yplane,
  List<int>? uplane,
  List<int>? vplane,
}) => sdlxUpdateYuvTexture(
  this,
  rect: rect,
  yplane: yplane,
  uplane: uplane,
  vplane: vplane,
);