setChecked method

void setChecked(
  1. bool checked
)

Sets whether or not an entry is checked.

The entry must have been created with the SDL_TRAYENTRY_CHECKBOX flag.

\param entry the entry to be updated. \param checked true if the entry should be checked; false otherwise.

\threadsafety This function should be called on the thread that created the tray.

\since This function is available since SDL 3.2.0.

\sa SDL_GetTrayEntries \sa SDL_InsertTrayEntryAt \sa SDL_GetTrayEntryChecked

extern SDL_DECLSPEC void SDLCALL SDL_SetTrayEntryChecked(SDL_TrayEntry *entry, bool checked)

Implementation

void setChecked(bool checked) => sdlSetTrayEntryChecked(this, checked);