setLabel method

void setLabel(
  1. String? label
)

Sets the label of an entry.

An entry cannot change between a separator and an ordinary entry; that is, it is not possible to set a non-NULL label on an entry that has a NULL label (separators), or to set a NULL label to an entry that has a non-NULL label. The function will silently fail if that happens.

\param entry the entry to be updated. \param label the new label for the entry in UTF-8 encoding.

\threadsafety This function should be called on the thread that created the tray.

\since This function is available since SDL 3.2.0.

\sa SDL_GetTrayEntries \sa SDL_InsertTrayEntryAt \sa SDL_GetTrayEntryLabel

extern SDL_DECLSPEC void SDLCALL SDL_SetTrayEntryLabel(SDL_TrayEntry *entry, const char *label)

Implementation

void setLabel(String? label) => sdlSetTrayEntryLabel(this, label);