SdlTrayMenuPointerEx extension

on

Methods

getParentEntry() Pointer<SdlTrayEntry> tray

Available on Pointer<SdlTrayMenu>, provided by the SdlTrayMenuPointerEx extension

Gets the entry for which the menu is a submenu, if the current menu is a submenu.
getParentTray() Pointer<SdlTray> tray

Available on Pointer<SdlTrayMenu>, provided by the SdlTrayMenuPointerEx extension

Gets the tray for which this menu is the first-level menu, if the current menu isn't a submenu.
insertEntryAt(int pos, String? label, int flags) Pointer<SdlTrayEntry> tray

Available on Pointer<SdlTrayMenu>, provided by the SdlTrayMenuPointerEx extension

Insert a tray entry at a given position.