getParentEntry method

Pointer<SdlTrayEntry> getParentEntry()

Gets the entry for which the menu is a submenu, if the current menu is a submenu.

Either this function or SDL_GetTrayMenuParentTray() will return non-NULL for any given menu.

\param menu the menu for which to get the parent entry. \returns the parent entry, or NULL if this menu is not a submenu.

\threadsafety This function should be called on the thread that created the tray.

\since This function is available since SDL 3.2.0.

\sa SDL_CreateTraySubmenu \sa SDL_GetTrayMenuParentTray

extern SDL_DECLSPEC SDL_TrayEntry * SDLCALL SDL_GetTrayMenuParentEntry(SDL_TrayMenu *menu)

Implementation

Pointer<SdlTrayEntry> getParentEntry() => sdlGetTrayMenuParentEntry(this);