SdlWindowPointerEx extension

on

Methods

createPopupWindow(int offsetX, int offsetY, int w, int h, int flags) Pointer<SdlWindow> video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Create a child popup window of the specified parent window.
destroy() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Destroy a window.
destroySurface() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Destroy the surface associated with the window.
eglGetSurface() Pointer<Void> video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the EGL surface associated with the window.
flash(int operation) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Request a window to demand attention from the user.
getAspectRatio() → ({double maxAspect, double minAspect})? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the aspect ratio of a window's client area.
getBordersSize() → ({int bottom, int left, int right, int top})? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the size of a window's borders (decorations) around the client area.
getDisplayFor() int video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the display associated with a window.
getDisplayScale() double video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the content display scale relative to a window's pixel size.
getFlags() int video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the window flags.
getFullscreenMode() SdlxDisplayMode? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Query the display mode to use when a window is visible at fullscreen.
getIccProfile() → ({Pointer<Void> profile, int size})? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the raw ICC profile data for the screen the window is currently on.
getId() int video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the numeric ID of a window.
getKeyboardGrab() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get a window's keyboard grab mode.
getMaximumSize() → ({int h, int w})? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the maximum size of a window's client area.
getMinimumSize() → ({int h, int w})? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the minimum size of a window's client area.
getMouseGrab() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get a window's mouse grab mode.
getMouseRect() SdlxRect? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the mouse confinement rectangle of a window.
getOpacity() double video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the opacity of a window.
getParent() Pointer<SdlWindow> video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get parent of a window.
getPixelDensity() double video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the pixel density of a window.
getPixelFormat() int video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the pixel format associated with the window.
getPosition() → ({int x, int y})? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the position of a window.
getProgressState() int video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the state of the progress bar for the given window’s taskbar icon.
getProgressValue() double video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the value of the progress bar for the given window’s taskbar icon.
getProperties() int video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the properties associated with a window.
getSafeArea() SdlxRect? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the safe area for this window.
getSize() → ({int h, int w})? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the size of a window's client area.
getSizeInPixels() → ({int h, int w})? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the size of a window's client area, in pixels.
getSurface() Pointer<SdlSurface> video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the SDL surface associated with the window.
getSurfaceVSync() int? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get VSync for the window surface.
getTitle() String? video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Get the title of a window.
glCreateContext() Pointer<SdlGlContext> video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Create an OpenGL context for an OpenGL window, and make it current.
glMakeCurrent(Pointer<SdlGlContext> context) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set up an OpenGL context for rendering into an OpenGL window.
glSwap() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Update a window with OpenGL rendering.
hasSurface() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Return whether the window has a surface associated with it.
hide() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Hide a window.
maximize() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Request that the window be made as large as possible.
minimize() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Request that the window be minimized to an iconic representation.
raise() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Request that a window be raised above other windows and gain the input focus.
restore() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Request that the size and position of a minimized or maximized window be restored.
sdlSetWindowFullscreenMode(SdlxDisplayMode mode) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set the display mode to use when a window is visible and fullscreen.
setAlwaysOnTop(bool onTop) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set the window to always be above the others.
setAspectRatio(double minAspect, double maxAspect) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Request that the aspect ratio of a window's client area be set.
setBordered(bool bordered) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set the border state of a window.
setFillDocument(bool fill) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set the window to fill the current document space (Emscripten only).
setFocasable(bool focusable) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set whether the window may have input focus.
setFullscreen(bool fullscreen) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Request that the window's fullscreen state be changed.
setHitTest(Pointer<NativeFunction<SdlHitTest>> callback, Pointer<Void> callbackData) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Provide a callback that decides if a window region has special properties.
setIcon(Pointer<SdlSurface> icon) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set the icon for a window.
setKeyboardGrab(bool grabbed) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set a window's keyboard grab mode.
setMaximumSize(int w, int h) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set the maximum size of a window's client area.
setMinimumSize(int w, int h) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set the minimum size of a window's client area.
setModal(bool modal) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Toggle the state of the window as modal.
setMouseGrab(bool grabbed) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set a window's mouse grab mode.
setMouseRect(SdlxRect rect) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Confines the cursor to the specified area of a window.
setOpacity(double opacity) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set the opacity for a window.
setParent(Pointer<SdlWindow> parent) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set the window as a child of a parent window.
setPosition(int x, int y) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Request that the window's position be set.
setProgressState(int state) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Sets the state of the progress bar for the given window’s taskbar icon.
setProgressValue(double value) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Sets the value of the progress bar for the given window’s taskbar icon.
setResizable(bool resizable) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set the user-resizable state of a window.
setShape(Pointer<SdlSurface> shape) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set the shape of a transparent window.
setSize(int w, int h) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Request that the size of a window's client area be set.
setSurfaceVSync(int vsync) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Toggle VSync for the window surface.
setTitle(String title) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Set the title of a window.
show() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Show a window.
showSystemMenu(int x, int y) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Display the system-level window menu.
sync() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Block until any pending window state is finalized.
updateSurface() bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Copy the window surface to the screen.
updateSurfaceRects(List<SdlxRect> rects) bool video

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerEx extension

Copy areas of the window surface to the screen.