getPixelDensity method

double getPixelDensity()

Get the pixel density of a window.

This is a ratio of pixel size to window size. For example, if the window is 1920x1080 and it has a high density back buffer of 3840x2160 pixels, it would have a pixel density of 2.0.

\param window the window to query. \returns the pixel density or 0.0f on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_GetWindowDisplayScale

extern SDL_DECLSPEC float SDLCALL SDL_GetWindowPixelDensity(SDL_Window *window)

See also:

Implementation

double getPixelDensity() => sdlGetWindowPixelDensity(this);