getSurfaceVSync method

int? getSurfaceVSync()

Get VSync for the window surface.

\param window the window to query. \param vsync an int filled with the current vertical refresh sync interval. See SDL_SetWindowSurfaceVSync() for the meaning of the value. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_SetWindowSurfaceVSync

extern SDL_DECLSPEC bool SDLCALL SDL_GetWindowSurfaceVSync(SDL_Window *window, int *vsync)

See also:

Implementation

int? getSurfaceVSync() => sdlxGetWindowSurfaceVSync(this);