setTextInputArea method

bool setTextInputArea(
  1. SdlxRect rect,
  2. int cursor
)

Set the area used to type Unicode text input.

Native input methods may place a window with word suggestions near the cursor, without covering the text being entered.

\param window the window for which to set the text input area. \param rect the SDL_Rect representing the text input area, in window coordinates, or NULL to clear it. \param cursor the offset of the current cursor location relative to rect->x, in window coordinates. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_GetTextInputArea \sa SDL_StartTextInput

extern SDL_DECLSPEC bool SDLCALL SDL_SetTextInputArea(SDL_Window *window, const SDL_Rect *rect, int cursor)

See also:

Implementation

bool setTextInputArea(SdlxRect rect, int cursor) =>
    sdlxSetTextInputArea(this, rect, cursor);