startTextInput method

bool startTextInput()

Start accepting Unicode text input events in a window.

This function will enable text input (SDL_EVENT_TEXT_INPUT and SDL_EVENT_TEXT_EDITING events) in the specified window. Please use this function paired with SDL_StopTextInput().

Text input events are not received by default.

On some platforms using this function shows the screen keyboard and/or activates an IME, which can prevent some key press events from being passed through.

\param window the window to enable text input. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_SetTextInputArea \sa SDL_StartTextInputWithProperties \sa SDL_StopTextInput \sa SDL_TextInputActive

extern SDL_DECLSPEC bool SDLCALL SDL_StartTextInput(SDL_Window *window)

See also:

Implementation

bool startTextInput() => sdlStartTextInput(this);