stopTextInput method

bool stopTextInput()

Stop receiving any text input events in a window.

If SDL_StartTextInput() showed the screen keyboard, this function will hide it.

\param window the window to disable text input. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_StartTextInput

extern SDL_DECLSPEC bool SDLCALL SDL_StopTextInput(SDL_Window *window)

See also:

Implementation

bool stopTextInput() => sdlStopTextInput(this);