getRelativeMouseMode method

bool getRelativeMouseMode()

Query whether relative mouse mode is enabled for a window.

\param window the window to query. \returns true if relative mode is enabled for a window or false otherwise.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_SetWindowRelativeMouseMode

extern SDL_DECLSPEC bool SDLCALL SDL_GetWindowRelativeMouseMode(SDL_Window *window)

See also:

Implementation

bool getRelativeMouseMode() => sdlGetWindowRelativeMouseMode(this);