SdlkSystemCursor class mouse

Constructors

SdlkSystemCursor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

alias → const int
allScroll → const int
cell → const int
colResize → const int
contextMenu → const int
copy → const int
count → const int
crosshair → const int
eResize → const int
ewResize → const int
grab → const int
grabbing → const int
help → const int
move → const int
neResize → const int
neswResize → const int
noDrop → const int
notAllowed → const int
nResize → const int
nsResize → const int
nwResize → const int
nwseResize → const int
onDefault → const int
pointer → const int
progress → const int
rowResize → const int
seResize → const int
sResize → const int
swResize → const int
text → const int
verticalText → const int
wait → const int
wResize → const int
zoomIn → const int
zoomOut → const int