SdlkThread class thread

Constructors

SdlkThread()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

alive → const int
complete → const int
detached → const int
priorityHigh → const int
priorityLow → const int
priorityNormal → const int
priorityTimeCritical → const int
unknown → const int