SdlxCameraSpec class

Constructors

SdlxCameraSpec({int format = 0, int colorspace = 0, int width = 0, int height = 0, int framerateNumerator = 0, int framerateDenominator = 0})

Properties

colorspace int
getter/setter pair
format int
getter/setter pair
framerateDenominator int
getter/setter pair
framerateNumerator int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
getter/setter pair

Methods

calloc() Pointer<SdlCameraSpec>
loadFromPointer(Pointer<SdlCameraSpec> pointer) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited