SdlxColor class

Constructors

SdlxColor(int r, int g, int b, [int a = 255])

Properties

a ↔ int
getter/setter pair
b ↔ int
getter/setter pair
g ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
r ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

calloc() → Pointer<SdlColor>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited