SdlxCursorFrameInfo class
Constructors
-
SdlxCursorFrameInfo({Pointer<
SdlSurface> ? surface, int duration = 0})
Properties
- duration ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
surface
↔ Pointer<
SdlSurface> -
getter/setter pair
Methods
-
calloc(
) → Pointer< SdlCursorFrameInfo> -
loadFromPointer(
Pointer< SdlCursorFrameInfo> pointer) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited