SdlxEvent class

Implementers

Constructors

SdlxEvent({int type = 0, int reserved = 0, int timestamp = 0})

Properties

hashCode int
The hash code for this object.
no setterinherited
reserved int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
getter/setter pair
type int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPointer(Pointer<SdlEvent> pointer) SdlxEvent