SdlxFPoint class

Constructors

SdlxFPoint(double x, double y)

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
getter/setter pair
y double
getter/setter pair

Methods

angleTo(SdlxFPoint other) double
calloc() Pointer<SdlFPoint>
distanceTo(SdlxFPoint other) double
distanceToSq(SdlxFPoint other) double
lerpTo(SdlxFPoint other, double t) SdlxFPoint
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInt() SdlxPoint
toString() String
A string representation of this object.
inherited

Operators

operator *(SdlxFPoint other) SdlxFPoint
operator +(SdlxFPoint other) SdlxFPoint
operator -(SdlxFPoint other) SdlxFPoint
operator /(SdlxFPoint other) SdlxFPoint
operator ==(Object other) bool
The equality operator.
override

Static Properties

zero SdlxFPoint
no setter