SdlxFRect class

Constructors

SdlxFRect({double x = 0, double y = 0, double w = 0, double h = 0})

Properties

bottom double
no setter
bottomLeft SdlxFPoint
getter/setter pair
bottomRight SdlxFPoint
getter/setter pair
center SdlxFPoint
getter/setter pair
h double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size SdlxFPoint
getter/setter pair
topLeft SdlxFPoint
getter/setter pair
topRight SdlxFPoint
getter/setter pair
w double
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair

Methods

calloc() Pointer<SdlFRect>
intersection(SdlxFRect other) SdlxFRect?
loadFrom(double x, double y, double w, double h) → void
loadFromCenter(SdlxFPoint center, SdlxFPoint size) → void
loadFromPointer(Pointer<SdlFRect> pointer) → void
loadFromPoints(SdlxFPoint p1, SdlxFPoint p2) → void
loadFromPosition(SdlxFPoint topLeft, SdlxFPoint size) → void
loadFromRect(SdlxFRect rect) → void
moveBy(SdlxFPoint offset) → void
moveTo(SdlxFPoint position) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sizeBy(SdlxFPoint offset) → void
sizeTo(SdlxFPoint size) → void
toInt() SdlxRect
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited