SdlxGpuBufferRegion class

Constructors

SdlxGpuBufferRegion({Pointer<SdlGpuBuffer>? buffer, int offset = 0, int size = 0})

Properties

buffer Pointer<SdlGpuBuffer>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
offset int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
getter/setter pair

Methods

calloc() Pointer<SdlGpuBufferRegion>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited