SdlxGpuDepthStencilState class

Constructors

SdlxGpuDepthStencilState({int compareOp = 0, int compareMask = 0, int writeMask = 0, int enableDepthTest = 0, int enableDepthWrite = 0, int enableStencilTest = 0})

Properties

backStencilState SdlxGpuStencilOpState
getter/setter pair
compareMask int
getter/setter pair
compareOp int
getter/setter pair
enableDepthTest int
getter/setter pair
enableDepthWrite int
getter/setter pair
enableStencilTest int
getter/setter pair
frontStencilState SdlxGpuStencilOpState
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writeMask int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited