SdlxGpuDepthStencilTargetInfo class

Constructors

SdlxGpuDepthStencilTargetInfo({Pointer<SdlGpuTexture>? texture, double clearDepth = 0, int loadOp = 0, int storeOp = 0, int stencilLoadOp = 0, int stencilStoreOp = 0, int cycle = 0, int clearStencil = 0, int mipLevel = 0, int layer = 0})

Properties

clearDepth double
getter/setter pair
clearStencil int
getter/setter pair
cycle int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
layer int
getter/setter pair
loadOp int
getter/setter pair
mipLevel int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stencilLoadOp int
getter/setter pair
stencilStoreOp int
getter/setter pair
storeOp int
getter/setter pair
texture Pointer<SdlGpuTexture>
getter/setter pair

Methods

calloc() Pointer<SdlGpuDepthStencilTargetInfo>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited