SdlxGpuRasterizerState class

Constructors

SdlxGpuRasterizerState({int fillMode = 0, int cullMode = 0, int frontFace = 0, double depthBiasAntFactor = 0, double depthBiasClamp = 0, double depthBiasSlopeFactor = 0, int enableDepthBias = 0, int enableDepthClip = 0})

Properties

cullMode int
getter/setter pair
depthBiasAntFactor double
getter/setter pair
depthBiasClamp double
getter/setter pair
depthBiasSlopeFactor double
getter/setter pair
enableDepthBias int
getter/setter pair
enableDepthClip int
getter/setter pair
fillMode int
getter/setter pair
frontFace int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited