SdlxGpuRenderStateCreateInfo class

Constructors

SdlxGpuRenderStateCreateInfo({Pointer<SdlGpuShader>? fragmentShader, List<SdlxGpuTextureSamplerBinding>? samplerBindings, List<Pointer<SdlGpuTexture>>? storageTextures, List<Pointer<SdlGpuBuffer>>? storageBuffers, int props = 0})

Properties

fragmentShader Pointer<SdlGpuShader>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
props int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplerBindings List<SdlxGpuTextureSamplerBinding>
getter/setter pair
storageBuffers List<Pointer<SdlGpuBuffer>>
getter/setter pair
storageTextures List<Pointer<SdlGpuTexture>>
getter/setter pair

Methods

calloc() Pointer<SdlGpuRenderStateCreateInfo>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited