SdlxGpuStencilOpState class

Constructors

SdlxGpuStencilOpState({int failOp = 0, int passOp = 0, int depthFailOp = 0, int compareOp = 0})

Properties

compareOp int
getter/setter pair
depthFailOp int
getter/setter pair
failOp int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
passOp int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited