SdlxGpuStorageTextureReadWriteBinding class

Constructors

SdlxGpuStorageTextureReadWriteBinding({Pointer<SdlGpuTexture>? texture, int mipLevel = 0, int layer = 0, bool cycle = false})

Properties

cycle ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
layer ↔ int
getter/setter pair
mipLevel ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texture ↔ Pointer<SdlGpuTexture>
getter/setter pair

Methods

calloc() → Pointer<SdlGpuStorageTextureReadWriteBinding>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited