SdlxGpuSwapchainTextureInfo class

Constructors

SdlxGpuSwapchainTextureInfo({Pointer<SdlGpuTexture>? texture, int w = 0, int h = 0})

Properties

h int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
texture Pointer<SdlGpuTexture>
getter/setter pair
w int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited