SdlxGpuTextureCreateInfo class

Constructors

SdlxGpuTextureCreateInfo({int type = 0, int format = 0, int usage = 0, int width = 0, int height = 0, int layerCountOrDepth = 0, int numLevels = 0, int sampleCount = 0, int props = 0})

Properties

format int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
layerCountOrDepth int
getter/setter pair
numLevels int
getter/setter pair
props int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleCount int
getter/setter pair
type int
getter/setter pair
usage int
getter/setter pair
width int
getter/setter pair

Methods

calloc() Pointer<SdlGpuTextureCreateInfo>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited