SdlxGpuTextureRegion class
Constructors
Properties
- d ↔ int
-
getter/setter pair
- h ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- layer ↔ int
-
getter/setter pair
- mipLevel ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
texture
↔ Pointer<
SdlGpuTexture> -
getter/setter pair
- w ↔ int
-
getter/setter pair
- x ↔ int
-
getter/setter pair
- y ↔ int
-
getter/setter pair
- z ↔ int
-
getter/setter pair
Methods
-
calloc(
) → Pointer< SdlGpuTextureRegion> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited