SdlxGpuTextureTransferInfo class

Constructors

SdlxGpuTextureTransferInfo({Pointer<SdlGpuTransferBuffer>? transferBuffer, int offset = 0, int pixelsPerRow = 0, int rowsPerLayer = 0})

Properties

hashCode int
The hash code for this object.
no setterinherited
offset int
getter/setter pair
pixelsPerRow int
getter/setter pair
rowsPerLayer int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transferBuffer Pointer<SdlGpuTransferBuffer>
getter/setter pair

Methods

calloc() Pointer<SdlGpuTextureTransferInfo>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited