SdlxGpuVertexAttribute class

Constructors

SdlxGpuVertexAttribute({int location = 0, int bufferSlot = 0, int format = 0, int offset = 0})

Properties

bufferSlot int
getter/setter pair
format int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
location int
getter/setter pair
offset int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited