SdlxHapticCondition class

Inheritance

Constructors

SdlxHapticCondition({int type = 0, SdlxHapticDirection? direction, int length = 0, int delay = 0, int button = 0, int interval = 0, List<int>? rightSat, List<int>? leftSat, List<int>? rightCoeff, List<int>? leftCoeff, List<int>? deadband, List<int>? center})

Properties

button int
getter/setter pair
center List<int>
getter/setter pair
deadband List<int>
getter/setter pair
delay int
getter/setter pair
direction SdlxHapticDirection
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interval int
getter/setter pair
leftCoeff List<int>
getter/setter pair
leftSat List<int>
getter/setter pair
length int
getter/setter pair
rightCoeff List<int>
getter/setter pair
rightSat List<int>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
getter/setter pairinherited

Methods

calloc() Pointer<SdlHapticEffect>
override
loadFromPointer(Pointer<SdlHapticEffect> pointer) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited