SdlxHapticCustom class
- Inheritance
-
- Object
- SdlxHapticEffect
- SdlxHapticCustom
Constructors
- SdlxHapticCustom({int type = 0, SdlxHapticDirection? direction, int length = 0, int delay = 0, int button = 0, int interval = 0, int channels = 0, int period = 0, int samples = 0, Uint16List? data, int attackLength = 0, int attackLevel = 0, int fadeLength = 0, int fadeLevel = 0})
Properties
- attackLength ↔ int
-
getter/setter pair
- attackLevel ↔ int
-
getter/setter pair
-
getter/setter pair
- channels ↔ int
-
getter/setter pair
- data ↔ Uint16List?
-
getter/setter pair
- delay ↔ int
-
getter/setter pair
- direction ↔ SdlxHapticDirection
-
getter/setter pair
- fadeLength ↔ int
-
getter/setter pair
- fadeLevel ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval ↔ int
-
getter/setter pair
- length ↔ int
-
getter/setter pair
- period ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samples ↔ int
-
getter/setter pair
- type ↔ int
-
getter/setter pairinherited
Methods
-
calloc(
) → Pointer< SdlHapticEffect> -
override
-
loadFromPointer(
Pointer< SdlHapticEffect> pointer) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited