SdlxHapticLeftRight class

Inheritance

Constructors

SdlxHapticLeftRight({int type = 0, int length = 0, int largeMagnitude = 0, int smallMagnitude = 0})

Properties

hashCode int
The hash code for this object.
no setterinherited
largeMagnitude int
getter/setter pair
length int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smallMagnitude int
getter/setter pair
type int
getter/setter pairinherited

Methods

calloc() Pointer<SdlHapticEffect>
override
loadFromPointer(Pointer<SdlHapticEffect> pointer) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited