SdlxIoStreamInterface class
Constructors
-
SdlxIoStreamInterface({int? version, Pointer<
NativeFunction< ? size, Pointer<SdlIoStreamInterfaceSize> >NativeFunction< ? seek, Pointer<SdlIoStreamInterfaceSeek> >NativeFunction< ? read, Pointer<SdlIoStreamInterfaceRead> >NativeFunction< ? write, Pointer<SdlIoStreamInterfaceRead> >NativeFunction< ? flush, Pointer<SdlIoStreamInterfaceFlush> >NativeFunction< ? close})SdlIoStreamInterfaceClose> >
Properties
-
close
↔ Pointer<
NativeFunction< SdlIoStreamInterfaceClose> > -
getter/setter pair
-
flush
↔ Pointer<
NativeFunction< SdlIoStreamInterfaceFlush> > -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
read
↔ Pointer<
NativeFunction< SdlIoStreamInterfaceRead> > -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
seek
↔ Pointer<
NativeFunction< SdlIoStreamInterfaceSeek> > -
getter/setter pair
-
size
↔ Pointer<
NativeFunction< SdlIoStreamInterfaceSize> > -
getter/setter pair
- version ↔ int
-
getter/setter pair
-
write
↔ Pointer<
NativeFunction< SdlIoStreamInterfaceRead> > -
getter/setter pair
Methods
-
calloc(
) → Pointer< SdlIoStreamInterface> -
loadFromPointer(
Pointer< SdlIoStreamInterface> pointer) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited