SdlxLocale class

Constructors

SdlxLocale({String language = '', String country = ''})

Properties

country String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
language String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadFromPointer(Pointer<SdlLocale> pointer) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited