SdlxMessageBoxButtonData class

Constructors

SdlxMessageBoxButtonData({int flags = 0, int buttonId = 0, String text = ''})

Properties

buttonId ↔ int
getter/setter pair
flags ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited