SdlxMessageBoxData class

Constructors

SdlxMessageBoxData({int flags = 0, Pointer<SdlWindow>? window, String? title, String? message, List<SdlxMessageBoxButtonData>? buttons, SdlxMessageBoxColorScheme? colorScheme})

Properties

buttons List<SdlxMessageBoxButtonData>
getter/setter pair
colorScheme SdlxMessageBoxColorScheme?
getter/setter pair
flags int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedButtonId int
getter/setter pair
title String
getter/setter pair
window Pointer<SdlWindow>
getter/setter pair

Methods

calloc() Pointer<SdlMessageBoxData>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited