SdlxMouseWheelEvent class

Inheritance

Constructors

SdlxMouseWheelEvent({int type = 0, int reserved = 0, int timestamp = 0, int windowId = 0, int which = 0, double x = 0, double y = 0, int direction = 0, double mouseX = 0, double mouseY = 0, int integerX = 0, int integerY = 0})

Properties

direction int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
integerX int
getter/setter pair
integerY int
getter/setter pair
mouseX double
getter/setter pair
mouseY double
getter/setter pair
reserved int
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
getter/setter pairinherited
type int
getter/setter pairinherited
which int
getter/setter pair
windowId int
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair

Methods

loadFromPointer(Pointer<SdlEvent> pointer) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPointer(Pointer<SdlEvent> pointer) SdlxMouseWheelEvent
override