SdlxNotificationActionButton class

Inheritance

Constructors

SdlxNotificationActionButton({int type = SDL_NOTIFICATION_ACTION_TYPE_BUTTON, String actionId = '', String actionLabel = ''})

Properties

actionId String
getter/setter pair
actionLabel String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPointer(Pointer<SdlNotificationAction> pointer) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited