SdlxRect class

Constructors

SdlxRect({int x = 0, int y = 0, int w = 0, int h = 0})

Properties

h int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
w int
getter/setter pair
x int
getter/setter pair
y int
getter/setter pair

Methods

calloc() Pointer<SdlRect>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited