SdlxTouchFingerEvent class

Inheritance

Constructors

SdlxTouchFingerEvent({int type = 0, int reserved = 0, int timestamp = 0, int touchId = 0, int fingerId = 0, double x = 0, double y = 0, double dx = 0, double dy = 0, double pressure = 0, int windowId = 0})

Properties

dx double
getter/setter pair
dy double
getter/setter pair
fingerId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pressure double
getter/setter pair
reserved int
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
getter/setter pairinherited
touchId int
getter/setter pair
type int
getter/setter pairinherited
windowId int
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair

Methods

loadFromPointer(Pointer<SdlEvent> pointer) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPointer(Pointer<SdlEvent> pointer) SdlxTouchFingerEvent
override