sdlCreateEnvironment function stdinc
Create a set of environment variables.
Note that on Windows, the variable names pulled in from the system, if
populated is true, have their ASCII values uppercased, to match what most
platforms expect even though the Windows system environment table is
case-insensitive. Once those uppercased variable names are in an
SDL_Environment, SDL treats them as case-sensitive.
\param populated true to initialize it from the C runtime environment, false to create an empty environment. \returns a pointer to the new environment or NULL on failure; call SDL_GetError() for more information.
\threadsafety If populated is false, it is safe to call this function
from any thread, otherwise it is safe if no other threads are
calling setenv() or unsetenv()
\since This function is available since SDL 3.2.0.
\sa SDL_GetEnvironmentVariable \sa SDL_GetEnvironmentVariables \sa SDL_SetEnvironmentVariable \sa SDL_UnsetEnvironmentVariable \sa SDL_DestroyEnvironment
extern SDL_DECLSPEC SDL_Environment * SDLCALL SDL_CreateEnvironment(bool populated)
See also:
Implementation
Pointer<SdlEnvironment> sdlCreateEnvironment(bool populated) {
final sdlCreateEnvironmentLookupFunction = _libSdl
.lookupFunction<
Pointer<SdlEnvironment> Function(Bool populated),
Pointer<SdlEnvironment> Function(bool populated)
>('SDL_CreateEnvironment');
return sdlCreateEnvironmentLookupFunction(populated);
}