sdlDestroyMutex function mutex

void sdlDestroyMutex(
  1. Pointer<SdlMutex> mutex
)

Destroy a mutex created with SDL_CreateMutex().

This function must be called on any mutex that is no longer needed. Failure to destroy a mutex will result in a system memory or resource leak. While it is safe to destroy a mutex that is unlocked, it is not safe to attempt to destroy a locked mutex, and may result in undefined behavior depending on the platform.

\param mutex the mutex to destroy.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

\sa SDL_CreateMutex

extern SDL_DECLSPEC void SDLCALL SDL_DestroyMutex(SDL_Mutex *mutex)

Implementation

void sdlDestroyMutex(Pointer<SdlMutex> mutex) {
  final sdlDestroyMutexLookupFunction = _libSdl
      .lookupFunction<
        Void Function(Pointer<SdlMutex> mutex),
        void Function(Pointer<SdlMutex> mutex)
      >('SDL_DestroyMutex');
  return sdlDestroyMutexLookupFunction(mutex);
}