sdlGetEnvironment function stdinc

Pointer<SdlEnvironment> sdlGetEnvironment()

Get the process environment.

This is initialized at application start and is not affected by setenv() and unsetenv() calls after that point. Use SDL_SetEnvironmentVariable() and SDL_UnsetEnvironmentVariable() if you want to modify this environment, or SDL_setenv_unsafe() or SDL_unsetenv_unsafe() if you want changes to persist in the C runtime environment after SDL_Quit().

Note that on Windows, the variable names pulled in from the system at startup have their ASCII values uppercased, to match what most platforms expect even though the Windows system environment table is case-insensitive. Once those uppercased variable names are in an SDL_Environment, SDL treats them as case-sensitive.

\returns a pointer to the environment for the process or NULL on failure; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

\sa SDL_GetEnvironmentVariable \sa SDL_GetEnvironmentVariables \sa SDL_SetEnvironmentVariable \sa SDL_UnsetEnvironmentVariable

extern SDL_DECLSPEC SDL_Environment * SDLCALL SDL_GetEnvironment(void)

See also:

Implementation

Pointer<SdlEnvironment> sdlGetEnvironment() {
  final sdlGetEnvironmentLookupFunction = _libSdl
      .lookupFunction<
        Pointer<SdlEnvironment> Function(),
        Pointer<SdlEnvironment> Function()
      >('SDL_GetEnvironment');
  return sdlGetEnvironmentLookupFunction();
}