sdlGetJoystickSensorData function joystick

bool sdlGetJoystickSensorData(
  1. Pointer<SdlJoystick> joystick,
  2. int type,
  3. Pointer<Float> data,
  4. int numValues,
)

Get the current state of a joystick sensor.

The number of values and interpretation of the data is sensor dependent. See the remarks in SDL_SensorType for details for each type of sensor.

\param joystick the joystick to query. \param type the type of sensor to query. \param data a pointer filled with the current sensor state. \param num_values the number of values to write to data. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.6.0.

extern SDL_DECLSPEC bool SDLCALL SDL_GetJoystickSensorData(SDL_Joystick *joystick, SDL_SensorType type, float *data, int num_values)

See also:

Implementation

bool sdlGetJoystickSensorData(
  Pointer<SdlJoystick> joystick,
  int type,
  Pointer<Float> data,
  int numValues,
) {
  final sdlGetJoystickSensorDataLookupFunction = _libSdl
      .lookupFunction<
        Bool Function(
          Pointer<SdlJoystick> joystick,
          Int32 type,
          Pointer<Float> data,
          Int32 numValues,
        ),
        bool Function(
          Pointer<SdlJoystick> joystick,
          int type,
          Pointer<Float> data,
          int numValues,
        )
      >('SDL_GetJoystickSensorData');
  return sdlGetJoystickSensorDataLookupFunction(
    joystick,
    type,
    data,
    numValues,
  );
}