sdlGetOpenHarmonyInternalStoragePath function system
Get the path used for internal storage for this OpenHarmony application.
This path is unique to your application and cannot be written to by other applications.
Your internal storage path is typically: /data/storage/el2/base/files.
\returns the path used for internal storage or NULL on failure; call SDL_GetError() for more information.
\since This function is available since SDL 3.6.0.
extern SDL_DECLSPEC const char * SDLCALL SDL_GetOpenHarmonyInternalStoragePath(void)
See also:
Implementation
String? sdlGetOpenHarmonyInternalStoragePath() {
final sdlGetOpenHarmonyInternalStoragePathLookupFunction = _libSdl
.lookupFunction<Pointer<Utf8> Function(), Pointer<Utf8> Function()>(
'SDL_GetOpenHarmonyInternalStoragePath',
);
final result = sdlGetOpenHarmonyInternalStoragePathLookupFunction();
if (result == nullptr) {
return null;
}
return result.toDartString();
}