sdlGetPerformanceFrequency function timer
Get the count per second of the high resolution counter.
\returns the frequency at which the result from SDL_GetPerformanceCounter is adjusted, measured in counts per second. This value is platform-dependent.
\threadsafety It is safe to call this function from any thread.
\since This function is available since SDL 3.2.0.
\sa SDL_GetPerformanceCounter
extern SDL_DECLSPEC Uint64 SDLCALL SDL_GetPerformanceFrequency(void)
See also:
Implementation
int sdlGetPerformanceFrequency() {
final sdlGetPerformanceFrequencyLookupFunction = _libSdl
.lookupFunction<Uint64 Function(), int Function()>(
'SDL_GetPerformanceFrequency',
);
return sdlGetPerformanceFrequencyLookupFunction();
}