sdlGetRenderClipRectFloat function render
Get the clip rectangle for the current target.
Each render target has its own clip rectangle. This function gets the cliprect for the current render target.
\param renderer the rendering context. \param rect an SDL_FRect structure filled in with the current clipping area or an empty rectangle if clipping is disabled. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function should only be called on the main thread.
\since This function is available since SDL 3.6.0.
\sa SDL_RenderClipEnabled \sa SDL_SetRenderClipRectFloat
extern SDL_DECLSPEC bool SDLCALL SDL_GetRenderClipRectFloat(SDL_Renderer *renderer, SDL_FRect *rect)
See also:
Implementation
bool sdlGetRenderClipRectFloat(
Pointer<SdlRenderer> renderer,
Pointer<SdlFRect> rect,
) {
final sdlGetRenderClipRectFloatLookupFunction = _libSdl
.lookupFunction<
Bool Function(Pointer<SdlRenderer> renderer, Pointer<SdlFRect> rect),
bool Function(Pointer<SdlRenderer> renderer, Pointer<SdlFRect> rect)
>('SDL_GetRenderClipRectFloat');
return sdlGetRenderClipRectFloatLookupFunction(renderer, rect);
}