sdlHasScreenKeyboardSupport function keyboard
Check whether the platform has screen keyboard support.
\returns true if the platform has some screen keyboard support or false if not.
\threadsafety This function should only be called on the main thread.
\since This function is available since SDL 3.2.0.
\sa SDL_StartTextInput \sa SDL_ScreenKeyboardShown
extern SDL_DECLSPEC bool SDLCALL SDL_HasScreenKeyboardSupport(void)
Implementation
bool sdlHasScreenKeyboardSupport() {
final sdlHasScreenKeyboardSupportLookupFunction = _libSdl
.lookupFunction<Bool Function(), bool Function()>(
'SDL_HasScreenKeyboardSupport',
);
return sdlHasScreenKeyboardSupportLookupFunction();
}