sdlIsPhone function system

bool sdlIsPhone()

Query if the current device is a phone.

If SDL can't determine this, it will return false.

\returns true if the device is a phone, false otherwise.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.6.0.

extern SDL_DECLSPEC bool SDLCALL SDL_IsPhone(void)

Implementation

bool sdlIsPhone() {
  final sdlIsPhoneLookupFunction = _libSdl
      .lookupFunction<Uint8 Function(), int Function()>('SDL_IsPhone');
  return sdlIsPhoneLookupFunction() == 1;
}