sdlLoadJpg function surface

Pointer<SdlSurface> sdlLoadJpg(
  1. String? file
)

Load a JPEG image from a file.

This is intended as a convenience function for loading images from trusted sources. If you want to load arbitrary images you should use libjpeg or another image loading library designed with security in mind.

The new surface should be freed with SDL_DestroySurface(). Not doing so will result in a memory leak.

\param file the JPG file to load. \returns a pointer to a new SDL_Surface structure or NULL on failure; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.6.0.

\sa SDL_DestroySurface \sa SDL_LoadJPG_IO

extern SDL_DECLSPEC SDL_Surface * SDLCALL SDL_LoadJPG(const char *file)

Implementation

Pointer<SdlSurface> sdlLoadJpg(String? file) {
  final sdlLoadJpgLookupFunction = _libSdl
      .lookupFunction<
        Pointer<SdlSurface> Function(Pointer<Utf8> file),
        Pointer<SdlSurface> Function(Pointer<Utf8> file)
      >('SDL_LoadJPG');
  final filePointer = file != null ? file.toNativeUtf8() : nullptr;
  final result = sdlLoadJpgLookupFunction(filePointer);
  calloc.free(filePointer);
  return result;
}