sdlRequestNotificationPermission function notification
Requests permission from the system to display notifications.
A return value of true only means that the system supports notifications,
and that the request for permission was successfully issued. It does not
reflect any user settings to allow or deny notifications.
\returns True on success or false on failure; call SDL_GetError() for more information.
\since This function is available since SDL 3.6.0.
\sa SDL_ShowNotification \sa SDL_ShowNotificationWithProperties \sa SDL_NotificationAction
extern SDL_DECLSPEC bool SDLCALL SDL_RequestNotificationPermission(void)
Implementation
bool sdlRequestNotificationPermission() {
final sdlRequestNotificationPermissionLookupFunction = _libSdl
.lookupFunction<Bool Function(), bool Function()>(
'SDL_RequestNotificationPermission',
);
return sdlRequestNotificationPermissionLookupFunction();
}