sdlSetTextureBlendMode function render
Set the blend mode for a texture, used by SDL_RenderTexture().
This blend mode is used for any drawing that involves this texture.
If the blend mode is not supported, the closest supported mode is chosen and this function returns false.
\param texture the texture to update. \param blendMode the SDL_BlendMode to use for texture blending. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function should only be called on the main thread.
\since This function is available since SDL 3.2.0.
\sa SDL_GetTextureBlendMode \sa SDL_SetRenderDrawBlendMode
extern SDL_DECLSPEC bool SDLCALL SDL_SetTextureBlendMode(SDL_Texture *texture, SDL_BlendMode blendMode)
Implementation
bool sdlSetTextureBlendMode(Pointer<SdlTexture> texture, int blendMode) {
final sdlSetTextureBlendModeLookupFunction = _libSdl
.lookupFunction<
Bool Function(Pointer<SdlTexture> texture, Uint32 blendMode),
bool Function(Pointer<SdlTexture> texture, int blendMode)
>('SDL_SetTextureBlendMode');
return sdlSetTextureBlendModeLookupFunction(texture, blendMode);
}