sdlSetiOsEventPump function system

void sdlSetiOsEventPump(
  1. bool enabled
)

Use this function to enable or disable the SDL event pump on Apple iOS.

This function is only available on Apple iOS.

\param enabled true to enable the event pump, false to disable it.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_SetiOSAnimationCallback

extern SDL_DECLSPEC void SDLCALL SDL_SetiOSEventPump(bool enabled)

Implementation

void sdlSetiOsEventPump(bool enabled) {
  final sdlSetiOsEventPumpLookupFunction = _libSdl
      .lookupFunction<Void Function(Uint8 enabled), void Function(int enabled)>(
        'SDL_SetiOSEventPump',
      );
  return sdlSetiOsEventPumpLookupFunction(enabled ? 1 : 0);
}