sdlTimeToWindows function time

void sdlTimeToWindows(
  1. int ticks,
  2. Pointer<Uint32> dwLowDateTime,
  3. Pointer<Uint32> dwHighDateTime
)

Converts an SDL time into a Windows FILETIME (100-nanosecond intervals since January 1, 1601).

This function fills in the two 32-bit values of the FILETIME structure.

\param ticks the time to convert. \param dwLowDateTime a pointer filled in with the low portion of the Windows FILETIME value. \param dwHighDateTime a pointer filled in with the high portion of the Windows FILETIME value.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC void SDLCALL SDL_TimeToWindows(SDL_Time ticks, Uint32 *dwLowDateTime, Uint32 *dwHighDateTime)

Implementation

void sdlTimeToWindows(
  int ticks,
  Pointer<Uint32> dwLowDateTime,
  Pointer<Uint32> dwHighDateTime,
) {
  final sdlTimeToWindowsLookupFunction = _libSdl
      .lookupFunction<
        Void Function(
          Int64 ticks,
          Pointer<Uint32> dwLowDateTime,
          Pointer<Uint32> dwHighDateTime,
        ),
        void Function(
          int ticks,
          Pointer<Uint32> dwLowDateTime,
          Pointer<Uint32> dwHighDateTime,
        )
      >('SDL_TimeToWindows');
  return sdlTimeToWindowsLookupFunction(ticks, dwLowDateTime, dwHighDateTime);
}