sdlUnlockMutex function mutex

void sdlUnlockMutex(
  1. Pointer<SdlMutex> mutex
)

Unlock the mutex.

It is legal for the owning thread to lock an already-locked mutex. It must unlock it the same number of times before it is actually made available for other threads in the system (this is known as a "recursive mutex").

It is illegal to unlock a mutex that has not been locked by the current thread, and doing so results in undefined behavior.

\param mutex the mutex to unlock.

\threadsafety This call must be paired with a previous locking call on the same thread.

\since This function is available since SDL 3.2.0.

\sa SDL_LockMutex \sa SDL_TryLockMutex

extern SDL_DECLSPEC void SDLCALL SDL_UnlockMutex(SDL_Mutex *mutex) SDL_RELEASE(mutex)

Implementation

void sdlUnlockMutex(Pointer<SdlMutex> mutex) {
  final sdlUnlockMutexLookupFunction = _libSdl
      .lookupFunction<
        Void Function(Pointer<SdlMutex> mutex),
        void Function(Pointer<SdlMutex> mutex)
      >('SDL_UnlockMutex');
  return sdlUnlockMutexLookupFunction(mutex);
}