sdlUnlockRwLock function mutex

void sdlUnlockRwLock(
  1. Pointer<SdlRwLock> rwlock
)

Unlock the read/write lock.

Use this function to unlock the rwlock, whether it was locked for read-only or write operations.

It is legal for the owning thread to lock an already-locked read-only lock. It must unlock it the same number of times before it is actually made available for other threads in the system (this is known as a "recursive rwlock").

It is illegal to unlock a rwlock that has not been locked by the current thread, and doing so results in undefined behavior.

\param rwlock the rwlock to unlock.

\threadsafety This call must be paired with a previous locking call on the same thread.

\since This function is available since SDL 3.2.0.

\sa SDL_LockRWLockForReading \sa SDL_LockRWLockForWriting \sa SDL_TryLockRWLockForReading \sa SDL_TryLockRWLockForWriting

extern SDL_DECLSPEC void SDLCALL SDL_UnlockRWLock(SDL_RWLock *rwlock) SDL_RELEASE_GENERIC(rwlock)

Implementation

void sdlUnlockRwLock(Pointer<SdlRwLock> rwlock) {
  final sdlUnlockRwLockLookupFunction = _libSdl
      .lookupFunction<
        Void Function(Pointer<SdlRwLock> rwlock),
        void Function(Pointer<SdlRwLock> rwlock)
      >('SDL_UnlockRWLock');
  return sdlUnlockRwLockLookupFunction(rwlock);
}