sdlUpdateJoysticks function joystick

void sdlUpdateJoysticks()

Update the current state of the open joysticks.

This is called automatically by the event loop if any joystick events are enabled and SDL_HINT_AUTO_UPDATE_JOYSTICKS hasn't been set to "0".

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC void SDLCALL SDL_UpdateJoysticks(void)

Implementation

void sdlUpdateJoysticks() {
  final sdlUpdateJoysticksLookupFunction = _libSdl
      .lookupFunction<Void Function(), void Function()>('SDL_UpdateJoysticks');
  return sdlUpdateJoysticksLookupFunction();
}