sdlWasInit function init

int sdlWasInit(
  1. int flags
)

Get a mask of the specified subsystems which are currently initialized.

\param flags any of the flags used by SDL_Init(); see SDL_Init for details. \returns a mask of all initialized subsystems if flags is 0, otherwise it returns the initialization status of the specified subsystems.

\threadsafety This function is not thread safe.

\since This function is available since SDL 3.2.0.

\sa SDL_Init \sa SDL_InitSubSystem

extern SDL_DECLSPEC SDL_InitFlags SDLCALL SDL_WasInit(SDL_InitFlags flags)

Implementation

int sdlWasInit(int flags) {
  final sdlWasInitLookupFunction = _libSdl
      .lookupFunction<Uint32 Function(Uint32 flags), int Function(int flags)>(
        'SDL_WasInit',
      );
  return sdlWasInitLookupFunction(flags);
}