sdlxBindGpuIndexBuffer function gpu

void sdlxBindGpuIndexBuffer(
  1. Pointer<SdlGpuRenderPass> renderPass,
  2. SdlxGpuBufferBinding binding,
  3. int indexElementSize
)

Binds an index buffer on a command buffer for use with subsequent draw calls.

\param render_pass a render pass handle. \param binding a pointer to a struct containing an index buffer and offset. \param index_element_size whether the index values in the buffer are 16- or 32-bit.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC void SDLCALL SDL_BindGPUIndexBuffer( SDL_GPURenderPass *render_pass, const SDL_GPUBufferBinding *binding, SDL_GPUIndexElementSize index_element_size)

Implementation

void sdlxBindGpuIndexBuffer(
  Pointer<SdlGpuRenderPass> renderPass,
  SdlxGpuBufferBinding binding,
  int indexElementSize,
) {
  final bindingPointer = binding.calloc();
  sdlBindGpuIndexBuffer(renderPass, bindingPointer, indexElementSize);
  bindingPointer.callocFree();
}