sdlxCreateGpuGraphicsPipeline function gpu

Pointer<SdlGpuGraphicsPipeline> sdlxCreateGpuGraphicsPipeline(
  1. Pointer<SdlGpuDevice> device,
  2. SdlxGpuGraphicsPipelineCreateInfo info
)

Creates a pipeline object to be used in a graphics workflow.

There are optional properties that can be provided through props. These are the supported properties:

  • SDL_PROP_GPU_GRAPHICSPIPELINE_CREATE_NAME_STRING: a name that can be displayed in debugging tools.

\param device a GPU Context. \param createinfo a struct describing the state of the graphics pipeline to create. \returns a graphics pipeline object on success, or NULL on failure; call SDL_GetError() for more information.

\since This function is available since SDL 3.2.0.

\sa SDL_CreateGPUShader \sa SDL_BindGPUGraphicsPipeline \sa SDL_ReleaseGPUGraphicsPipeline

extern SDL_DECLSPEC SDL_GPUGraphicsPipeline * SDLCALL SDL_CreateGPUGraphicsPipeline( SDL_GPUDevice *device, const SDL_GPUGraphicsPipelineCreateInfo *createinfo)

Implementation

Pointer<SdlGpuGraphicsPipeline> sdlxCreateGpuGraphicsPipeline(
  Pointer<SdlGpuDevice> device,
  SdlxGpuGraphicsPipelineCreateInfo info,
) {
  Pointer<SdlGpuGraphicsPipeline> result;
  final pointer = info.calloc();
  result = sdlCreateGpuGraphicsPipeline(device, pointer);
  pointer.callocAllFree();
  return result;
}