sdlxCreateGpuSampler function gpu

Pointer<SdlGpuSampler> sdlxCreateGpuSampler(
  1. Pointer<SdlGpuDevice> device,
  2. SdlxGpuSamplerCreateInfo createinfo
)

Creates a sampler object to be used when binding textures in a graphics workflow.

There are optional properties that can be provided through props. These are the supported properties:

  • SDL_PROP_GPU_SAMPLER_CREATE_NAME_STRING: a name that can be displayed in debugging tools.

\param device a GPU Context. \param createinfo a struct describing the state of the sampler to create. \returns a sampler object on success, or NULL on failure; call SDL_GetError() for more information.

\since This function is available since SDL 3.2.0.

\sa SDL_BindGPUVertexSamplers \sa SDL_BindGPUFragmentSamplers \sa SDL_ReleaseGPUSampler

extern SDL_DECLSPEC SDL_GPUSampler * SDLCALL SDL_CreateGPUSampler( SDL_GPUDevice *device, const SDL_GPUSamplerCreateInfo *createinfo)

Implementation

Pointer<SdlGpuSampler> sdlxCreateGpuSampler(
  Pointer<SdlGpuDevice> device,
  SdlxGpuSamplerCreateInfo createinfo,
) {
  Pointer<SdlGpuSampler> result;
  final pointer = createinfo.calloc();
  result = sdlCreateGpuSampler(device, pointer);
  pointer.callocFree();
  return result;
}