sdlxGetClipboardText function clipboard

String? sdlxGetClipboardText()

Get UTF-8 text from the clipboard.

This function returns an empty string if there is not enough memory left for a copy of the clipboard's content.

\returns the clipboard text on success or an empty string on failure; call SDL_GetError() for more information. This should be freed with SDL_free() when it is no longer needed.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_HasClipboardText \sa SDL_SetClipboardText

extern SDL_DECLSPEC char * SDLCALL SDL_GetClipboardText(void)

Implementation

String? sdlxGetClipboardText() {
  final result = sdlGetClipboardText();
  if (result == nullptr) {
    return null;
  }
  final text = result.cast<Utf8>().toDartString();
  sdlFree(result.cast<Void>());
  return text;
}