sdlxGetCurrentRenderOutputSize function render
Get the current output size in pixels of a rendering context.
If a rendering target is active, this will return the size of the rendering target in pixels, otherwise return the value of SDL_GetRenderOutputSize().
Rendering target or not, the output will be adjusted by the current logical presentation state, dictated by SDL_SetRenderLogicalPresentation().
\param renderer the rendering context. \param w a pointer filled in with the current width. \param h a pointer filled in with the current height. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function should only be called on the main thread.
\since This function is available since SDL 3.2.0.
\sa SDL_GetRenderOutputSize
extern SDL_DECLSPEC bool SDLCALL SDL_GetCurrentRenderOutputSize(SDL_Renderer *renderer, int *w, int *h)
Implementation
bool sdlxGetCurrentRenderOutputSize(
Pointer<SdlRenderer> renderer,
SdlxPoint size,
) {
final wPointer = ffi.calloc<Int32>();
final hPointer = ffi.calloc<Int32>();
final result = sdlGetCurrentRenderOutputSize(renderer, wPointer, hPointer);
size
..x = wPointer.value
..y = hPointer.value;
wPointer.callocFree();
hPointer.callocFree();
return result;
}