sdlxGetRectUnion function rect

bool sdlxGetRectUnion(
  1. SdlxRect a,
  2. SdlxRect b,
  3. SdlxRect result
)

Calculate the union of two rectangles.

\param A an SDL_Rect structure representing the first rectangle. \param B an SDL_Rect structure representing the second rectangle. \param result an SDL_Rect structure filled in with the union of rectangles A and B. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC bool SDLCALL SDL_GetRectUnion(const SDL_Rect *A, const SDL_Rect *B, SDL_Rect *result)

Implementation

bool sdlxGetRectUnion(SdlxRect a, SdlxRect b, SdlxRect result) {
  final aPointer = a.calloc();
  final bPointer = b.calloc();
  final resultPointer = ffi.calloc<SdlRect>();
  final bl = sdlGetRectUnion(aPointer, bPointer, resultPointer);
  if (bl) {
    result.loadFromPointer(resultPointer);
  }
  aPointer.callocFree();
  bPointer.callocFree();
  resultPointer.callocFree();
  return bl;
}