sdlxGetRectUnionFloat function rect

bool sdlxGetRectUnionFloat(
  1. SdlxFRect a,
  2. SdlxFRect b,
  3. SdlxFRect result
)

Calculate the union of two rectangles with float precision.

\param A an SDL_FRect structure representing the first rectangle. \param B an SDL_FRect structure representing the second rectangle. \param result an SDL_FRect structure filled in with the union of rectangles A and B. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC bool SDLCALL SDL_GetRectUnionFloat(const SDL_FRect *A, const SDL_FRect *B, SDL_FRect *result)

Implementation

bool sdlxGetRectUnionFloat(SdlxFRect a, SdlxFRect b, SdlxFRect result) {
  final aPointer = a.calloc();
  final bPointer = b.calloc();
  final resultPointer = ffi.calloc<SdlFRect>();
  final bl = sdlGetRectUnionFloat(aPointer, bPointer, resultPointer);
  if (bl) {
    result.loadFromPointer(resultPointer);
  }
  aPointer.callocFree();
  bPointer.callocFree();
  resultPointer.callocFree();
  return bl;
}