sdlxGetRenderColorScale function render

double? sdlxGetRenderColorScale(
  1. Pointer<SdlRenderer> renderer
)

Get the color scale used for render operations.

\param renderer the rendering context. \param scale a pointer filled in with the current color scale value. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_SetRenderColorScale

extern SDL_DECLSPEC bool SDLCALL SDL_GetRenderColorScale(SDL_Renderer *renderer, float *scale)

Implementation

double? sdlxGetRenderColorScale(Pointer<SdlRenderer> renderer) {
  double? result;
  final scalePointer = ffi.calloc<Float>();
  final bl = sdlGetRenderColorScale(renderer, scalePointer);
  if (bl) {
    result = scalePointer.value;
  }
  scalePointer.callocFree();
  return result;
}