sdlxGetTextureAlphaMod function render

int? sdlxGetTextureAlphaMod(
  1. Pointer<SdlTexture> texture
)

Get the additional alpha value multiplied into render copy operations.

\param texture the texture to query. \param alpha a pointer filled in with the current alpha value. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_GetTextureAlphaModFloat \sa SDL_GetTextureColorMod \sa SDL_SetTextureAlphaMod

extern SDL_DECLSPEC bool SDLCALL SDL_GetTextureAlphaMod(SDL_Texture *texture, Uint8 *alpha)

Implementation

int? sdlxGetTextureAlphaMod(Pointer<SdlTexture> texture) {
  int? result;
  final alphaPointer = calloc<Uint8>();
  final bl = sdlGetTextureAlphaMod(texture, alphaPointer);
  if (bl) {
    result = alphaPointer.value;
  }
  alphaPointer.callocFree();
  return result;
}