sdlxGetTextureAlphaModFloat function render

double? sdlxGetTextureAlphaModFloat(
  1. Pointer<SdlTexture> texture
)

Get the additional alpha value multiplied into render copy operations.

\param texture the texture to query. \param alpha a pointer filled in with the current alpha value. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_GetTextureAlphaMod \sa SDL_GetTextureColorModFloat \sa SDL_SetTextureAlphaModFloat

extern SDL_DECLSPEC bool SDLCALL SDL_GetTextureAlphaModFloat(SDL_Texture *texture, float *alpha)

Implementation

double? sdlxGetTextureAlphaModFloat(Pointer<SdlTexture> texture) {
  double? result;
  final alphaPointer = calloc<Float>();
  final bl = sdlGetTextureAlphaModFloat(texture, alphaPointer);
  if (bl) {
    result = alphaPointer.value;
  }
  alphaPointer.callocFree();
  return result;
}