sdlxGetTextureBlendMode function render
Get the blend mode used for texture copy operations.
\param texture the texture to query. \param blendMode a pointer filled in with the current SDL_BlendMode. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function should only be called on the main thread.
\since This function is available since SDL 3.2.0.
\sa SDL_SetTextureBlendMode
extern SDL_DECLSPEC bool SDLCALL SDL_GetTextureBlendMode(SDL_Texture *texture, SDL_BlendMode *blendMode)
Implementation
int? sdlxGetTextureBlendMode(Pointer<SdlTexture> texture) {
int? result;
final blendModePointer = calloc<Uint32>();
final bl = sdlGetTextureBlendMode(texture, blendModePointer);
if (bl) {
result = blendModePointer.value;
}
blendModePointer.callocFree();
return result;
}