sdlxReadU8 function iostream

int? sdlxReadU8(
  1. Pointer<SdlIoStream> src
)

Use this function to read a byte from an SDL_IOStream.

This function will return false when the data stream is completely read, and SDL_GetIOStatus() will return SDL_IO_STATUS_EOF. If false is returned and the stream is not at EOF, SDL_GetIOStatus() will return a different error value and SDL_GetError() will offer a human-readable message.

\param src the SDL_IOStream to read from. \param value a pointer filled in with the data read. \returns true on success or false on failure or EOF; call SDL_GetError() for more information.

\threadsafety Do not use the same SDL_IOStream from two threads at once.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC bool SDLCALL SDL_ReadU8(SDL_IOStream *src, Uint8 *value)

Implementation

int? sdlxReadU8(Pointer<SdlIoStream> src) {
  int? result;
  final pointer = ffi.calloc<Uint8>();
  final bl = sdlReadU8(src, pointer);
  if (bl) {
    result = pointer.value;
  }
  pointer.callocFree();
  return result;
}