sdlxRenderFillRects function render

bool sdlxRenderFillRects(
  1. Pointer<SdlRenderer> renderer,
  2. List<SdlxFRect> rects
)

Fill some number of rectangles on the current rendering target with the drawing color at subpixel precision.

\param renderer the renderer which should fill multiple rectangles. \param rects a pointer to an array of destination rectangles. \param count the number of rectangles. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_RenderFillRect

extern SDL_DECLSPEC bool SDLCALL SDL_RenderFillRects(SDL_Renderer *renderer, const SDL_FRect *rects, int count)

Implementation

bool sdlxRenderFillRects(Pointer<SdlRenderer> renderer, List<SdlxFRect> rects) {
  final rectsPointer = rects.calloc();
  final result = sdlRenderFillRects(renderer, rectsPointer, rects.length);
  rectsPointer.callocFree();
  return result;
}