sdlxSetWindowMinimumSize function video

bool sdlxSetWindowMinimumSize(
  1. Pointer<SdlWindow> window,
  2. SdlxPoint minSize
)

Set the minimum size of a window's client area.

\param window the window to change. \param min_w the minimum width of the window, or 0 for no limit. \param min_h the minimum height of the window, or 0 for no limit. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_GetWindowMinimumSize \sa SDL_SetWindowMaximumSize

extern SDL_DECLSPEC bool SDLCALL SDL_SetWindowMinimumSize(SDL_Window *window, int min_w, int min_h)

Implementation

bool sdlxSetWindowMinimumSize(Pointer<SdlWindow> window, SdlxPoint minSize) =>
    sdlSetWindowMinimumSize(window, minSize.x, minSize.y);