sdlxWaitEvent function events

SdlxEvent? sdlxWaitEvent()

Wait indefinitely for the next available event.

If event is not NULL, the next event is removed from the queue and stored in the SDL_Event structure pointed to by event.

As this function may implicitly call SDL_PumpEvents(), you can only call this function in the thread that initialized the video subsystem.

\param event the SDL_Event structure to be filled in with the next event from the queue, or NULL. \returns true on success or false if there was an error while waiting for events; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_PollEvent \sa SDL_PushEvent \sa SDL_WaitEventTimeout

extern SDL_DECLSPEC bool SDLCALL SDL_WaitEvent(SDL_Event *event)

Implementation

SdlxEvent? sdlxWaitEvent() {
  SdlxEvent? result;
  final pointer = calloc<SdlEvent>();
  final bl = sdlWaitEvent(pointer);
  if (bl) {
    result = SdlxEvent.fromPointer(pointer);
  }
  calloc.free(pointer);
  return result;
}