sdlxWriteSurfacePixelFloat function surface
Writes a single pixel to a surface.
This function prioritizes correctness over speed: it is suitable for unit tests, but is not intended for use in a game engine.
\param surface the surface to write. \param x the horizontal coordinate, 0 <= x < width. \param y the vertical coordinate, 0 <= y < height. \param r the red channel value, normally in the range 0-1. \param g the green channel value, normally in the range 0-1. \param b the blue channel value, normally in the range 0-1. \param a the alpha channel value, normally in the range 0-1. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function can be called on different threads with different surfaces.
\since This function is available since SDL 3.2.0.
extern SDL_DECLSPEC bool SDLCALL SDL_WriteSurfacePixelFloat(SDL_Surface *surface, int x, int y, float r, float g, float b, float a)
Implementation
bool sdlxWriteSurfacePixelFloat(
Pointer<SdlSurface> surface,
SdlxPoint point,
SdlxFColor color,
) => sdlWriteSurfacePixelFloat(
surface,
point.x,
point.y,
color.r,
color.g,
color.b,
color.a,
);