sdl3/sdl_asyncio library

Functions

sdlAsyncIoFromFile(String? file, String? mode) → Pointer<SdlAsyncIo> asyncio
Use this function to create a new SDL_AsyncIO object for reading from and/or writing to a named file.
sdlCloseAsyncIo(Pointer<SdlAsyncIo> asyncio, bool flush, Pointer<SdlAsyncIoQueue> queue, Pointer<Void> userdata) → bool asyncio
Close and free any allocated resources for an async I/O object.
sdlCreateAsyncIoQueue() → Pointer<SdlAsyncIoQueue> asyncio
Create a task queue for tracking multiple I/O operations.
sdlDestroyAsyncIoQueue(Pointer<SdlAsyncIoQueue> queue) → void asyncio
Destroy a previously-created async I/O task queue.
sdlGetAsyncIoResult(Pointer<SdlAsyncIoQueue> queue, Pointer<SdlAsyncIoOutcome> outcome) → bool asyncio
Query an async I/O task queue for completed tasks.
sdlGetAsyncIoSize(Pointer<SdlAsyncIo> asyncio) → int asyncio
Use this function to get the size of the data stream in an SDL_AsyncIO.
sdlLoadFileAsync(String? file, Pointer<SdlAsyncIoQueue> queue, Pointer<Void> userdata) → bool asyncio
Load all the data from a file path, asynchronously.
sdlReadAsyncIo(Pointer<SdlAsyncIo> asyncio, Pointer<Void> ptr, int offset, int size, Pointer<SdlAsyncIoQueue> queue, Pointer<Void> userdata) → bool asyncio
Start an async read.
sdlSignalAsyncIoQueue(Pointer<SdlAsyncIoQueue> queue) → void asyncio
Wake up any threads that are blocking in SDL_WaitAsyncIOResult().
sdlWaitAsyncIoResult(Pointer<SdlAsyncIoQueue> queue, Pointer<SdlAsyncIoOutcome> outcome, int timeoutMs) → bool asyncio
Block until an async I/O task queue has a completed task.
sdlWriteAsyncIo(Pointer<SdlAsyncIo> asyncio, Pointer<Void> ptr, int offset, int size, Pointer<SdlAsyncIoQueue> queue, Pointer<Void> userdata) → bool asyncio
Start an async write.
sdlxGetAsyncIoResult(Pointer<SdlAsyncIoQueue> queue) → SdlxAsyncIoOutcome? asyncio
Query an async I/O task queue for completed tasks.
sdlxWaitAsyncIoResult(Pointer<SdlAsyncIoQueue> queue, int timeoutMS) → SdlxAsyncIoOutcome? asyncio
Block until an async I/O task queue has a completed task.