sdl3/sdl_camera library

Classes

SdlxCameraSpec

Functions

sdlAcquireCameraFrame(Pointer<SdlCamera> camera, Pointer<Uint64> timestampNs) → Pointer<SdlSurface> camera
Acquire a frame.
sdlCloseCamera(Pointer<SdlCamera> camera) → void camera
Use this function to shut down camera processing and close the camera device.
sdlGetCameraDriver(int index) → String? camera
Use this function to get the name of a built in camera driver.
sdlGetCameraFormat(Pointer<SdlCamera> camera, Pointer<SdlCameraSpec> spec) → bool camera
Get the spec that a camera is using when generating images.
sdlGetCameraId(Pointer<SdlCamera> camera) → int camera
Get the instance ID of an opened camera.
sdlGetCameraName(int instanceId) → String? camera
Get the human-readable device name for a camera.
sdlGetCameraPermissionState(Pointer<SdlCamera> camera) → int camera
Query if camera access has been approved by the user.
sdlGetCameraPosition(int instanceId) → int camera
Get the position of the camera in relation to the system.
sdlGetCameraProperties(Pointer<SdlCamera> camera) → int camera
Get the properties associated with an opened camera.
sdlGetCameras(Pointer<Int32> count) → Pointer<Uint32> camera
Get a list of currently connected camera devices.
sdlGetCameraSupportedFormats(int instanceId, Pointer<Int32> count) → Pointer<Pointer<SdlCameraSpec>> camera
Get the list of native formats/sizes a camera supports.
sdlGetCurrentCameraDriver() → String? camera
Get the name of the current camera driver.
sdlGetNumCameraDrivers() → int camera
Use this function to get the number of built-in camera drivers.
sdlOpenCamera(int instanceId, Pointer<SdlCameraSpec> spec) → Pointer<SdlCamera> camera
Open a video recording device (a "camera").
sdlReleaseCameraFrame(Pointer<SdlCamera> camera, Pointer<SdlSurface> frame) → void camera
Release a frame of video acquired from a camera.
sdlxAcquireCameraFrame(Pointer<SdlCamera> camera) → ({Pointer<SdlSurface> surface, int timestampNs})? camera
Acquire a frame.
sdlxGetCameraFormat(Pointer<SdlCamera> camera) → SdlxCameraSpec? camera
Get the spec that a camera is using when generating images.
sdlxGetCameras() → List<int> camera
Get a list of currently connected camera devices.
sdlxGetCameraSupportedFormats(int instanceId) → List<SdlxCameraSpec> camera
Get the list of native formats/sizes a camera supports.
sdlxOpenCamera(int instanceId, [SdlxCameraSpec? spec]) → Pointer<SdlCamera> camera
Open a video recording device (a "camera").