sdl3/sdl_filesystem
library
Functions
-
sdlCopyFile(String? oldpath, String? newpath)
→ bool
filesystem
-
Copy a file.
-
sdlCreateDirectory(String? path)
→ bool
filesystem
-
Create a directory, and any missing parent directories.
-
sdlEnumerateDirectory(String? path, Pointer<NativeFunction<SdlEnumerateDirectoryCallback>> callback, Pointer<Void> userdata)
→ bool
filesystem
-
Enumerate a directory through a callback function.
-
sdlGetBasePath()
→ String?
filesystem
-
Get the directory where the application was run from.
-
sdlGetCurrentDirectory()
→ Pointer<Int8>
filesystem
-
Get what the system believes is the "current working directory."
-
sdlGetPathInfo(String? path, Pointer<SdlPathInfo> info)
→ bool
filesystem
-
Get information about a filesystem path.
-
sdlGetPrefPath(String? org, String? app)
→ Pointer<Int8>
filesystem
-
Get the user-and-app-specific path where files can be written.
-
sdlGetUserFolder(int folder)
→ String?
filesystem
-
Finds the most suitable user folder for a specific purpose.
-
sdlGlobDirectory(String? path, String? pattern, int flags, Pointer<Int32> count)
→ Pointer<Pointer<Int8>>
filesystem
-
Enumerate a directory tree, filtered by pattern, and return a list.
-
sdlRemovePath(String? path)
→ bool
filesystem
-
Remove a file or an empty directory.
-
sdlRenamePath(String? oldpath, String? newpath)
→ bool
filesystem
-
Rename a file or directory.
-
sdlxGetPrefPath(String? org, String? app)
→ String?
filesystem
-
Get the user-and-app-specific path where files can be written.
-
sdlxGlobDirectory(String path, {String? pattern, int flags = 0})
→ List<String>
filesystem
-
Enumerate a directory tree, filtered by pattern, and return a list.