releaseShader method

void releaseShader(
  1. Pointer<SdlGpuShader> shader
)

Frees the given shader as soon as it is safe to do so.

You must not reference the shader after calling this function.

It is safe to pass NULL for shader, in that case this function is a no-op.

\param device a GPU context. \param shader a shader to be destroyed.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC void SDLCALL SDL_ReleaseGPUShader( SDL_GPUDevice *device, SDL_GPUShader *shader)

See also:

Implementation

void releaseShader(Pointer<SdlGpuShader> shader) =>
    sdlReleaseGpuShader(this, shader);