textureSupportsSampleCount method

bool textureSupportsSampleCount(
  1. int format,
  2. int sampleCount
)

Determines if a sample count for a texture format is supported.

\param device a GPU context. \param format the texture format to check. \param sample_count the sample count to check. \returns whether the sample count is supported for this texture format.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC bool SDLCALL SDL_GPUTextureSupportsSampleCount( SDL_GPUDevice *device, SDL_GPUTextureFormat format, SDL_GPUSampleCount sample_count)

See also:

Implementation

bool textureSupportsSampleCount(int format, int sampleCount) =>
    sdlGpuTextureSupportsSampleCount(this, format, sampleCount);