bindVertexSamplers method
Binds texture-sampler pairs for use on the vertex shader.
The textures must have been created with SDL_GPU_TEXTUREUSAGE_SAMPLER.
The textures being bound must have a matching type declared in the shader (2D, 3D, etc.). Multisample textures are not allowed.
Be sure your shader is set up according to the requirements documented in SDL_CreateGPUShader().
\param render_pass a render pass handle. \param first_slot the vertex sampler slot to begin binding from. \param texture_sampler_bindings an array of texture-sampler binding structs. \param num_bindings the number of texture-sampler pairs to bind from the array.
\since This function is available since SDL 3.2.0.
\sa SDL_CreateGPUShader
extern SDL_DECLSPEC void SDLCALL SDL_BindGPUVertexSamplers( SDL_GPURenderPass *render_pass, Uint32 first_slot, const SDL_GPUTextureSamplerBinding *texture_sampler_bindings, Uint32 num_bindings)
See also:
Implementation
void bindVertexSamplers(
List<SdlxGpuTextureSamplerBinding> bindings, {
int firstSlot = 0,
}) => sdlxBindGpuVertexSamplers(this, bindings, firstSlot: firstSlot);