SdlxGpuBufferCreateInfo class

Constructors

SdlxGpuBufferCreateInfo({int usage = 0, int size = 0, int props = 0})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
final
usage → int
final

Methods

calloc() → Pointer<SdlGpuBufferCreateInfo>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited