SdlxGpuComputePipelineCreateInfo class

Constructors

SdlxGpuComputePipelineCreateInfo({Uint8List? code, String entrypoint = '', int format = 0, int numSamplers = 0, int numReadonlyStorageTextures = 0, int numReadonlyStorageBuffers = 0, int numReadwriteStorageTextures = 0, int numReadwriteStorageBuffers = 0, int numUniformBuffers = 0, int threadcountX = 0, int threadcountY = 0, int threadcountZ = 0, int props = 0})

Properties

code → Uint8List
final
entrypoint → String
final
format → int
final
hashCode → int
The hash code for this object.
no setterinherited
numReadonlyStorageBuffers → int
final
numReadonlyStorageTextures → int
final
numReadwriteStorageBuffers → int
final
numReadwriteStorageTextures → int
final
numSamplers → int
final
numUniformBuffers → int
final
props → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadcountX → int
final
threadcountY → int
final
threadcountZ → int
final

Methods

calloc() → Pointer<SdlGpuComputePipelineCreateInfo>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited