SdlxGpuRasterizerState class

Constructors

SdlxGpuRasterizerState({int fillMode = 0, int cullMode = 0, int frontFace = 0, double depthBiasAntFactor = 0, double depthBiasClamp = 0, double depthBiasSlopeFactor = 0, bool enableDepthBias = false, bool enableDepthClip = false})
const

Properties

cullMode → int
final
depthBiasAntFactor → double
final
depthBiasClamp → double
final
depthBiasSlopeFactor → double
final
enableDepthBias → bool
final
enableDepthClip → bool
final
fillMode → int
final
frontFace → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited