SdlxGpuSamplerCreateInfo class
Constructors
- SdlxGpuSamplerCreateInfo({int minFilter = 0, int magFilter = 0, int mipmapMode = 0, int addressModeU = 0, int addressModeV = 0, int addressModeW = 0, double mipLodBias = 0, double maxAnisotropy = 0, int compareOp = 0, double minLod = 0, double maxLod = 0, bool enableAnisotropy = false, bool enableCompare = false, int padding1 = 0, int padding2 = 0, int props = 0})
-
const
Properties
- addressModeU → int
-
final
- addressModeV → int
-
final
- addressModeW → int
-
final
- compareOp → int
-
final
- enableAnisotropy → bool
-
final
- enableCompare → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- magFilter → int
-
final
- maxAnisotropy → double
-
final
- maxLod → double
-
final
- minFilter → int
-
final
- minLod → double
-
final
- mipLodBias → double
-
final
- mipmapMode → int
-
final
- padding1 → int
-
final
- padding2 → int
-
final
- props → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
calloc(
) → Pointer< SdlGpuSamplerCreateInfo> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited