SdlxGpuTextureLocation class

Constructors

SdlxGpuTextureLocation({Pointer<SdlGpuTexture>? texture, int mipLevel = 0, int layer = 0, int x = 0, int y = 0, int z = 0})

Properties

hashCode → int
The hash code for this object.
no setterinherited
layer → int
final
mipLevel → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texture → Pointer<SdlGpuTexture>
final
x → int
final
y → int
final
z → int
final

Methods

calloc() → Pointer<SdlGpuTextureLocation>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited