sdl3/sdl_haptic library

Functions

sdlCloseHaptic(Pointer<SdlHaptic> haptic) → void haptic
Close a haptic device previously opened with SDL_OpenHaptic().
sdlCreateHapticEffect(Pointer<SdlHaptic> haptic, Pointer<SdlHapticEffect> effect) → int haptic
Create a new haptic effect on a specified device.
sdlDestroyHapticEffect(Pointer<SdlHaptic> haptic, int effect) → void haptic
Destroy a haptic effect on the device.
sdlGetHapticEffectStatus(Pointer<SdlHaptic> haptic, int effect) → bool haptic
Get the status of the current effect on the specified haptic device.
sdlGetHapticFeatures(Pointer<SdlHaptic> haptic) → int haptic
Get the haptic device's supported features in bitwise manner.
sdlGetHapticFromId(int instanceId) → Pointer<SdlHaptic> haptic
Get the SDL_Haptic associated with an instance ID, if it has been opened.
sdlGetHapticId(Pointer<SdlHaptic> haptic) → int haptic
Get the instance ID of an opened haptic device.
sdlGetHapticName(Pointer<SdlHaptic> haptic) → String? haptic
Get the implementation dependent name of a haptic device.
sdlGetHapticNameForId(int instanceId) → String? haptic
Get the implementation dependent name of a haptic device.
sdlGetHaptics(Pointer<Int32> count) → Pointer<Uint32> haptic
Get a list of currently connected haptic devices.
sdlGetMaxHapticEffects(Pointer<SdlHaptic> haptic) → int haptic
Get the number of effects a haptic device can store.
sdlGetMaxHapticEffectsPlaying(Pointer<SdlHaptic> haptic) → int haptic
Get the number of effects a haptic device can play at the same time.
sdlGetNumHapticAxes(Pointer<SdlHaptic> haptic) → int haptic
Get the number of haptic axes the device has.
sdlHapticEffectSupported(Pointer<SdlHaptic> haptic, Pointer<SdlHapticEffect> effect) → bool haptic
Check to see if an effect is supported by a haptic device.
sdlHapticRumbleSupported(Pointer<SdlHaptic> haptic) → bool haptic
Check whether rumble is supported on a haptic device.
sdlInitHapticRumble(Pointer<SdlHaptic> haptic) → bool haptic
Initialize a haptic device for simple rumble playback.
sdlIsJoystickHaptic(Pointer<SdlJoystick> joystick) → bool haptic
Query if a joystick has haptic features.
sdlIsMouseHaptic() → bool haptic
Query whether or not the current mouse has haptic capabilities.
sdlOpenHaptic(int instanceId) → Pointer<SdlHaptic> haptic
Open a haptic device for use.
sdlOpenHapticFromJoystick(Pointer<SdlJoystick> joystick) → Pointer<SdlHaptic> haptic
Open a haptic device for use from a joystick device.
sdlOpenHapticFromMouse() → Pointer<SdlHaptic> haptic
Try to open a haptic device from the current mouse.
sdlPauseHaptic(Pointer<SdlHaptic> haptic) → bool haptic
Pause a haptic device.
sdlPlayHapticRumble(Pointer<SdlHaptic> haptic, double strength, int length) → bool haptic
Run a simple rumble effect on a haptic device.
sdlResumeHaptic(Pointer<SdlHaptic> haptic) → bool haptic
Resume a haptic device.
sdlRunHapticEffect(Pointer<SdlHaptic> haptic, int effect, int iterations) → bool haptic
Run the haptic effect on its associated haptic device.
sdlSetHapticAutocenter(Pointer<SdlHaptic> haptic, int autocenter) → bool haptic
Set the global autocenter of the device.
sdlSetHapticGain(Pointer<SdlHaptic> haptic, int gain) → bool haptic
Set the global gain of the specified haptic device.
sdlStopHapticEffect(Pointer<SdlHaptic> haptic, int effect) → bool haptic
Stop the haptic effect on its associated haptic device.
sdlStopHapticEffects(Pointer<SdlHaptic> haptic) → bool haptic
Stop all the currently playing effects on a haptic device.
sdlStopHapticRumble(Pointer<SdlHaptic> haptic) → bool haptic
Stop the simple rumble on a haptic device.
sdlUpdateHapticEffect(Pointer<SdlHaptic> haptic, int effect, Pointer<SdlHapticEffect> data) → bool haptic
Update the properties of an effect.
sdlxCreateHapticEffect(Pointer<SdlHaptic> haptic, SdlxHapticEffect effect) → int haptic
Create a new haptic effect on a specified device.
sdlxGetHaptics() → List<int> haptic
Get a list of currently connected haptic devices.
sdlxHapticEffectSupported(Pointer<SdlHaptic> haptic, SdlxHapticEffect effect) → bool haptic
Check to see if an effect is supported by a haptic device.
sdlxUpdateHapticEffect(Pointer<SdlHaptic> haptic, int effect, SdlxHapticEffect data) → bool haptic
Update the properties of an effect.