SdlxHapticDirection class final

Constructors

SdlxHapticDirection({int type = 0, List<int> dir = const [0, 0, 0]})
const
SdlxHapticDirection.fromRef(SdlHapticDirection ref)
factory

Properties

dir → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → int
final

Methods

copyTo(SdlHapticDirection ref) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited