ImgAnimationDecoderEx extension

on

Static Methods

create(String file) Pointer<ImgAnimationDecoder> image

Available on ImgAnimationDecoder, provided by the ImgAnimationDecoderEx extension

Create a decoder to read a series of images from a file.
createIo(Pointer<SdlIoStream> src, String type, {bool closeio = false}) Pointer<ImgAnimationDecoder> image

Available on ImgAnimationDecoder, provided by the ImgAnimationDecoderEx extension

Create a decoder to read a series of images from an IOStream.
createWithProperties(int props) Pointer<ImgAnimationDecoder> image

Available on ImgAnimationDecoder, provided by the ImgAnimationDecoderEx extension

Create an animation decoder with the specified properties.