getStatus method

int getStatus()

Get the decoder status indicating the current state of the decoder.

\param decoder the decoder to get the status of. \returns the status of the underlying decoder, or IMG_DECODER_STATUS_INVALID if the given decoder is invalid.

\since This function is available since SDL_image 3.4.0.

\sa IMG_GetAnimationDecoderFrame

extern SDL_DECLSPEC IMG_AnimationDecoderStatus SDLCALL IMG_GetAnimationDecoderStatus(IMG_AnimationDecoder *decoder)

Implementation

int getStatus() => imgGetAnimationDecoderStatus(this);