ImgAnimationEncoderEx extension

on

Static Methods

create(String file) Pointer<ImgAnimationEncoder> image

Available on ImgAnimationEncoder, provided by the ImgAnimationEncoderEx extension

Create an encoder to save a series of images to a file.
createIo(Pointer<SdlIoStream> dst, String type, {bool closeio = false}) Pointer<ImgAnimationEncoder> image

Available on ImgAnimationEncoder, provided by the ImgAnimationEncoderEx extension

Create an encoder to save a series of images to an IOStream.
createWithProperties(int props) Pointer<ImgAnimationEncoder> image

Available on ImgAnimationEncoder, provided by the ImgAnimationEncoderEx extension

Create an animation encoder with the specified properties.