addFrame method
Add a frame to an animation encoder.
\param encoder the receiving images.
\param surface the surface to add as the next frame in the animation.
\param duration the duration of the frame, usually in milliseconds but can
be other units if the
IMG_PROP_ANIMATION_ENCODER_CREATE_TIMEBASE_DENOMINATOR_NUMBER
property is set when creating the encoder.
\returns true on success or false on failure; call SDL_GetError() for more
information.
\since This function is available since SDL_image 3.4.0.
\sa IMG_CreateAnimationEncoder \sa IMG_CreateAnimationEncoder_IO \sa IMG_CreateAnimationEncoderWithProperties \sa IMG_CloseAnimationEncoder
extern SDL_DECLSPEC bool SDLCALL IMG_AddAnimationEncoderFrame(IMG_AnimationEncoder *encoder, SDL_Surface *surface, Uint64 duration)
Implementation
bool addFrame(Pointer<SdlSurface> surface, int duration) =>
imgAddAnimationEncoderFrame(this, surface, duration);