sdl3/sdl_log library

Functions

sdlGetDefaultLogOutputFunction() → Pointer<NativeFunction<SdlLogOutputFunction>> log
Get the default log output function.
sdlGetLogOutputFunction(Pointer<Pointer<NativeFunction<SdlLogOutputFunction>>> callback, Pointer<Pointer<Void>> userdata) → void log
Get the current log output function.
sdlGetLogPriority(int category) → int log
Get the priority of a particular log category.
sdlLog(String? fmt) → void log
Log a message with SDL_LOG_CATEGORY_APPLICATION and SDL_LOG_PRIORITY_INFO.
sdlLogCritical(int category, String? fmt) → void log
Log a message with SDL_LOG_PRIORITY_CRITICAL.
sdlLogDebug(int category, String? fmt) → void log
Log a message with SDL_LOG_PRIORITY_DEBUG.
sdlLogError(int category, String? fmt) → void log
Log a message with SDL_LOG_PRIORITY_ERROR.
sdlLogInfo(int category, String? fmt) → void log
Log a message with SDL_LOG_PRIORITY_INFO.
sdlLogMessage(int category, int priority, String? fmt) → void log
Log a message with the specified category and priority.
sdlLogMessageV(int category, int priority, String? fmt) → void log
Log a message with the specified category and priority.
sdlLogTrace(int category, String? fmt) → void log
Log a message with SDL_LOG_PRIORITY_TRACE.
sdlLogVerbose(int category, String? fmt) → void log
Log a message with SDL_LOG_PRIORITY_VERBOSE.
sdlLogWarn(int category, String? fmt) → void log
Log a message with SDL_LOG_PRIORITY_WARN.
sdlResetLogPriorities() → void log
Reset all priorities to default.
sdlSetLogOutputFunction(Pointer<NativeFunction<SdlLogOutputFunction>> callback, Pointer<Void> userdata) → void log
Replace the default log output function with one of your own.
sdlSetLogPriorities(int priority) → void log
Set the priority of all log categories.
sdlSetLogPriority(int category, int priority) → void log
Set the priority of a particular log category.
sdlSetLogPriorityPrefix(int priority, String? prefix) → bool log
Set the text prepended to log messages of a given priority.