sdl3/sdl_main
library
Functions
sdlEnterAppMainCallbacks (int argc , Pointer <Pointer <Int8 > > argv , Pointer <NativeFunction <SdlAppInitFunc > > appinit , Pointer <NativeFunction <SdlAppIterateFunc > > appiter , Pointer <NativeFunction <SdlAppEventFunc > > appevent , Pointer <NativeFunction <SdlAppQuitFunc > > appquit )
→ int
main
An entry point for SDL's use in SDL_MAIN_USE_CALLBACKS.
sdlGdkSuspendComplete ()
→ void
main
Callback from the application to let the suspend continue.
sdlRegisterApp (String ? name , int style , Pointer <Void > hInst )
→ bool
main
Register a win32 window class for SDL's use.
sdlRunApp (int argc , Pointer <Pointer <Int8 > > argv , Pointer <NativeFunction <SdlMainFunc > > mainFunction , Pointer <Void > reserved )
→ int
main
Initializes and launches an SDL application, by doing platform-specific
initialization before calling your mainFunction and cleanups after it
returns, if that is needed for a specific platform, otherwise it just calls
mainFunction.
sdlSetMainReady ()
→ void
main
Circumvent failure of SDL_Init() when not using SDL_main() as an entry
point.
sdlUnregisterApp ()
→ void
main
Deregister the win32 window class from an SDL_RegisterApp call.