SdlxMessageBoxData class

Constructors

SdlxMessageBoxData({int flags = 0, Pointer<SdlWindow>? window, String title = '', String message = '', List<SdlxMessageBoxButtonData> buttons = const [], SdlxMessageBoxColorScheme? colorScheme})

Properties

buttons → List<SdlxMessageBoxButtonData>
final
colorScheme → SdlxMessageBoxColorScheme?
final
flags → int
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final
window → Pointer<SdlWindow>
final

Methods

calloc() → Pointer<SdlMessageBoxData>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited