mixGetMixerGain function mixer
Get a mixer's master gain control.
This returns the last value set through MIX_SetMixerGain(), or 1.0f if no value has ever been explicitly set.
\param mixer the mixer to query. \returns the mixer's current master gain.
\threadsafety It is safe to call this function from any thread.
\since This function is available since SDL_mixer 3.0.0.
\sa MIX_SetMixerGain \sa MIX_GetTrackGain
extern SDL_DECLSPEC float SDLCALL MIX_GetMixerGain(MIX_Mixer *mixer)
Implementation
double mixGetMixerGain(Pointer<MixMixer> mixer) {
final mixGetMixerGainLookupFunction = _libMixer
.lookupFunction<
Float Function(Pointer<MixMixer> mixer),
double Function(Pointer<MixMixer> mixer)
>('MIX_GetMixerGain');
return mixGetMixerGainLookupFunction(mixer);
}