mixSetMixerFrequencyRatio function mixer

bool mixSetMixerFrequencyRatio(
  1. Pointer<MixMixer> mixer,
  2. double ratio
)

Set a mixer's master frequency ratio.

Each mixer has a master frequency ratio, that affects the entire mix. This can cause the final output to change speed and pitch. A value greater than 1.0f will play the audio faster, and at a higher pitch. A value less than 1.0f will play the audio slower, and at a lower pitch. 1.0f is normal speed.

Each track also has a frequency ratio; it will be applied when mixing that track's audio regardless of the master setting. The master setting affects the final output after all mixing has been completed.

A mixer's master frequency ratio defaults to 1.0f.

This value can be changed at any time to adjust the future mix.

\param mixer the mixer to adjust. \param ratio the frequency ratio. Must be between 0.01f and 100.0f. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL_mixer 3.0.0.

\sa MIX_GetMixerFrequencyRatio \sa MIX_SetTrackFrequencyRatio

extern SDL_DECLSPEC bool SDLCALL MIX_SetMixerFrequencyRatio(MIX_Mixer *mixer, float ratio)

Implementation

bool mixSetMixerFrequencyRatio(Pointer<MixMixer> mixer, double ratio) {
  final mixSetMixerFrequencyRatioLookupFunction = _libMixer
      .lookupFunction<
        Uint8 Function(Pointer<MixMixer> mixer, Float ratio),
        int Function(Pointer<MixMixer> mixer, double ratio)
      >('MIX_SetMixerFrequencyRatio');
  return mixSetMixerFrequencyRatioLookupFunction(mixer, ratio) == 1;
}