mixUnlockMixer function mixer

void mixUnlockMixer(
  1. Pointer<MixMixer> mixer
)

Unlock a mixer previously locked by a call to MIX_LockMixer().

While locked, the mixer will not be able to mix more audio or change its internal state another thread. Those other threads will block until the mixer is unlocked again.

Under the hood, this function calls SDL_LockMutex(), so all the same rules apply: the lock can be recursive, it must be unlocked the same number of times from the same thread that locked it, etc.

Unlocking a NULL mixer is a safe no-op.

\param mixer the mixer to unlock. May be NULL.

\threadsafety This call must be paired with a previous MIX_LockMixer call on the same thread.

\since This function is available since SDL_mixer 3.0.0.

\sa MIX_LockMixer

extern SDL_DECLSPEC void SDLCALL MIX_UnlockMixer(MIX_Mixer *mixer)

Implementation

void mixUnlockMixer(Pointer<MixMixer> mixer) {
  final mixUnlockMixerLookupFunction = _libMixer
      .lookupFunction<
        Void Function(Pointer<MixMixer> mixer),
        void Function(Pointer<MixMixer> mixer)
      >('MIX_UnlockMixer');
  return mixUnlockMixerLookupFunction(mixer);
}