SdlxCursorFrameInfo class

Constructors

SdlxCursorFrameInfo({Pointer<SdlSurface>? surface, int duration = 0})
SdlxCursorFrameInfo.fromPointer(Pointer<SdlCursorFrameInfo> pointer)
factory

Properties

duration → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
surface → Pointer<SdlSurface>
final

Methods

calloc() → Pointer<SdlCursorFrameInfo>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited