compare method
Compare two NET_Address objects.
This compares two addresses, returning a value that is useful for qsort (or SDL_qsort).
\param a first address to compare.
\param b second address to compare.
\returns a value less than zero if a is "less than" b, a value greater
than zero if "greater than", zero if equal.
\threadsafety It is safe to call this function from any thread.
\since This function is available since SDL_net 3.0.0.
extern SDL_DECLSPEC int SDLCALL NET_CompareAddresses(const NET_Address *a, const NET_Address *b)
Implementation
int compare(Pointer<NetAddress> b) => netCompareAddresses(this, b);