NetDatagramSocketPointerEx extension

on

Methods

destroy() → void net

Available on Pointer<NetDatagramSocket>, provided by the NetDatagramSocketPointerEx extension

Dispose of a previously-created datagram socket.
receive({bool refAddress = true}) NetxDatagram? net

Available on Pointer<NetDatagramSocket>, provided by the NetDatagramSocketPointerEx extension

Receive a new packet that a remote system sent to a datagram socket.
send(Pointer<NetAddress> address, int port, Uint8List buf) bool net

Available on Pointer<NetDatagramSocket>, provided by the NetDatagramSocketPointerEx extension

Send a new packet over a datagram socket to a remote system.
simulatePacketLoss(int percentLoss) → void net

Available on Pointer<NetDatagramSocket>, provided by the NetDatagramSocketPointerEx extension

Enable simulated datagram socket failures.