getAddress method
Get the remote address of a stream socket.
This reports the address of the remote side of a stream socket, which might still be pending connnection.
This adds a reference to the address; the caller must call NET_UnrefAddress() when done with it.
\param sock the stream socket to query. \returns the socket's remote address, or NULL on error; call SDL_GetError() for details.
\threadsafety It is safe to call this function from any thread.
\since This function is available since SDL_net 3.0.0.
extern SDL_DECLSPEC NET_Address * SDLCALL NET_GetStreamSocketAddress(NET_StreamSocket *sock)
Implementation
Pointer<NetAddress> getAddress() => netGetStreamSocketAddress(this);