SdlxNotificationActionButton class
- Inheritance
-
- Object
- SdlxNotificationAction
- SdlxNotificationActionButton
Constructors
- SdlxNotificationActionButton({int type = SDL_NOTIFICATION_ACTION_TYPE_BUTTON, String actionId = '', String actionLabel = ''})
-
const
Properties
- actionId → String
-
final
- actionLabel → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → int
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPointer(
Pointer< SdlNotificationAction> pointer) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited