sdl3/sdl_pixels library

Functions

sdlCreatePalette(int ncolors) → Pointer<SdlPalette> pixels
Create a palette structure with the specified number of color entries.
sdlDestroyPalette(Pointer<SdlPalette> palette) → void pixels
Free a palette created with SDL_CreatePalette().
sdlGetMasksForPixelFormat(int format, Pointer<Int32> bpp, Pointer<Uint32> rmask, Pointer<Uint32> gmask, Pointer<Uint32> bmask, Pointer<Uint32> amask) → bool pixels
Convert one of the enumerated pixel formats to a bpp value and RGBA masks.
sdlGetPixelFormatDetails(int format) → Pointer<SdlPixelFormatDetails> pixels
Create an SDL_PixelFormatDetails structure corresponding to a pixel format.
sdlGetPixelFormatForMasks(int bpp, int rmask, int gmask, int bmask, int amask) → int pixels
Convert a bpp value and RGBA masks to an enumerated pixel format.
sdlGetPixelFormatName(int format) → String? pixels
Get the human readable name of a pixel format.
sdlGetRgb(int pixelvalue, Pointer<SdlPixelFormatDetails> format, Pointer<SdlPalette> palette, Pointer<Uint8> r, Pointer<Uint8> g, Pointer<Uint8> b) → void pixels
Get RGB values from a pixel in the specified format.
sdlGetRgba(int pixelvalue, Pointer<SdlPixelFormatDetails> format, Pointer<SdlPalette> palette, Pointer<Uint8> r, Pointer<Uint8> g, Pointer<Uint8> b, Pointer<Uint8> a) → void pixels
Get RGBA values from a pixel in the specified format.
sdlMapRgb(Pointer<SdlPixelFormatDetails> format, Pointer<SdlPalette> palette, int r, int g, int b) → int pixels
Map an RGB triple to an opaque pixel value for a given pixel format.
sdlMapRgba(Pointer<SdlPixelFormatDetails> format, Pointer<SdlPalette> palette, int r, int g, int b, int a) → int pixels
Map an RGBA quadruple to a pixel value for a given pixel format.
sdlSetPaletteColors(Pointer<SdlPalette> palette, Pointer<SdlColor> colors, int firstcolor, int ncolors) → bool pixels
Set a range of colors in a palette.
sdlxGetMasksForPixelFormat(int format) → SdlxMasks? pixels
Convert one of the enumerated pixel formats to a bpp value and RGBA masks.
sdlxGetPixelFormatForMasks(SdlxMasks masks) → int pixels
Convert a bpp value and RGBA masks to an enumerated pixel format.
sdlxGetRgb(int pixelvalue, Pointer<SdlPixelFormatDetails> format, Pointer<SdlPalette> palette) → SdlxColor? pixels
Get RGB values from a pixel in the specified format.
sdlxGetRgba(int pixelvalue, Pointer<SdlPixelFormatDetails> format, Pointer<SdlPalette> palette) → SdlxColor pixels
Get RGBA values from a pixel in the specified format.
sdlxSetPaletteColors(Pointer<SdlPalette> palette, List<SdlxColor> colors, int firstcolor) → bool pixels
Set a range of colors in a palette.