SdlxMasks class

Constructors

SdlxMasks({int bpp = 0, int rmask = 0, int gmask = 0, int bmask = 0, int amask = 0})
const

Properties

amask → int
final
bmask → int
final
bpp → int
final
gmask → int
final
hashCode → int
The hash code for this object.
no setterinherited
rmask → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited