SdlxFRect class

Constructors

SdlxFRect([double x = 0, double y = 0, double w = 0, double h = 0])
const
SdlxFRect.fromCenter({required SdlxFPoint center, required SdlxFPoint size})
factory
SdlxFRect.fromPointer(Pointer<SdlFRect> pointer)
factory
SdlxFRect.fromPoints(SdlxFPoint p1, SdlxFPoint p2)
factory
SdlxFRect.fromPosition(SdlxFPoint topLeft, SdlxFPoint size)
factory

Properties

bottom → double
no setter
bottomLeft → SdlxFPoint
no setter
bottomRight → SdlxFPoint
no setter
center → SdlxFPoint
no setter
h → double
final
hashCode → int
The hash code for this object.
no setterinherited
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → SdlxFPoint
no setter
topLeft → SdlxFPoint
no setter
topRight → SdlxFPoint
no setter
w → double
final
x → double
final
y → double
final

Methods

calloc() → Pointer<SdlFRect>
copyWith({double? x, double? y, double? w, double? h}) → SdlxFRect
intersection(SdlxFRect other) → SdlxFRect?
moveBy(SdlxFPoint offset) → SdlxFRect
moveTo(SdlxFPoint position) → SdlxFRect
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sizeBy(SdlxFPoint offset) → SdlxFRect
sizeTo(SdlxFPoint newSize) → SdlxFRect
toInt() → SdlxRect
toString() → String
A string representation of this object.
inherited
withBottomLeft(SdlxFPoint point) → SdlxFRect
withBottomRight(SdlxFPoint point) → SdlxFRect
withCenter(SdlxFPoint point) → SdlxFRect
withTopLeft(SdlxFPoint point) → SdlxFRect
withTopRight(SdlxFPoint point) → SdlxFRect

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from({double x = 0, double y = 0, double w = 0, double h = 0}) → SdlxFRect