SdlxRect class

Constructors

SdlxRect([int x = 0, int y = 0, int w = 0, int h = 0])
const
SdlxRect.fromPointer(Pointer<SdlRect> pointer)
factory

Properties

h → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
w → int
final
x → int
final
y → int
final

Methods

calloc() → Pointer<SdlRect>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFloat() → SdlxFRect
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited