sdlxGetRectUnionFloat function rect

SdlxFRect? sdlxGetRectUnionFloat(
  1. SdlxFRect a,
  2. SdlxFRect b
)

Calculate the union of two rectangles with float precision.

\param A an SDL_FRect structure representing the first rectangle. \param B an SDL_FRect structure representing the second rectangle. \param result an SDL_FRect structure filled in with the union of rectangles A and B. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.2.0.

extern SDL_DECLSPEC bool SDLCALL SDL_GetRectUnionFloat(const SDL_FRect *A, const SDL_FRect *B, SDL_FRect *result)

See also:

Implementation

SdlxFRect? sdlxGetRectUnionFloat(SdlxFRect a, SdlxFRect b) =>
    ffi.using((arena) {
      final aPointer = arena<SdlFRect>()
        ..ref.x = a.x
        ..ref.y = a.y
        ..ref.w = a.w
        ..ref.h = a.h;

      final bPointer = arena<SdlFRect>()
        ..ref.x = b.x
        ..ref.y = b.y
        ..ref.w = b.w
        ..ref.h = b.h;

      final resultPointer = arena<SdlFRect>();

      final result = sdlGetRectUnionFloat(aPointer, bPointer, resultPointer);

      if (!result) {
        return null;
      }

      return SdlxFRect.fromPointer(resultPointer);
    });