SdlShaderCrossComputePipelineMetadata class final shadercross

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
numReadonlyStorageBuffers int
getter/setter pair
numReadonlyStorageTextures int
getter/setter pair
numReadwriteStorageBuffers int
getter/setter pair
numReadwriteStorageTextures int
getter/setter pair
numSamplers int
getter/setter pair
numUniformBuffers int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threadcountX int
getter/setter pair
threadcountY int
getter/setter pair
threadcountZ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited