SdlkShadercrossIovarType class shadercross

Constructors

SdlkShadercrossIovarType()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

float16 → const int
float32 → const int
float64 → const int
int8 → const int
int16 → const int
int32 → const int
int64 → const int
uint8 → const int
uint16 → const int
uint32 → const int
uint64 → const int
unknown → const int