SdlxStorageInterface class
Constructors
-
SdlxStorageInterface({int? version, Pointer<
NativeFunction< ? close, Pointer<SdlStorageInterfaceClose> >NativeFunction< ? ready, Pointer<SdlStorageInterfaceClose> >NativeFunction< ? enumerate, Pointer<SdlStorageInterfaceEnumerate> >NativeFunction< ? info, Pointer<SdlStorageInterfaceInfo> >NativeFunction< ? readFile, Pointer<SdlStorageInterfaceReadFile> >NativeFunction< ? writeFile, Pointer<SdlStorageInterfaceReadFile> >NativeFunction< ? mkdir, Pointer<SdlStorageInterfaceMkdir> >NativeFunction< ? remove, Pointer<SdlStorageInterfaceMkdir> >NativeFunction< ? rename, Pointer<SdlStorageInterfaceRename> >NativeFunction< ? copy, Pointer<SdlStorageInterfaceRename> >NativeFunction< ? spaceRemaining})SdlStorageInterfaceSpaceRemaining> > -
SdlxStorageInterface.fromPointer(Pointer<
SdlStorageInterface> pointer) -
factory
Properties
-
close
→ Pointer<
NativeFunction< SdlStorageInterfaceClose> > -
final
-
copy
→ Pointer<
NativeFunction< SdlStorageInterfaceRename> > -
final
-
enumerate
→ Pointer<
NativeFunction< SdlStorageInterfaceEnumerate> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
info
→ Pointer<
NativeFunction< SdlStorageInterfaceInfo> > -
final
-
mkdir
→ Pointer<
NativeFunction< SdlStorageInterfaceMkdir> > -
final
-
readFile
→ Pointer<
NativeFunction< SdlStorageInterfaceReadFile> > -
final
-
ready
→ Pointer<
NativeFunction< SdlStorageInterfaceClose> > -
final
-
remove
→ Pointer<
NativeFunction< SdlStorageInterfaceMkdir> > -
final
-
rename
→ Pointer<
NativeFunction< SdlStorageInterfaceRename> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spaceRemaining
→ Pointer<
NativeFunction< SdlStorageInterfaceSpaceRemaining> > -
final
- version → int
-
final
-
writeFile
→ Pointer<
NativeFunction< SdlStorageInterfaceReadFile> > -
final
Methods
-
calloc(
) → Pointer< SdlStorageInterface> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited