sdlxGetStoragePathInfo function storage

SdlxPathInfo? sdlxGetStoragePathInfo(
  1. Pointer<SdlStorage> storage,
  2. String path
)

Get information about a filesystem path in a storage container.

\param storage a storage container. \param path the path to query. \param info a pointer filled in with information about the path, or NULL to check for the existence of a file. \returns true on success or false if the file doesn't exist, or another failure; call SDL_GetError() for more information.

\since This function is available since SDL 3.2.0.

\sa SDL_StorageReady

extern SDL_DECLSPEC bool SDLCALL SDL_GetStoragePathInfo(SDL_Storage *storage, const char *path, SDL_PathInfo *info)

See also:

Implementation

SdlxPathInfo? sdlxGetStoragePathInfo(
  Pointer<SdlStorage> storage,
  String path,
) => ffi.using((arena) {
  final infoPointer = arena<SdlPathInfo>();
  final success = sdlGetStoragePathInfo(storage, path, infoPointer);

  if (!success) return null;

  return SdlxPathInfo.fromPointer(infoPointer);
});