sdl3/sdl_touch library

Classes

SdlxFinger

Functions

sdlGetTouchDeviceName(int touchId) → String? touch
Get the touch device name as reported from the driver.
sdlGetTouchDevices(Pointer<Int32> count) → Pointer<Uint64> touch
Get a list of registered touch devices.
sdlGetTouchDeviceType(int touchId) → int touch
Get the type of the given touch device.
sdlGetTouchFingers(int touchId, Pointer<Int32> count) → Pointer<Pointer<SdlFinger>> touch
Get a list of active fingers for a given touch device.
sdlxGetTouchDevices() → List<int> touch
Get a list of registered touch devices.
sdlxGetTouchFingers(int touchID) → List<SdlxFinger> touch
Get a list of active fingers for a given touch device.