TtfCopyOperation class final textengine

Inheritance
Implemented types
Available extensions

Constructors

TtfCopyOperation()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cmd int
getter/setter pair
dst SdlRect
getter/setter pair
glyphFont Pointer<TtfFont>
getter/setter pair
glyphIndex int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
reserved Pointer<Void>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src SdlRect
getter/setter pair
textOffset int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited