TtfFontEx extension

on

Static Methods

getFreeTypeVersion(Pointer<Int32> major, Pointer<Int32> minor, Pointer<Int32> patch) → void ttf

Available on TtfFont, provided by the TtfFontEx extension

Query the version of the FreeType library in use.
getGlyphScript(int ch) int ttf

Available on TtfFont, provided by the TtfFontEx extension

Get the script used by a 32-bit codepoint.
getHarfBuzzVersion(Pointer<Int32> major, Pointer<Int32> minor, Pointer<Int32> patch) → void ttf

Available on TtfFont, provided by the TtfFontEx extension

Query the version of the HarfBuzz library in use.
init() bool ttf

Available on TtfFont, provided by the TtfFontEx extension

Initialize SDL_ttf.
open(String file, double ptsize) Pointer<TtfFont> ttf

Available on TtfFont, provided by the TtfFontEx extension

Create a font from a file, using a specified point size.
openIo(Pointer<SdlIoStream> src, bool closeio, double ptsize) Pointer<TtfFont> ttf

Available on TtfFont, provided by the TtfFontEx extension

Create a font from an SDL_IOStream, using a specified point size.
openWithProperties(int props) Pointer<TtfFont> ttf

Available on TtfFont, provided by the TtfFontEx extension

Create a font with the specified properties.
quit() → void ttf

Available on TtfFont, provided by the TtfFontEx extension

Deinitialize SDL_ttf.
version() int ttf

Available on TtfFont, provided by the TtfFontEx extension

This function gets the version of the dynamically linked SDL_ttf library.
wasInit() int ttf

Available on TtfFont, provided by the TtfFontEx extension

Check if SDL_ttf is initialized.