TtfFontPointerEx extension

on

Methods

addFallback(Pointer<TtfFont> fallback) bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Add a fallback font.
clearFallbacks() → void ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Remove all fallback fonts.
close() → void ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Dispose of a previously-created font.
copy() Pointer<TtfFont> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Create a copy of an existing font.
getAscent() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query the offset from the baseline to the top of a font.
getCharSpacing() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Get the additional character spacing in pixels to be applied between any two rendered characters.
getDescent() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query the offset from the baseline to the bottom of a font.
getDirection() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Get the direction to be used for text shaping by a font.
getDpi() → ({int hdpi, int vdpi})? ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Get font target resolutions, in dots per inch.
getFamilyName() String? ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query a font's family name.
getGeneration() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Get the font generation.
getGlyphImage(int ch) → ({int imageType, Pointer<SdlSurface> surface})? ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Get the pixel image for a UNICODE codepoint.
getGlyphImageForIndex(int glyphIndex) → ({int imageType, Pointer<SdlSurface> surface})? ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Get the pixel image for a character index.
getGlyphKerning(int previousCh, int ch) int? ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query the kerning size between the glyphs of two UNICODE codepoints.
getGlyphMetrics(int ch) → ({int advance, int maxx, int maxy, int minx, int miny})? ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query the metrics (dimensions) of a font's glyph for a UNICODE codepoint.
getHeight() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query the total height of a font.
getHinting() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query a font's current FreeType hinter setting.
getKerning() bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query whether or not kerning is enabled for a font.
getLineSkip() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query the spacing between lines of text for a font.
getNumFaces() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query the number of faces of a font.
getOutline() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query a font's current outline.
getProperties() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Get the properties associated with a font.
getScript() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Get the script used for text shaping a font.
getSdf() bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query whether Signed Distance Field rendering is enabled for a font.
getSize() double ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Get the size of a font.
getStringSize(String text) → ({int h, int w})? ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Calculate the dimensions of a rendered string of UTF-8 text.
getStringSizeWrapped(String text, int wrapWidth) → ({int h, int w})? ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Calculate the dimensions of a rendered string of UTF-8 text.
getStyle() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query a font's current style.
getStyleName() String? ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query a font's style name.
getWeight() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query a font's weight, in terms of the lightness/heaviness of the strokes.
getWrapAlignment() int ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query a font's current wrap alignment option.
hasGlyph(int ch) bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Check whether a glyph is provided by the font for a UNICODE codepoint.
isFixedWidth() bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query whether a font is fixed-width.
isScalable() bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Query whether a font is scalable or not.
measureString(String text, int maxWidth) → ({int measuredLength, int measuredWidth})? ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Calculate how much of a UTF-8 string will fit in a given width.
removeFallback(Pointer<TtfFont> fallback) → void ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Remove a fallback font.
renderGlyphBlended(int ch, SdlxColor fg) Pointer<SdlSurface> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Render a single UNICODE codepoint at high quality to a new ARGB surface.
renderGlyphLcd(int ch, SdlxColor fg, SdlxColor bg) Pointer<SdlSurface> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Render a single UNICODE codepoint at LCD subpixel quality to a new ARGB surface.
renderGlyphShaded(int ch, SdlxColor fg, SdlxColor bg) Pointer<SdlSurface> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Render a single UNICODE codepoint at high quality to a new 8-bit surface.
renderGlyphSolid(int ch, SdlxColor fg) Pointer<SdlSurface> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Render a single 32-bit glyph at fast quality to a new 8-bit surface.
renderTextBlended(String text, SdlxColor fg) Pointer<SdlSurface> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Render UTF-8 text at high quality to a new ARGB surface.
renderTextBlendedWrapped(String? text, SdlxColor fg, int wrapLength) Pointer<SdlSurface> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Render word-wrapped UTF-8 text at high quality to a new ARGB surface.
renderTextLcd(String? text, int length, SdlxColor fg, SdlxColor bg) Pointer<SdlSurface> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Render UTF-8 text at LCD subpixel quality to a new ARGB surface.
renderTextLcdWrapped(String? text, int length, SdlxColor fg, SdlxColor bg, int wrapLength) Pointer<SdlSurface> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Render word-wrapped UTF-8 text at LCD subpixel quality to a new ARGB surface.
renderTextShaded(String? text, SdlxColor fg, SdlxColor bg) Pointer<SdlSurface> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Render UTF-8 text at high quality to a new 8-bit surface.
renderTextShadedWrapped(String? text, SdlxColor fg, SdlxColor bg, int wrapLength) Pointer<SdlSurface> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Render UTF-8 text at high quality to a new 8-bit surface.
renderTextSolid(String? text, SdlxColor fg) Pointer<SdlSurface> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Render UTF-8 text at fast quality to a new 8-bit surface.
renderTextSolidWrapped(String? text, SdlxColor fg, int wrapLength) Pointer<SdlSurface> ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Render word-wrapped UTF-8 text at fast quality to a new 8-bit surface.
setCharSpacing(int spacing) bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Set additional space in pixels to be applied between any two rendered characters.
setDirection(int direction) bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Set the direction to be used for text shaping by a font.
setHinting(int hinting) → void ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Set a font's current hinter setting.
setKerning(bool allowed) → void ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Set if kerning is enabled for a font.
setLanguage(String? languageBcp47) bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Set language to be used for text shaping by a font.
setLineSkip(int lineskip) → void ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Set the spacing between lines of text for a font.
setOutline(int outline) bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Set a font's current outline.
setScript(int script) bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Set the script to be used for text shaping by a font.
setSdf(bool enabled) bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Enable Signed Distance Field rendering for a font.
setSize(double ptsize) bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Set a font's size dynamically.
setSizeDpi(double ptsize, int hdpi, int vdpi) bool ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Set font size dynamically with target resolutions, in dots per inch.
setStyle(int style) → void ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Set a font's current style.
setWrapAlignment(int align) → void ttf

Available on Pointer<TtfFont>, provided by the TtfFontPointerEx extension

Set a font's current wrap alignment option.