getDirection method

int getDirection()

Get the direction to be used for text shaping by a font.

This defaults to TTF_DIRECTION_INVALID if it hasn't been set.

\param font the font to query. \returns the direction to be used for text shaping.

\threadsafety This function should be called on the thread that created the font.

\since This function is available since SDL_ttf 3.0.0.

extern SDL_DECLSPEC TTF_Direction SDLCALL TTF_GetFontDirection(TTF_Font *font)

Implementation

int getDirection() => ttfGetFontDirection(this);