renderGlyphSolid method

Pointer<SdlSurface> renderGlyphSolid(
  1. int ch,
  2. SdlxColor fg
)

Render a single 32-bit glyph at fast quality to a new 8-bit surface.

This function will allocate a new 8-bit, palettized surface. The surface's 0 pixel will be the colorkey, giving a transparent background. The 1 pixel will be set to the text color.

The glyph is rendered without any padding or centering in the X direction, and aligned normally in the Y direction.

You can render at other quality levels with TTF_RenderGlyph_Shaded, TTF_RenderGlyph_Blended, and TTF_RenderGlyph_LCD.

\param font the font to render with. \param ch the character to render. \param fg the foreground color for the text. \returns a new 8-bit, palettized surface, or NULL if there was an error.

\threadsafety This function should be called on the thread that created the font.

\since This function is available since SDL_ttf 3.0.0.

\sa TTF_RenderGlyph_Blended \sa TTF_RenderGlyph_LCD \sa TTF_RenderGlyph_Shaded

extern SDL_DECLSPEC SDL_Surface * SDLCALL TTF_RenderGlyph_Solid(TTF_Font *font, Uint32 ch, SDL_Color fg)

See also:

Implementation

Pointer<SdlSurface> renderGlyphSolid(int ch, SdlxColor fg) =>
    ttfxRenderGlyphSolid(this, ch, fg);