TtfTextData class final textengine

Inheritance
Implemented types
Available extensions

Constructors

TtfTextData()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
clusters Pointer<TtfSubString>
getter/setter pair
color SdlFColor
getter/setter pair
engine Pointer<TtfTextEngine>
getter/setter pair
engineText Pointer<Void>
getter/setter pair
font Pointer<TtfFont>
getter/setter pair
h int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
layout Pointer<TtfTextLayout>
getter/setter pair
needsEngineUpdate bool
getter/setter pair
needsLayoutUpdate bool
getter/setter pair
numClusters int
getter/setter pair
numOps int
getter/setter pair
ops Pointer<TtfDrawOperation>
getter/setter pair
props int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
w int
getter/setter pair
x int
getter/setter pair
y int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited