TtfTextEngine class final textengine

Inheritance
Implemented types
Available extensions

Constructors

TtfTextEngine()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
createText ↔ Pointer<NativeFunction<TtfTextEngineCreateText>>
getter/setter pair
destroyText ↔ Pointer<NativeFunction<TtfTextEngineDestroyText>>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userdata ↔ Pointer<Void>
getter/setter pair
version ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited