TtfTextEnginePointerEx extension

on

Methods

createText(Pointer<TtfFont> font, String text) Pointer<TtfText> ttf

Available on Pointer<TtfTextEngine>, provided by the TtfTextEnginePointerEx extension

Create a text object from UTF-8 text and a text engine.
destroyGl() → void ttf

Available on Pointer<TtfTextEngine>, provided by the TtfTextEnginePointerEx extension

Destroy a text engine created for drawing text with OpenGL.
destroyGpu() → void ttf

Available on Pointer<TtfTextEngine>, provided by the TtfTextEnginePointerEx extension

Destroy a text engine created for drawing text with the SDL GPU API.
destroyRenderer() → void ttf

Available on Pointer<TtfTextEngine>, provided by the TtfTextEnginePointerEx extension

Destroy a text engine created for drawing text on an SDL renderer.
destroySurface() → void ttf

Available on Pointer<TtfTextEngine>, provided by the TtfTextEnginePointerEx extension

Destroy a text engine created for drawing text on SDL surfaces.
getGlWinding() int ttf

Available on Pointer<TtfTextEngine>, provided by the TtfTextEnginePointerEx extension

Get the winding order of the vertices returned by TTF_GetGLTextDrawData for a particular GL text engine.
getGpuWinding() int ttf

Available on Pointer<TtfTextEngine>, provided by the TtfTextEnginePointerEx extension

Get the winding order of the vertices returned by TTF_GetGPUTextDrawData for a particular GPU text engine
setGlWinding(int winding) → void ttf

Available on Pointer<TtfTextEngine>, provided by the TtfTextEnginePointerEx extension

Sets the winding order of the vertices returned by TTF_GetGLTextDrawData for a particular GL text engine.
setGpuWinding(int winding) → void ttf

Available on Pointer<TtfTextEngine>, provided by the TtfTextEnginePointerEx extension

Sets the winding order of the vertices returned by TTF_GetGPUTextDrawData for a particular GPU text engine.