destroySurface method

void destroySurface()

Destroy a text engine created for drawing text on SDL surfaces.

All text created by this engine should be destroyed before calling this function.

\param engine a TTF_TextEngine object created with TTF_CreateSurfaceTextEngine().

\threadsafety This function should be called on the thread that created the engine.

\since This function is available since SDL_ttf 3.0.0.

\sa TTF_CreateSurfaceTextEngine

extern SDL_DECLSPEC void SDLCALL TTF_DestroySurfaceTextEngine(TTF_TextEngine *engine)

Implementation

void destroySurface() => ttfDestroySurfaceTextEngine(this);