getGlWinding method

int getGlWinding()

Get the winding order of the vertices returned by TTF_GetGLTextDrawData for a particular GL text engine.

\param engine a TTF_TextEngine object created with TTF_CreateGLTextEngine(). \returns the winding order used by the GL text engine or TTF_GL_TEXTENGINE_WINDING_INVALID in case of error.

\threadsafety This function should be called on the thread that created the engine.

\since This function is available since SDL_ttf 3.3.0.

\sa TTF_SetGLTextEngineWinding

extern SDL_DECLSPEC TTF_GLTextEngineWinding SDLCALL TTF_GetGLTextEngineWinding(const TTF_TextEngine *engine)

Implementation

int getGlWinding() => ttfGetGlTextEngineWinding(this);