getGpuWinding method

int getGpuWinding()

Get the winding order of the vertices returned by TTF_GetGPUTextDrawData for a particular GPU text engine

\param engine a TTF_TextEngine object created with TTF_CreateGPUTextEngine(). \returns the winding order used by the GPU text engine or TTF_GPU_TEXTENGINE_WINDING_INVALID in case of error.

\threadsafety This function should be called on the thread that created the engine.

\since This function is available since SDL_ttf 3.0.0.

\sa TTF_SetGPUTextEngineWinding

extern SDL_DECLSPEC TTF_GPUTextEngineWinding SDLCALL TTF_GetGPUTextEngineWinding(const TTF_TextEngine *engine)

Implementation

int getGpuWinding() => ttfGetGpuTextEngineWinding(this);