setGpuWinding method
Sets the winding order of the vertices returned by TTF_GetGPUTextDrawData for a particular GPU text engine.
\param engine a TTF_TextEngine object created with TTF_CreateGPUTextEngine(). \param winding the new winding order option.
\threadsafety This function should be called on the thread that created the engine.
\since This function is available since SDL_ttf 3.0.0.
\sa TTF_GetGPUTextEngineWinding
extern SDL_DECLSPEC void SDLCALL TTF_SetGPUTextEngineWinding(TTF_TextEngine *engine, TTF_GPUTextEngineWinding winding)
Implementation
void setGpuWinding(int winding) => ttfSetGpuTextEngineWinding(this, winding);