TtfTextPointerEx extension

on

Methods

appendString(String string) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Append UTF-8 text to a text object.
deleteString(int offset, int length) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Delete UTF-8 text from a text object.
destroy() → void ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Destroy a text object created by a text engine.
drawRenderer(double x, double y) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Draw text to an SDL renderer.
drawSurface(int x, int y, Pointer<SdlSurface> surface) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Draw text to an SDL surface.
getColor() SdlxColor? ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the color of a text object.
getColorFloat() SdlxFColor? ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the color of a text object.
getDirection() int ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the direction to be used for text shaping a text object.
getEngine() Pointer<TtfTextEngine> ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the text engine used by a text object.
getFont() Pointer<TtfFont> ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the font used by a text object.
getGlDrawData() Pointer<TtfGlAtlasDrawSequence> ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the geometry data needed for drawing the text.
getGpuDrawData() Pointer<TtfGpuAtlasDrawSequence> ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the geometry data needed for drawing the text.
getNextSubString(TtfxSubString substring) TtfxSubString? ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the next substring in a text object
getPosition() SdlxPoint? ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the position of a text object.
getPreviousSubString(TtfxSubString substring) TtfxSubString? ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the previous substring in a text object
getProperties() int ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the properties associated with a text object.
getScript() int ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the script used for text shaping a text object.
getSize() SdlxPoint? ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the size of a text object.
getSubString(int offset) TtfxSubString? ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the substring of a text object that surrounds a text offset.
getSubStringForLine(int offset) TtfxSubString? ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the substring of a text object that contains the given line.
getSubStringForPoint(int x, int y) TtfxSubString? ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the portion of a text string that is closest to a point.
getSubStringsForRange(int offset, int length) List<TtfxSubString> ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get the substrings of a text object that contain a range of text.
getWrapWidth() int? ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Get whether wrapping is enabled on a text object.
insertString(int offset, String string) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Insert UTF-8 text into a text object.
setColor(SdlxColor color) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Set the color of a text object.
setColorFloat(SdlxFColor color) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Set the color of a text object.
setDirection(int direction) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Set the direction to be used for text shaping a text object.
setEngine(Pointer<TtfTextEngine> engine) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Set the text engine used by a text object.
setFont(Pointer<TtfFont> font) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Set the font used by a text object.
setPosition(SdlxPoint position) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Set the position of a text object.
setScript(int script) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Set the script to be used for text shaping a text object.
setString(String string) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Set the UTF-8 text used by a text object.
setWrapWidth(int wrapWidth) bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Set whether wrapping is enabled on a text object.
update() bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Update the layout of a text object.
wrapWhitespaceVisible() bool ttf

Available on Pointer<TtfText>, provided by the TtfTextPointerEx extension

Return whether whitespace is shown when wrapping a text object.