appendString method

bool appendString(
  1. String string
)

Append UTF-8 text to a text object.

This function may cause the internal text representation to be rebuilt.

\param text the TTF_Text to modify. \param string the UTF-8 text to insert. \param length the length of the text, in bytes, or 0 for null terminated text. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should be called on the thread that created the text.

\since This function is available since SDL_ttf 3.0.0.

\sa TTF_DeleteTextString \sa TTF_InsertTextString \sa TTF_SetTextString

extern SDL_DECLSPEC bool SDLCALL TTF_AppendTextString(TTF_Text *text, const char *string, size_t length)

Implementation

bool appendString(String string) => ttfAppendTextString(this, string);