deleteString method
Delete UTF-8 text from a text object.
This function may cause the internal text representation to be rebuilt.
\param text the TTF_Text to modify. \param offset the offset, in bytes, from the beginning of the string if >= 0, the offset from the end of the string if < 0. Note that this does not do UTF-8 validation, so you should only delete at UTF-8 sequence boundaries. \param length the length of text to delete, in bytes, or -1 for the remainder of the string. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function should be called on the thread that created the text.
\since This function is available since SDL_ttf 3.0.0.
\sa TTF_AppendTextString \sa TTF_InsertTextString \sa TTF_SetTextString
extern SDL_DECLSPEC bool SDLCALL TTF_DeleteTextString(TTF_Text *text, int offset, int length)
Implementation
bool deleteString(int offset, int length) =>
ttfDeleteTextString(this, offset, length);