destroy method

void destroy()

Destroy a text object created by a text engine.

\param text the text to destroy.

\threadsafety This function should be called on the thread that created the text.

\since This function is available since SDL_ttf 3.0.0.

\sa TTF_CreateText

extern SDL_DECLSPEC void SDLCALL TTF_DestroyText(TTF_Text *text)

Implementation

void destroy() => ttfDestroyText(this);