getEngine method

Pointer<TtfTextEngine> getEngine()

Get the text engine used by a text object.

\param text the TTF_Text to query. \returns the TTF_TextEngine used by the text on success or NULL on failure; call SDL_GetError() for more information.

\threadsafety This function should be called on the thread that created the text.

\since This function is available since SDL_ttf 3.0.0.

\sa TTF_SetTextEngine

extern SDL_DECLSPEC TTF_TextEngine * SDLCALL TTF_GetTextEngine(TTF_Text *text)

Implementation

Pointer<TtfTextEngine> getEngine() => ttfGetTextEngine(this);