getFont method

Pointer<TtfFont> getFont()

Get the font used by a text object.

\param text the TTF_Text to query. \returns the TTF_Font used by the text on success or NULL on failure; call SDL_GetError() for more information.

\threadsafety This function should be called on the thread that created the text.

\since This function is available since SDL_ttf 3.0.0.

\sa TTF_SetTextFont

extern SDL_DECLSPEC TTF_Font * SDLCALL TTF_GetTextFont(TTF_Text *text)

Implementation

Pointer<TtfFont> getFont() => ttfGetTextFont(this);