getGpuDrawData method

Pointer<TtfGpuAtlasDrawSequence> getGpuDrawData()

Get the geometry data needed for drawing the text.

text must have been created using a TTF_TextEngine from TTF_CreateGPUTextEngine().

The positive X-axis is taken towards the right and the positive Y-axis is taken upwards for both the vertex and the texture coordinates, i.e, it follows the same convention used by the SDL_GPU API. If you want to use a different coordinate system you will need to transform the vertices yourself.

If the text looks blocky use linear filtering.

\param text the text to draw. \returns a NULL terminated linked list of TTF_GPUAtlasDrawSequence objects or NULL if the passed text is empty or in case of failure; call SDL_GetError() for more information.

\threadsafety This function should be called on the thread that created the text.

\since This function is available since SDL_ttf 3.0.0.

\sa TTF_CreateGPUTextEngine \sa TTF_CreateText

extern SDL_DECLSPEC TTF_GPUAtlasDrawSequence * SDLCALL TTF_GetGPUTextDrawData(TTF_Text *text)

Implementation

Pointer<TtfGpuAtlasDrawSequence> getGpuDrawData() =>
    ttfGetGpuTextDrawData(this);