getNextSubString method

TtfxSubString? getNextSubString(
  1. TtfxSubString substring
)

Get the next substring in a text object

If called at the end of the text, this will return a zero length substring with the TTF_SUBSTRING_TEXT_END flag set.

\param text the TTF_Text to query. \param substring the TTF_SubString to query. \param next a pointer filled in with the next substring. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should be called on the thread that created the text.

\since This function is available since SDL_ttf 3.0.0.

extern SDL_DECLSPEC bool SDLCALL TTF_GetNextTextSubString(TTF_Text *text, const TTF_SubString *substring, TTF_SubString *next)

Implementation

TtfxSubString? getNextSubString(TtfxSubString substring) =>
    ttfxGetNextTextSubString(this, substring);