insertString method

bool insertString(
  1. int offset,
  2. String string
)

Insert UTF-8 text into a text object.

This function may cause the internal text representation to be rebuilt.

\param text the TTF_Text to modify. \param offset the offset, in bytes, from the beginning of the string if >= 0, the offset from the end of the string if < 0. Note that this does not do UTF-8 validation, so you should only insert at UTF-8 sequence boundaries. \param string the UTF-8 text to insert. \param length the length of the text, in bytes, or 0 for null terminated text. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should be called on the thread that created the text.

\since This function is available since SDL_ttf 3.0.0.

\sa TTF_AppendTextString \sa TTF_DeleteTextString \sa TTF_SetTextString

extern SDL_DECLSPEC bool SDLCALL TTF_InsertTextString(TTF_Text *text, int offset, const char *string, size_t length)

Implementation

bool insertString(int offset, String string) =>
    ttfInsertTextString(this, offset, string);