setDirection method

bool setDirection(
  1. int direction
)

Set the direction to be used for text shaping a text object.

This function only supports left-to-right text shaping if SDL_ttf was not built with HarfBuzz support.

\param text the text to modify. \param direction the new direction for text to flow. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should be called on the thread that created the text.

\since This function is available since SDL_ttf 3.0.0.

extern SDL_DECLSPEC bool SDLCALL TTF_SetTextDirection(TTF_Text *text, TTF_Direction direction)

Implementation

bool setDirection(int direction) => ttfSetTextDirection(this, direction);