wrapWhitespaceVisible method

bool wrapWhitespaceVisible()

Return whether whitespace is shown when wrapping a text object.

\param text the TTF_Text to query. \returns true if whitespace is shown when wrapping text, or false otherwise.

\threadsafety This function should be called on the thread that created the text.

\since This function is available since SDL_ttf 3.0.0.

\sa TTF_SetTextWrapWhitespaceVisible

extern SDL_DECLSPEC bool SDLCALL TTF_TextWrapWhitespaceVisible(TTF_Text *text)

Implementation

bool wrapWhitespaceVisible() => ttfTextWrapWhitespaceVisible(this);