TtfxSubString class

Constructors

TtfxSubString({int flags = 0, int offset = 0, int length = 0, int lineIndex = 0, int clusterIndex = 0, SdlxRect? rect})

Properties

clusterIndex ↔ int
getter/setter pair
flags ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length ↔ int
getter/setter pair
lineIndex ↔ int
getter/setter pair
offset ↔ int
getter/setter pair
rect ↔ SdlxRect
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

calloc() → Pointer<TtfSubString>
loadFromPointer(Pointer<TtfSubString> pointer) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited