ttfxGetFreeTypeVersion function ttf
Query the version of the FreeType library in use.
TTF_Init() should be called before calling this function.
\param major to be filled in with the major version number. Can be NULL. \param minor to be filled in with the minor version number. Can be NULL. \param patch to be filled in with the param version number. Can be NULL.
\threadsafety It is safe to call this function from any thread.
\since This function is available since SDL_ttf 3.0.0.
\sa TTF_Init
extern SDL_DECLSPEC void SDLCALL TTF_GetFreeTypeVersion(int *major, int *minor, int *patch)
Implementation
({int major, int minor, int patch}) ttfxGetFreeTypeVersion(
Pointer<Int32> major,
Pointer<Int32> minor,
Pointer<Int32> patch,
) {
final majorPointer = ffi.calloc<Int32>();
final minorPointer = ffi.calloc<Int32>();
final patchPointer = ffi.calloc<Int32>();
ttfGetFreeTypeVersion(majorPointer, minorPointer, patchPointer);
final major = majorPointer.value;
final minor = minorPointer.value;
final patch = patchPointer.value;
majorPointer.callocFree();
minorPointer.callocFree();
patchPointer.callocFree();
return (major: major, minor: minor, patch: patch);
}