ttfxGetTextSubString function ttf
Get the substring of a text object that surrounds a text offset.
If offset is less than 0, this will return a zero length substring at the
beginning of the text with the TTF_SUBSTRING_TEXT_START flag set. If
offset is greater than or equal to the length of the text string, this
will return a zero length substring at the end of the text with the
TTF_SUBSTRING_TEXT_END flag set.
\param text the TTF_Text to query. \param offset a byte offset into the text string. \param substring a pointer filled in with the substring containing the offset. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function should be called on the thread that created the text.
\since This function is available since SDL_ttf 3.0.0.
extern SDL_DECLSPEC bool SDLCALL TTF_GetTextSubString(TTF_Text *text, int offset, TTF_SubString *substring)
Implementation
TtfxSubString? ttfxGetTextSubString(Pointer<TtfText> text, int offset) {
TtfxSubString? result;
final subStringPointer = ffi.calloc<TtfSubString>();
final bl = ttfGetTextSubString(text, offset, subStringPointer);
if (bl) {
result = TtfxSubString()..loadFromPointer(subStringPointer);
}
subStringPointer.callocFree();
return result;
}