sdl3gfx library

Classes

FpsManager

Constants

aaBits → const int
aaLevels → const int
defaultEllipseOverscan → const int
FPS_DEFAULT → const int
FPS_LOWER_LIMIT → const int
FPS_UPPER_LIMIT → const int
SDL3_GFXPRIMITIVES_MAJOR → const int
SDL3_GFXPRIMITIVES_MICRO → const int
SDL3_GFXPRIMITIVES_MINOR → const int
SMOOTHING_OFF → const int
SMOOTHING_ON → const int

Properties

charHeight ↔ int
getter/setter pair
charHeightLocal ↔ int
getter/setter pair
charPitch ↔ int
getter/setter pair
charRotation ↔ int
getter/setter pair
charSize ↔ int
getter/setter pair
charWidth ↔ int
getter/setter pair
charWidthLocal ↔ int
getter/setter pair
currentFontdata ↔ List<int>
getter/setter pair
gfxPrimitivesFont ↔ List<Pointer<SdlTexture>>
getter/setter pair
gfxPrimitivesFontdata ↔ List<int>
getter/setter pair
SDL_GFX_COMPILEDVERSION → int
final

Functions

aacircleColor(Pointer<SdlRenderer> renderer, double x, double y, double rad, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
aacircleRgba(Pointer<SdlRenderer> renderer, double x, double y, double rad, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
aaellipseColor(Pointer<SdlRenderer> renderer, double x, double y, double rx, double ry, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
aaellipseRgba(Pointer<SdlRenderer> renderer, double x, double y, double rx, double ry, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
aalineColor(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
aalineRgba(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
aapolygonColor(Pointer<SdlRenderer> renderer, List<SdlxFPoint> points, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
aapolygonRgba(Pointer<SdlRenderer> renderer, List<SdlxFPoint> points, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
aatrigonColor(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, double x3, double y3, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
aatrigonRgba(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, double x3, double y3, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
arcColor(Pointer<SdlRenderer> renderer, double x, double y, double rad, double start, double end, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
arcRgba(Pointer<SdlRenderer> renderer, double x, double y, double rad, double start, double end, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
bezierColor(Pointer<SdlRenderer> renderer, List<SdlxFPoint> points, int s, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
bezierRgba(Pointer<SdlRenderer> renderer, List<SdlxFPoint> points, int s, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
boxColor(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
boxRgba(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
characterColor(Pointer<SdlRenderer> renderer, double x, double y, int c, SdlxColor color) → bool
characterRgba(Pointer<SdlRenderer> renderer, double x, double y, int c, int r, int g, int b, int a) → bool
circleColor(Pointer<SdlRenderer> renderer, double x, double y, double rad, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
circleRgba(Pointer<SdlRenderer> renderer, double x, double y, double rad, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
createCharacterSurface(int c, int rotation) → Pointer<SdlSurface>
ellipseColor(Pointer<SdlRenderer> renderer, double x, double y, double rx, double ry, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
ellipseRgba(Pointer<SdlRenderer> renderer, double x, double y, double rx, double ry, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
filledCircleColor(Pointer<SdlRenderer> renderer, double x, double y, double rad, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
filledCircleRgba(Pointer<SdlRenderer> renderer, double x, double y, double rad, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
filledEllipseColor(Pointer<SdlRenderer> renderer, double x, double y, double rx, double ry, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
filledEllipseRgba(Pointer<SdlRenderer> renderer, double x, double y, double rx, double ry, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
filledPieColor(Pointer<SdlRenderer> renderer, double x, double y, double rad, double start, double end, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
filledPieRgba(Pointer<SdlRenderer> renderer, double x, double y, double rad, double start, double end, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
filledPolygonColor(Pointer<SdlRenderer> renderer, List<SdlxFPoint> points, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
filledPolygonRgba(Pointer<SdlRenderer> renderer, List<SdlxFPoint> points, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
filledPolygonRgbaMt(Pointer<SdlRenderer> renderer, List<SdlxFPoint> points, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
filledTrigonColor(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, double x3, double y3, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
filledTrigonRgba(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, double x3, double y3, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
gfxFree() → void
gfxPrimitivesSetFont(List<int> fontdata, int cw, int ch) → void
gfxPrimitivesSetFontRotation(int rotation) → void
hline(Pointer<SdlRenderer> renderer, double x1, double x2, double y) → bool
hlineColor(Pointer<SdlRenderer> renderer, double x1, double x2, double y, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
hlineRgba(Pointer<SdlRenderer> renderer, double x1, double x2, double y, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
line(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2) → bool
lineColor(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
lineRgba(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
pieColor(Pointer<SdlRenderer> renderer, double x, double y, double rad, double start, double end, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
pieRgba(Pointer<SdlRenderer> renderer, double x, double y, double rad, double start, double end, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
pixel(Pointer<SdlRenderer> renderer, double x, double y) → bool
pixelColor(Pointer<SdlRenderer> renderer, double x, double y, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
pixelRgba(Pointer<SdlRenderer> renderer, double x, double y, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
pixelRgbaWeight(Pointer<SdlRenderer> renderer, double x, double y, int r, int g, int b, int a, int weight, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
polygon(Pointer<SdlRenderer> renderer, List<SdlxFPoint> points) → bool
polygonColor(Pointer<SdlRenderer> renderer, List<SdlxFPoint> points, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
polygonRgba(Pointer<SdlRenderer> renderer, List<SdlxFPoint> points, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
rectangleColor(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
rectangleRgba(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
rotateSurface90Degrees(Pointer<SdlSurface> src, int numClockwiseTurns) → Pointer<SdlSurface>
roundedBoxColor(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, double rad, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
roundedBoxRgba(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, double rad, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
roundedRectangleColor(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, double rad, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
roundedRectangleRgba(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, double rad, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
stackLine(SdlxFPoint p1, SdlxFPoint p2) → List<SdlxFPoint>
stackPolygon(List<SdlxFPoint> points) → List<SdlxFPoint>
stackRectangle(SdlxFPoint p1, SdlxFPoint p2) → List<SdlxFPoint>
stringColor(Pointer<SdlRenderer> renderer, double x, double y, String s, SdlxColor color) → bool
stringRgba(Pointer<SdlRenderer> renderer, double x, double y, String s, int r, int g, int b, int a) → bool
texturedPolygon(Pointer<SdlRenderer> renderer, List<SdlxFPoint> points, Pointer<SdlSurface> texture, int textureDx, int textureDy) → bool
texturedPolygonMt(Pointer<SdlRenderer> renderer, List<SdlxFPoint> points, Pointer<SdlSurface> texture, int textureDx, int textureDy) → bool
thickLineColor(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, double width, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
thickLineRgba(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, double width, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
trigonColor(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, double x3, double y3, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
trigonRgba(Pointer<SdlRenderer> renderer, double x1, double y1, double x2, double y2, double x3, double y3, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
vline(Pointer<SdlRenderer> renderer, double x, double y1, double y2) → bool
vlineColor(Pointer<SdlRenderer> renderer, double x, double y1, double y2, SdlxColor color, {int blendMode = SDL_BLENDMODE_BLEND}) → bool
vlineRgba(Pointer<SdlRenderer> renderer, double x, double y1, double y2, int r, int g, int b, int a, {int blendMode = SDL_BLENDMODE_BLEND}) → bool