locale topic
CategoryLocale
SDL locale services.
This provides a way to get a list of preferred locales (language plus country) for the user. There is exactly one function: SDL_GetPreferredLocales(), which handles all the heavy lifting, and offers documentation on all the strange ways humans might have configured their language settings.
Functions
-
sdlGetPreferredLocales(
Pointer< localeInt32> count) → Pointer<Pointer< SdlLocale> > - Report the user's preferred locale.
-
sdlxGetPreferredLocales(
) → List< localeSdlxLocale> - Report the user's preferred locale.