version topic

CategoryVersion

Functionality to query the current SDL version, both as headers the app was compiled against, and a library the app is linked to.

Functions

sdlGetRevision() → String? version
Get the code revision of the SDL library that is linked against your program.
sdlGetVersion() → int version
Get the version of SDL that is linked against your program.