sdlGetWindowFullscreenMode function
Query the display mode to use when a window is visible at fullscreen.
\param window the window to query. \returns a pointer to the exclusive fullscreen mode to use or NULL for borderless fullscreen desktop mode.
\since This function is available since SDL 3.1.3.
\sa SDL_SetWindowFullscreenMode \sa SDL_SetWindowFullscreen
extern SDL_DECLSPEC const SDL_DisplayMode * SDLCALL SDL_GetWindowFullscreenMode(SDL_Window *window)
Implementation
Pointer<SdlDisplayMode> sdlGetWindowFullscreenMode(Pointer<SdlWindow> window) {
final sdlGetWindowFullscreenModeLookupFunction = libSdl3.lookupFunction<
Pointer<SdlDisplayMode> Function(Pointer<SdlWindow> window),
Pointer<SdlDisplayMode> Function(
Pointer<SdlWindow> window)>('SDL_GetWindowFullscreenMode');
return sdlGetWindowFullscreenModeLookupFunction(window);
}