SdlAsyncIoPointerEx extension
- on
Methods
-
close(
Pointer< asyncioSdlAsyncIoQueue> queue, Pointer<NativeType> userdata, {bool flush = false}) → bool -
Available on Pointer<
Close and free any allocated resources for an async I/O object.SdlAsyncIo> , provided by the SdlAsyncIoPointerEx extension -
getSize(
) → int asyncio -
Available on Pointer<
Use this function to get the size of the data stream in an SDL_AsyncIO.SdlAsyncIo> , provided by the SdlAsyncIoPointerEx extension -
read(
Pointer< asyncioNativeType> ptr, int offset, int size, Pointer<SdlAsyncIoQueue> queue, Pointer<NativeType> userdata) → bool -
Available on Pointer<
Start an async read.SdlAsyncIo> , provided by the SdlAsyncIoPointerEx extension -
write(
Pointer< asyncioNativeType> ptr, int offset, int size, Pointer<SdlAsyncIoQueue> queue, Pointer<NativeType> userdata) → bool -
Available on Pointer<
Start an async write.SdlAsyncIo> , provided by the SdlAsyncIoPointerEx extension