SdlAsyncIoQueuePointerEx extension
Methods
-
destroy(
) → void asyncio -
Available on Pointer<
Destroy a previously-created async I/O task queue.SdlAsyncIoQueue> , provided by the SdlAsyncIoQueuePointerEx extension -
getResult(
SdlxAsyncIoOutcome outcome) → bool asyncio -
Available on Pointer<
Query an async I/O task queue for completed tasks.SdlAsyncIoQueue> , provided by the SdlAsyncIoQueuePointerEx extension -
loadFile(
String file, Pointer< asyncioNativeType> userdata) → bool -
Available on Pointer<
Load all the data from a file path, asynchronously.SdlAsyncIoQueue> , provided by the SdlAsyncIoQueuePointerEx extension -
signal(
) → void asyncio -
Available on Pointer<
Wake up any threads that are blocking in SDL_WaitAsyncIOResult().SdlAsyncIoQueue> , provided by the SdlAsyncIoQueuePointerEx extension -
waitResult(
SdlxAsyncIoOutcome outcome, int timeoutMS) → bool asyncio -
Available on Pointer<
Block until an async I/O task queue has a completed task.SdlAsyncIoQueue> , provided by the SdlAsyncIoQueuePointerEx extension