SdlCameraPointerEx extension
Methods
-
acquireFrame(
) → ({Pointer< cameraSdlSurface> surface, int timestampNs})? -
Available on Pointer<
Acquire a frame.SdlCamera> , provided by the SdlCameraPointerEx extension -
close(
) → void camera -
Available on Pointer<
Use this function to shut down camera processing and close the camera device.SdlCamera> , provided by the SdlCameraPointerEx extension -
getFormat(
SdlxCameraSpec spec) → bool camera -
Available on Pointer<
Get the spec that a camera is using when generating images.SdlCamera> , provided by the SdlCameraPointerEx extension -
getId(
) → int camera -
Available on Pointer<
Get the instance ID of an opened camera.SdlCamera> , provided by the SdlCameraPointerEx extension -
getPermissionState(
) → int camera -
Available on Pointer<
Query if camera access has been approved by the user.SdlCamera> , provided by the SdlCameraPointerEx extension -
getProperties(
Pointer< cameraSdlCamera> camera) → int -
Available on Pointer<
Get the properties associated with an opened camera.SdlCamera> , provided by the SdlCameraPointerEx extension -
releaseFrame(
Pointer< cameraSdlSurface> frame) → void -
Available on Pointer<
Release a frame of video acquired from a camera.SdlCamera> , provided by the SdlCameraPointerEx extension