SdlEnvironmentPointerEx extension

on

Methods

destroy() → void stdinc

Available on Pointer<SdlEnvironment>, provided by the SdlEnvironmentPointerEx extension

Destroy a set of environment variables.
getVariable(String name) String? stdinc

Available on Pointer<SdlEnvironment>, provided by the SdlEnvironmentPointerEx extension

Get the value of a variable in the environment.
getVariables() List<String> stdinc

Available on Pointer<SdlEnvironment>, provided by the SdlEnvironmentPointerEx extension

Get all variables in the environment.
setVariable(String name, String value, bool overwrite) bool stdinc

Available on Pointer<SdlEnvironment>, provided by the SdlEnvironmentPointerEx extension

Set the value of a variable in the environment.
unsetVariable(String name) bool stdinc

Available on Pointer<SdlEnvironment>, provided by the SdlEnvironmentPointerEx extension

Clear a variable from the environment.