SdlGpuCommandBufferPointerEx extension
Methods
-
acquireSwapchainTexture(
Pointer< gpuSdlWindow> window) → ({int height, Pointer<SdlGpuTexture> texture, int width})? -
Available on Pointer<
Acquire a texture to use in presentation.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
beginComputePass(
{List< gpuSdlxGpuStorageTextureReadWriteBinding> ? textures, List<SdlxGpuStorageBufferReadWriteBinding> ? buffers}) → Pointer<SdlGpuComputePass> -
Available on Pointer<
Begins a compute pass on a command buffer.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
beginCopyPass(
) → Pointer< gpuSdlGpuCopyPass> -
Available on Pointer<
Begins a copy pass on a command buffer.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
beginRenderPass(
List< gpuSdlxGpuColorTargetInfo> colorTargetInfo, {SdlxGpuDepthStencilTargetInfo? depthStencilTargetInfo}) → Pointer<SdlGpuRenderPass> -
Available on Pointer<
Begins a render pass on a command buffer.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
blitTexture(
SdlxGpuBlitInfo info) → void gpu -
Available on Pointer<
Blits from a source texture region to a destination texture region.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
cancel(
) → bool gpu -
Available on Pointer<
Cancels a command buffer.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
generateMipmapsForTexture(
Pointer< gpuSdlGpuTexture> texture) → void -
Available on Pointer<
Generates mipmaps for the given texture.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
insertDebugLabel(
String text) → void gpu -
Available on Pointer<
Inserts an arbitrary string label into the command buffer callstream.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
popDebugGroup(
) → void gpu -
Available on Pointer<
Ends the most-recently pushed debug group.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
pushComputeUniformData(
int slotIndex, Pointer< gpuVoid> data, int length) → void -
Available on Pointer<
Pushes data to a uniform slot on the command buffer.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
pushDebugGroup(
String name) → void gpu -
Available on Pointer<
Begins a debug group with an arbitrary name.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
pushFragmentUniformData(
int slotIndex, Pointer< gpuVoid> data, int length) → void -
Available on Pointer<
Pushes data to a fragment uniform slot on the command buffer.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
pushVertexUniformData(
int slotIndex, Pointer< gpuVoid> data, int length) → void -
Available on Pointer<
Pushes data to a vertex uniform slot on the command buffer.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
submit(
) → bool gpu -
Available on Pointer<
Submits a command buffer so its commands can be processed on the GPU.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
submitAndAcquireFence(
) → Pointer< gpuSdlGpuFence> -
Available on Pointer<
Submits a command buffer so its commands can be processed on the GPU, and acquires a fence associated with the command buffer.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension -
waitAndAcquireSwapchainTexture(
Pointer< gpuSdlWindow> window) → ({int height, Pointer<SdlGpuTexture> texture, int width})? -
Available on Pointer<
Blocks the thread until a swapchain texture is available to be acquired, and then acquires it.SdlGpuCommandBuffer> , provided by the SdlGpuCommandBufferPointerEx extension