SdlGpuComputePassPointerEx extension
Methods
-
bindPipeline(
Pointer< gpuSdlGpuComputePipeline> computePipeline) → void -
Available on Pointer<
Binds a compute pipeline on a command buffer for use in compute dispatch.SdlGpuComputePass> , provided by the SdlGpuComputePassPointerEx extension -
bindSamplers(
List< gpuSdlxGpuTextureSamplerBinding> bindings, {int firstSlot = 0}) → void -
Available on Pointer<
Binds texture-sampler pairs for use on the compute shader.SdlGpuComputePass> , provided by the SdlGpuComputePassPointerEx extension -
bindStorageBuffers(
List< gpuPointer< storageBuffers, {int firstSlot = 0}) → voidSdlGpuBuffer> > -
Available on Pointer<
Binds storage buffers as readonly for use on the compute pipeline.SdlGpuComputePass> , provided by the SdlGpuComputePassPointerEx extension -
bindStorageTextures(
List< gpuPointer< storageTextures, {int firstSlot = 0}) → voidSdlGpuTexture> > -
Available on Pointer<
Binds storage textures as readonly for use on the compute pipeline.SdlGpuComputePass> , provided by the SdlGpuComputePassPointerEx extension -
dispatch(
int groupcountX, int groupcountY, int groupcountZ) → void gpu -
Available on Pointer<
Dispatches compute work.SdlGpuComputePass> , provided by the SdlGpuComputePassPointerEx extension -
dispatchIndirect(
Pointer< gpuSdlGpuBuffer> buffer, int offset) → void -
Available on Pointer<
Dispatches compute work with parameters set from a buffer.SdlGpuComputePass> , provided by the SdlGpuComputePassPointerEx extension -
end(
) → void gpu -
Available on Pointer<
Ends the current compute pass.SdlGpuComputePass> , provided by the SdlGpuComputePassPointerEx extension