bindStorageBuffers method
Binds storage buffers as readonly for use on the compute pipeline.
These buffers must have been created with SDL_GPU_BUFFERUSAGE_COMPUTE_STORAGE_READ.
Be sure your shader is set up according to the requirements documented in SDL_CreateGPUComputePipeline().
\param compute_pass a compute pass handle. \param first_slot the compute storage buffer slot to begin binding from. \param storage_buffers an array of storage buffer binding structs. \param num_bindings the number of storage buffers to bind from the array.
\since This function is available since SDL 3.2.0.
\sa SDL_CreateGPUComputePipeline
extern SDL_DECLSPEC void SDLCALL SDL_BindGPUComputeStorageBuffers( SDL_GPUComputePass *compute_pass, Uint32 first_slot, SDL_GPUBuffer *const *storage_buffers, Uint32 num_bindings)
Implementation
void bindStorageBuffers(
List<Pointer<SdlGpuBuffer>> storageBuffers, {
int firstSlot = 0,
}) => sdlxBindGpuComputeStorageBuffers(
this,
storageBuffers,
firstSlot: firstSlot,
);