SdlGpuCopyPassPointerEx extension
Methods
-
copyBufferToBuffer(
SdlxGpuBufferLocation source, SdlxGpuBufferLocation destination, int size, {bool cycle = false}) → void gpu -
Available on Pointer<
Performs a buffer-to-buffer copy.SdlGpuCopyPass> , provided by the SdlGpuCopyPassPointerEx extension -
copyTextureToTexture(
SdlxGpuTextureLocation source, SdlxGpuTextureLocation destination, int w, int h, int d, {bool cycle = false}) → void gpu -
Available on Pointer<
Performs a texture-to-texture copy.SdlGpuCopyPass> , provided by the SdlGpuCopyPassPointerEx extension -
downloadFromBuffer(
SdlxGpuBufferRegion source, SdlxGpuTransferBufferLocation destination) → void gpu -
Available on Pointer<
Copies data from a buffer to a transfer buffer on the GPU timeline.SdlGpuCopyPass> , provided by the SdlGpuCopyPassPointerEx extension -
downloadFromTexture(
SdlxGpuTextureRegion source, SdlxGpuTextureTransferInfo destination) → void gpu -
Available on Pointer<
Copies data from a texture to a transfer buffer on the GPU timeline.SdlGpuCopyPass> , provided by the SdlGpuCopyPassPointerEx extension -
end(
) → void gpu -
Available on Pointer<
Ends the current copy pass.SdlGpuCopyPass> , provided by the SdlGpuCopyPassPointerEx extension -
uploadToBuffer(
SdlxGpuTransferBufferLocation source, SdlxGpuBufferRegion destination, {bool cycle = false}) → void gpu -
Available on Pointer<
Uploads data from a transfer buffer to a buffer.SdlGpuCopyPass> , provided by the SdlGpuCopyPassPointerEx extension -
uploadToTexture(
SdlxGpuTextureTransferInfo source, SdlxGpuTextureRegion destination, {bool cycle = false}) → void gpu -
Available on Pointer<
Uploads data from a transfer buffer to a texture.SdlGpuCopyPass> , provided by the SdlGpuCopyPassPointerEx extension