SdlGpuDevicePointerEx extension
- on
Methods
-
acquireCommandBuffer(
) → Pointer< gpuSdlGpuCommandBuffer> -
Available on Pointer<
Acquire a command buffer.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
claimWindowFor(
Pointer< gpuSdlWindow> window) → bool -
Available on Pointer<
Claims a window, creating a swapchain structure for it.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
createBuffer(
SdlxGpuBufferCreateInfo createinfo) → Pointer< gpuSdlGpuBuffer> -
Available on Pointer<
Creates a buffer object to be used in graphics or compute workflows.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
createComputePipeline(
SdlxGpuComputePipelineCreateInfo createinfo) → Pointer< gpuSdlGpuComputePipeline> -
Available on Pointer<
Creates a pipeline object to be used in a compute workflow.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
createGraphicsPipeline(
SdlxGpuGraphicsPipelineCreateInfo createinfo) → Pointer< gpuSdlGpuGraphicsPipeline> -
Available on Pointer<
Creates a pipeline object to be used in a graphics workflow.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
createSampler(
SdlxGpuSamplerCreateInfo createinfo) → Pointer< gpuSdlGpuSampler> -
Available on Pointer<
Creates a sampler object to be used when binding textures in a graphics workflow.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
createShader(
SdlxGpuShaderCreateInfo createinfo) → Pointer< gpuSdlGpuShader> -
Available on Pointer<
Creates a shader to be used when creating a graphics pipeline.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
createTexture(
SdlxGpuTextureCreateInfo createinfo) → Pointer< gpuSdlGpuTexture> -
Available on Pointer<
Creates a texture object to be used in graphics or compute workflows.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
createTransferBuffer(
SdlxGpuTransferBufferCreateInfo createinfo) → Pointer< gpuSdlGpuTransferBuffer> -
Available on Pointer<
Creates a transfer buffer to be used when uploading to or downloading from graphics resources.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
destroy(
) → void gpu -
Available on Pointer<
Destroys a GPU context previously returned by SDL_CreateGPUDevice.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
gdkResume(
) → void gpu -
Available on Pointer<
Call this to resume GPU operation on Xbox after receiving the SDL_EVENT_WILL_ENTER_FOREGROUND event.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
gdkSuspend(
) → void gpu -
Available on Pointer<
Call this to suspend GPU operation on Xbox after receiving the SDL_EVENT_DID_ENTER_BACKGROUND event.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
getDriver(
) → String? gpu -
Available on Pointer<
Returns the name of the backend used to create this GPU context.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
getProperties(
) → int gpu -
Available on Pointer<
Get the properties associated with a GPU device.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
getShaderFormats(
) → int gpu -
Available on Pointer<
Returns the supported shader formats for this GPU context.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
getSwapchainTextureFormat(
Pointer< gpuSdlWindow> window) → int -
Available on Pointer<
Obtains the texture format of the swapchain for the given window.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
mapTransferBuffer(
Pointer< gpuSdlGpuTransferBuffer> transferBuffer, {bool cycle = false}) → Pointer<Void> -
Available on Pointer<
Maps a transfer buffer into application address space.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
queryFence(
Pointer< gpuSdlGpuFence> fence) → bool -
Available on Pointer<
Checks the status of a fence.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
releaseBuffer(
Pointer< gpuSdlGpuBuffer> buffer) → void -
Available on Pointer<
Frees the given buffer as soon as it is safe to do so.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
releaseComputePipeline(
Pointer< gpuSdlGpuComputePipeline> computePipeline) → void -
Available on Pointer<
Frees the given compute pipeline as soon as it is safe to do so.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
releaseFence(
Pointer< gpuSdlGpuFence> fence) → void -
Available on Pointer<
Releases a fence obtained from SDL_SubmitGPUCommandBufferAndAcquireFence.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
releaseGraphicsPipeline(
Pointer< gpuSdlGpuGraphicsPipeline> graphicsPipeline) → void -
Available on Pointer<
Frees the given graphics pipeline as soon as it is safe to do so.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
releaseSampler(
Pointer< gpuSdlGpuSampler> sampler) → void -
Available on Pointer<
Frees the given sampler as soon as it is safe to do so.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
releaseShader(
Pointer< gpuSdlGpuShader> shader) → void -
Available on Pointer<
Frees the given shader as soon as it is safe to do so.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
releaseTexture(
Pointer< gpuSdlGpuTexture> texture) → void -
Available on Pointer<
Frees the given texture as soon as it is safe to do so.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
releaseTransferBuffer(
Pointer< gpuSdlGpuTransferBuffer> transferBuffer) → void -
Available on Pointer<
Frees the given transfer buffer as soon as it is safe to do so.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
releaseWindowFrom(
Pointer< gpuSdlWindow> window) → void -
Available on Pointer<
Unclaims a window, destroying its swapchain structure.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
setAllowedFramesInFlight(
int allowedFramesInFlight) → bool gpu -
Available on Pointer<
Configures the maximum allowed number of frames in flight.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
setBufferName(
Pointer< gpuSdlGpuBuffer> buffer, String text) → void -
Available on Pointer<
Sets an arbitrary string constant to label a buffer.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
setSwapchainParameters(
Pointer< gpuSdlWindow> window, int swapchainComposition, int presentMode) → bool -
Available on Pointer<
Changes the swapchain parameters for the given claimed window.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
setTextureName(
Pointer< gpuSdlGpuTexture> texture, String text) → void -
Available on Pointer<
Sets an arbitrary string constant to label a texture.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
textureSupportsFormat(
int format, int type, int usage) → bool gpu -
Available on Pointer<
Determines whether a texture format is supported for a given type and usage.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
textureSupportsSampleCount(
int format, int sampleCount) → bool gpu -
Available on Pointer<
Determines if a sample count for a texture format is supported.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
unmapTransferBuffer(
Pointer< gpuSdlGpuTransferBuffer> transferBuffer) → void -
Available on Pointer<
Unmaps a previously mapped transfer buffer.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
waitForFences(
List< gpuPointer< fences, {bool waitAll = true}) → boolSdlGpuFence> > -
Available on Pointer<
Blocks the thread until the given fences are signaled.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
waitForIdle(
) → bool gpu -
Available on Pointer<
Blocks the thread until the GPU is completely idle.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
waitForSwapchain(
Pointer< gpuSdlWindow> window) → bool -
Available on Pointer<
Blocks the thread until all presenting command buffers are finished executing.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
windowSupportsPresentMode(
Pointer< gpuSdlWindow> window, int presentMode) → bool -
Available on Pointer<
Determines whether a presentation mode is supported by the window.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension -
windowSupportsSwapchainComposition(
Pointer< gpuSdlWindow> window, int swapchainComposition) → bool -
Available on Pointer<
Determines whether a swapchain composition is supported by the window.SdlGpuDevice> , provided by the SdlGpuDevicePointerEx extension