SdlGpuRenderPassPointerEx extension
Methods
-
bindFragmentSamplers(
List< gpuSdlxGpuTextureSamplerBinding> bindings, {int firstSlot = 0}) → void -
Available on Pointer<
Binds texture-sampler pairs for use on the fragment shader.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
bindFragmentStorageBuffers(
List< gpuPointer< storageBuffers, {int firstSlot = 0}) → voidSdlGpuBuffer> > -
Available on Pointer<
Binds storage buffers for use on the fragment shader.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
bindFragmentStorageTextures(
List< gpuPointer< storageTextures, {int firstSlot = 0}) → voidSdlGpuTexture> > -
Available on Pointer<
Binds storage textures for use on the fragment shader.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
bindGraphicsPipeline(
Pointer< gpuSdlGpuGraphicsPipeline> graphicsPipeline) → void -
Available on Pointer<
Binds a graphics pipeline on a render pass to be used in rendering.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
bindIndexBuffer(
SdlxGpuBufferBinding binding, int indexElementSize) → void gpu -
Available on Pointer<
Binds an index buffer on a command buffer for use with subsequent draw calls.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
bindVertexBuffers(
List< gpuSdlxGpuBufferBinding> bindings, {int firstSlot = 0}) → void -
Available on Pointer<
Binds vertex buffers on a command buffer for use with subsequent draw calls.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
bindVertexSamplers(
List< gpuSdlxGpuTextureSamplerBinding> bindings, {int firstSlot = 0}) → void -
Available on Pointer<
Binds texture-sampler pairs for use on the vertex shader.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
bindVertexStorageBuffers(
List< gpuPointer< storageBuffers, {int firstSlot = 0}) → voidSdlGpuBuffer> > -
Available on Pointer<
Binds storage buffers for use on the vertex shader.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
bindVertexStorageTextures(
List< gpuPointer< storageTextures, {int firstSlot = 0}) → voidSdlGpuTexture> > -
Available on Pointer<
Binds storage textures for use on the vertex shader.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
drawIndexedPrimitives(
int numIndices, int numInstances, int firstIndex, int vertexOffset, int firstInstance) → void gpu -
Available on Pointer<
Draws data using bound graphics state with an index buffer and instancing enabled.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
drawIndexedPrimitivesIndirect(
Pointer< gpuSdlGpuBuffer> buffer, int offset, int drawCount) → void -
Available on Pointer<
Draws data using bound graphics state with an index buffer enabled and with draw parameters set from a buffer.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
drawPrimitives(
int numVertices, int numInstances, int firstVertex, int firstInstance) → void gpu -
Available on Pointer<
Draws data using bound graphics state.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
drawPrimitivesIndirect(
Pointer< gpuSdlGpuBuffer> buffer, int offset, int drawCount) → void -
Available on Pointer<
Draws data using bound graphics state and with draw parameters set from a buffer.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
end(
) → void gpu -
Available on Pointer<
Ends the given render pass.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
setBlendConstants(
SdlxFColor blendConstants) → void gpu -
Available on Pointer<
Sets the current blend constants on a command buffer.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
setScissor(
SdlxRect scissor) → void gpu -
Available on Pointer<
Sets the current scissor state on a command buffer.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
setStencilReference(
int reference) → void gpu -
Available on Pointer<
Sets the current stencil reference value on a command buffer.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension -
setViewport(
SdlxGpuViewport viewport) → void gpu -
Available on Pointer<
Sets the current viewport state on a command buffer.SdlGpuRenderPass> , provided by the SdlGpuRenderPassPointerEx extension