SdlHapticCondition class final haptic

Inheritance
Implemented types
Available extensions

Constructors

SdlHapticCondition()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
button int
getter/setter pair
center Array<Int16>
getter/setter pair
deadband Array<Uint16>
getter/setter pair
delay int
getter/setter pair
direction SdlHapticDirection
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interval int
getter/setter pair
leftCoeff Array<Int16>
getter/setter pair
leftSat Array<Uint16>
getter/setter pair
length int
getter/setter pair
rightCoeff Array<Int16>
getter/setter pair
rightSat Array<Uint16>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited