- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the UnionAddress extension
The memory address of the underlying data.no setter - ant ↔ SdlHapticConstant
-
getter/setter pair
- condition ↔ SdlHapticCondition
-
getter/setter pair
- custom ↔ SdlHapticCustom
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- leftright ↔ SdlHapticLeftRight
-
getter/setter pair
- periodic ↔ SdlHapticPeriodic
-
getter/setter pair
- ramp ↔ SdlHapticRamp
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited