SdlHapticPointerEx extension

on

Methods

close() → void haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Close a haptic device previously opened with SDL_OpenHaptic().
createEffect(SdlxHapticEffect effect) int haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Create a new haptic effect on a specified device.
destroyEffect(int effect) → void haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Destroy a haptic effect on the device.
effectSupported(SdlxHapticEffect effect) bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Check to see if an effect is supported by a haptic device.
getEffectStatus(int effect) bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Get the status of the current effect on the specified haptic device.
getFeatures() int haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Get the haptic device's supported features in bitwise manner.
getId() int haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Get the instance ID of an opened haptic device.
getMaxEffects() int haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Get the number of effects a haptic device can store.
getMaxEffectsPlaying() int haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Get the number of effects a haptic device can play at the same time.
getName() String? haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Get the implementation dependent name of a haptic device.
getNumAxes() int haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Get the number of haptic axes the device has.
initRumble() bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Initialize a haptic device for simple rumble playback.
pause() bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Pause a haptic device.
playRumble(double strength, int length) bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Run a simple rumble effect on a haptic device.
resume() bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Resume a haptic device.
rumbleSupported() bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Check whether rumble is supported on a haptic device.
runEffect(int effect, int iterations) bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Run the haptic effect on its associated haptic device.
setAutocenter(int autocenter) bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Set the global autocenter of the device.
setGain(int gain) bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Set the global gain of the specified haptic device.
stopEffect(int effect) bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Stop the haptic effect on its associated haptic device.
stopEffects() bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Stop all the currently playing effects on a haptic device.
stopRumble() bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Stop the simple rumble on a haptic device.
updateEffect(int effect, SdlxHapticEffect data) bool haptic

Available on Pointer<SdlHaptic>, provided by the SdlHapticPointerEx extension

Update the properties of an effect.