createEffect method
Create a new haptic effect on a specified device.
\param haptic an SDL_Haptic device to create the effect on. \param effect an SDL_HapticEffect structure containing the properties of the effect to create. \returns the ID of the effect on success or -1 on failure; call SDL_GetError() for more information.
\since This function is available since SDL 3.2.0.
\sa SDL_DestroyHapticEffect \sa SDL_RunHapticEffect \sa SDL_UpdateHapticEffect
extern SDL_DECLSPEC SDL_HapticEffectID SDLCALL SDL_CreateHapticEffect(SDL_Haptic *haptic, const SDL_HapticEffect *effect)
Implementation
int createEffect(SdlxHapticEffect effect) =>
sdlxCreateHapticEffect(this, effect);