SdlIoStreamPointerEx extension

on

Methods

close() bool iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Close and free an allocated SDL_IOStream structure.
flush() bool iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Flush any buffered data in the stream.
getProperties() int iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Get the properties associated with an SDL_IOStream.
getSize() int iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Use this function to get the size of the data stream in an SDL_IOStream.
getStatus() int iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Query the stream status of an SDL_IOStream.
loadFile(SdlxDataResult result, {bool closeio = false}) bool iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Load all the data from an SDL data stream.
printf(String fmt) int iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Print to an SDL_IOStream data stream.
readInt16([Endian endian = Endian.big]) int? iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Use this function to read 16 bits of little-endian data from an SDL_IOStream and return in native format.
readInt32([Endian endian = Endian.big]) int? iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Use this function to read 32 bits of little-endian data from an SDL_IOStream and return in native format.
readInt64([Endian endian = Endian.big]) int? iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Use this function to read 64 bits of little-endian data from an SDL_IOStream and return in native format.
readInt8() int? iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Use this function to read a signed byte from an SDL_IOStream.
readString(int size) String? iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Read from a data source.
readUint16([Endian endian = Endian.big]) int? iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Use this function to read 16 bits of little-endian data from an SDL_IOStream and return in native format.
readUint32([Endian endian = Endian.big]) int? iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Use this function to read 32 bits of little-endian data from an SDL_IOStream and return in native format.
readUint64([Endian endian = Endian.big]) int? iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Use this function to read 64 bits of little-endian data from an SDL_IOStream and return in native format.
readUint8() int? iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Use this function to read a byte from an SDL_IOStream.
readUint8List(int size) Uint8List? iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Read from a data source.
saveFile(Uint8List data, {bool closeio = false}) bool iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Save all the data into an SDL data stream.
seek(int offset, int whence) int iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Seek within an SDL_IOStream data stream.
tell() int iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Determine the current read/write offset in an SDL_IOStream data stream.
vprintf(String fmt) int iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Print to an SDL_IOStream data stream.
writeString(String str) int iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Write to an SDL_IOStream data stream.
writeUint8List(Uint8List data) int iostream

Available on Pointer<SdlIoStream>, provided by the SdlIoStreamPointerEx extension

Write to an SDL_IOStream data stream.