SdlIoStreamPointerEx extension
- on
Methods
-
close(
) → bool iostream -
Available on Pointer<
Close and free an allocated SDL_IOStream structure.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
flush(
) → bool iostream -
Available on Pointer<
Flush any buffered data in the stream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
getProperties(
) → int iostream -
Available on Pointer<
Get the properties associated with an SDL_IOStream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
getSize(
) → int iostream -
Available on Pointer<
Use this function to get the size of the data stream in an SDL_IOStream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
getStatus(
) → int iostream -
Available on Pointer<
Query the stream status of an SDL_IOStream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
loadFile(
SdlxDataResult result, {bool closeio = false}) → bool iostream -
Available on Pointer<
Load all the data from an SDL data stream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
printf(
String fmt) → int iostream -
Available on Pointer<
Print to an SDL_IOStream data stream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
readInt16(
[Endian endian = Endian.big]) → int? iostream -
Available on Pointer<
Use this function to read 16 bits of little-endian data from an SDL_IOStream and return in native format.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
readInt32(
[Endian endian = Endian.big]) → int? iostream -
Available on Pointer<
Use this function to read 32 bits of little-endian data from an SDL_IOStream and return in native format.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
readInt64(
[Endian endian = Endian.big]) → int? iostream -
Available on Pointer<
Use this function to read 64 bits of little-endian data from an SDL_IOStream and return in native format.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
readInt8(
) → int? iostream -
Available on Pointer<
Use this function to read a signed byte from an SDL_IOStream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
readString(
int size) → String? iostream -
Available on Pointer<
Read from a data source.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
readUint16(
[Endian endian = Endian.big]) → int? iostream -
Available on Pointer<
Use this function to read 16 bits of little-endian data from an SDL_IOStream and return in native format.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
readUint32(
[Endian endian = Endian.big]) → int? iostream -
Available on Pointer<
Use this function to read 32 bits of little-endian data from an SDL_IOStream and return in native format.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
readUint64(
[Endian endian = Endian.big]) → int? iostream -
Available on Pointer<
Use this function to read 64 bits of little-endian data from an SDL_IOStream and return in native format.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
readUint8(
) → int? iostream -
Available on Pointer<
Use this function to read a byte from an SDL_IOStream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
readUint8List(
int size) → Uint8List? iostream -
Available on Pointer<
Read from a data source.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
saveFile(
Uint8List data, {bool closeio = false}) → bool iostream -
Available on Pointer<
Save all the data into an SDL data stream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
seek(
int offset, int whence) → int iostream -
Available on Pointer<
Seek within an SDL_IOStream data stream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
tell(
) → int iostream -
Available on Pointer<
Determine the current read/write offset in an SDL_IOStream data stream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
vprintf(
String fmt) → int iostream -
Available on Pointer<
Print to an SDL_IOStream data stream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
writeString(
String str) → int iostream -
Available on Pointer<
Write to an SDL_IOStream data stream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension -
writeUint8List(
Uint8List data) → int iostream -
Available on Pointer<
Write to an SDL_IOStream data stream.SdlIoStream> , provided by the SdlIoStreamPointerEx extension