getPathForId static method
Get the implementation dependent path of a joystick.
This can be called before any joysticks are opened.
\param instance_id the joystick instance ID. \returns the path of the selected joystick. If no path can be found, this function returns NULL; call SDL_GetError() for more information.
\threadsafety It is safe to call this function from any thread.
\since This function is available since SDL 3.2.0.
\sa SDL_GetJoystickPath \sa SDL_GetJoysticks
extern SDL_DECLSPEC const char * SDLCALL SDL_GetJoystickPathForID(SDL_JoystickID instance_id)
Implementation
static String? getPathForId(int instanceId) =>
sdlGetJoystickPathForId(instanceId);