SdlJoystickPointerEx extension
- on
Methods
-
close(
) → void joystick -
Available on Pointer<
Close a joystick previously opened with SDL_OpenJoystick().SdlJoystick> , provided by the SdlJoystickPointerEx extension -
connected(
) → bool joystick -
Available on Pointer<
Get the status of a specified joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getAxis(
int axis) → int joystick -
Available on Pointer<
Get the current state of an axis control on a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getAxisInitialState(
int axis) → int? joystick -
Available on Pointer<
Get the initial state of an axis control on a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getBall(
int ball) → SdlxPoint? joystick -
Available on Pointer<
Get the ball axis change since the last poll.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getButton(
int button) → bool joystick -
Available on Pointer<
Get the current state of a button on a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getConnectionState(
) → int joystick -
Available on Pointer<
Get the connection state of a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getFirmwareVersion(
) → int joystick -
Available on Pointer<
Get the firmware version of an opened joystick, if available.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getGuid(
) → SdlGuid joystick -
Available on Pointer<
Get the implementation-dependent GUID for the joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getHat(
int hat) → int joystick -
Available on Pointer<
Get the current state of a POV hat on a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getId(
) → int joystick -
Available on Pointer<
Get the instance ID of an opened joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getName(
) → String? joystick -
Available on Pointer<
Get the implementation dependent name of a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getNumBalls(
) → int joystick -
Available on Pointer<
Get the number of trackballs on a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getNumButtons(
) → int joystick -
Available on Pointer<
Get the number of buttons on a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getNumHats(
) → int joystick -
Available on Pointer<
Get the number of POV hats on a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getNumJAxes(
) → int joystick -
Available on Pointer<
Get the number of general axis controls on a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getPath(
) → String? joystick -
Available on Pointer<
Get the implementation dependent path of a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getPlayerIndex(
) → int joystick -
Available on Pointer<
Get the player index of an opened joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getPowerInfo(
) → ({int percent, int state}) joystick -
Available on Pointer<
Get the battery state of a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getProduct(
) → int joystick -
Available on Pointer<
Get the USB product ID of an opened joystick, if available.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getProductVersion(
) → int joystick -
Available on Pointer<
Get the product version of an opened joystick, if available.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getProperties(
) → int joystick -
Available on Pointer<
Get the properties associated with a joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getSerial(
) → String? joystick -
Available on Pointer<
Get the serial number of an opened joystick, if available.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getType(
) → int joystick -
Available on Pointer<
Get the type of an opened joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
getVendor(
) → int joystick -
Available on Pointer<
Get the USB vendor ID of an opened joystick, if available.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
rumble(
int lowFrequencyRumble, int highFrequencyRumble, int durationMs) → bool joystick -
Available on Pointer<
Start a rumble effect.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
rumbleTriggers(
int leftRumble, int rightRumble, int durationMs) → bool joystick -
Available on Pointer<
Start a rumble effect in the joystick's triggers.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
sendVirtualSensorData(
int type, int sensorTimestamp, List< joystickdouble> data) → bool -
Available on Pointer<
Send a sensor update for an opened virtual joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
setEffect(
Pointer< joystickVoid> data, int size) → bool -
Available on Pointer<
Send a joystick specific effect packet.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
setLed(
int red, int green, int blue) → bool joystick -
Available on Pointer<
Update a joystick's LED color.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
setPlayerIndex(
int playerIndex) → bool joystick -
Available on Pointer<
Set the player index of an opened joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
setVirtualAxis(
int axis, int value) → bool joystick -
Available on Pointer<
Set the state of an axis on an opened virtual joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
setVirtualBall(
int ball, int xrel, int yrel) → bool joystick -
Available on Pointer<
Generate ball motion on an opened virtual joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
setVirtualButton(
int button, bool down) → bool joystick -
Available on Pointer<
Set the state of a button on an opened virtual joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
setVirtualHat(
int hat, int value) → bool joystick -
Available on Pointer<
Set the state of a hat on an opened virtual joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension -
setVirtualTouchpad(
int touchpad, int finger, bool down, double x, double y, double pressure) → bool joystick -
Available on Pointer<
Set touchpad finger state on an opened virtual joystick.SdlJoystick> , provided by the SdlJoystickPointerEx extension