SdlRendererPointerEx extension
- on
Methods
-
addVulkanSemaphores(
int waitStageMask, int waitSemaphore, int signalSemaphore) → bool render -
Available on Pointer<
Add a set of synchronization semaphores for the current frame.SdlRenderer> , provided by the SdlRendererPointerEx extension -
clear(
) → bool render -
Available on Pointer<
Clear the current rendering target with the drawing color.SdlRenderer> , provided by the SdlRendererPointerEx extension -
clipEnabled(
) → bool render -
Available on Pointer<
Get whether clipping is enabled on the given render target.SdlRenderer> , provided by the SdlRendererPointerEx extension -
convertEventToCoordinates(
Pointer< renderSdlEvent> event) → bool -
Available on Pointer<
Convert the coordinates in an event to render coordinates.SdlRenderer> , provided by the SdlRendererPointerEx extension -
coordinatesFromWindow(
{required SdlxFPoint windowPosition, required SdlxFPoint renderPosition}) → bool render -
Available on Pointer<
Get a point in render coordinates when given a point in window coordinates.SdlRenderer> , provided by the SdlRendererPointerEx extension -
coordinatesToWindow(
{required SdlxFPoint renderPosition, required SdlxFPoint windowPosition}) → bool render -
Available on Pointer<
Get a point in window coordinates when given a point in render coordinates.SdlRenderer> , provided by the SdlRendererPointerEx extension -
createTexture(
int format, int access, int w, int h) → Pointer< renderSdlTexture> -
Available on Pointer<
Create a texture for a rendering context.SdlRenderer> , provided by the SdlRendererPointerEx extension -
createTextureFromSurface(
Pointer< renderSdlSurface> surface) → Pointer<SdlTexture> -
Available on Pointer<
Create a texture from an existing surface.SdlRenderer> , provided by the SdlRendererPointerEx extension -
createTextureWithProperties(
int props) → Pointer< renderSdlTexture> -
Available on Pointer<
Create a texture for a rendering context with the specified properties.SdlRenderer> , provided by the SdlRendererPointerEx extension -
debugText(
double x, double y, String? str) → bool render -
Available on Pointer<
Draw debug text to an SDL_Renderer.SdlRenderer> , provided by the SdlRendererPointerEx extension -
destroy(
) → bool render -
Available on Pointer<
Destroy the rendering context for a window and free all associated textures.SdlRenderer> , provided by the SdlRendererPointerEx extension -
fillRect(
SdlxFRect? rect) → bool render -
Available on Pointer<
Fill a rectangle on the current rendering target with the drawing color at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension -
fillRects(
List< renderSdlxFRect> rects) → bool -
Available on Pointer<
Fill some number of rectangles on the current rendering target with the drawing color at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension -
flush(
) → bool render -
Available on Pointer<
Force the rendering context to flush any pending commands and state.SdlRenderer> , provided by the SdlRendererPointerEx extension -
geometry(
Pointer< renderSdlTexture> texture, {List<SdlxVertex> ? vertices, List<int> ? indices}) → bool -
Available on Pointer<
Render a list of triangles, optionally using a texture and indices into the vertex array.SdlRenderer> , provided by the SdlRendererPointerEx extension -
geometryRaw(
Pointer< renderSdlTexture> texture, Pointer<Float> xy, int xyStride, Pointer<SdlFColor> color, int colorStride, Pointer<Float> uv, int uvStride, int numVertices, Pointer<NativeType> indices, int numIndices, int sizeIndices) → bool -
Available on Pointer<
Render a list of triangles, optionally using a texture and indices into the vertex arrays.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getClipRect(
SdlxRect rect) → bool render -
Available on Pointer<
Get the clip rectangle for the current target.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getColorScale(
) → double? render -
Available on Pointer<
Get the color scale used for render operations.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getCurrentOutputSize(
SdlxPoint size) → bool render -
Available on Pointer<
Get the current output size in pixels of a rendering context.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getDrawBlendMode(
) → int? render -
Available on Pointer<
Get the blend mode used for drawing operations.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getDrawColor(
SdlxColor color) → bool render -
Available on Pointer<
Get the color used for drawing operations (Rect, Line and Clear).SdlRenderer> , provided by the SdlRendererPointerEx extension -
getDrawColorFloat(
SdlxFColor color) → bool render -
Available on Pointer<
Get the color used for drawing operations (Rect, Line and Clear).SdlRenderer> , provided by the SdlRendererPointerEx extension -
getLogicalPresentation(
SdlxRenderLogicalPresentationInfo info) → bool render -
Available on Pointer<
Get device independent resolution and presentation mode for rendering.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getMetalCommandEncoder(
) → Pointer< renderNativeType> -
Available on Pointer<
Get the Metal command encoder for the current frame.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getMetalLayer(
) → Pointer< renderNativeType> -
Available on Pointer<
Get the CAMetalLayer associated with the given Metal renderer.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getOutputSize(
SdlxPoint size) → bool render -
Available on Pointer<
Get the output size in pixels of a rendering context.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getProperties(
) → int render -
Available on Pointer<
Get the properties associated with a renderer.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getSafeArea(
SdlxRect rect) → bool render -
Available on Pointer<
Get the safe area for rendering within the current viewport.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getScale(
SdlxFPoint scale) → bool render -
Available on Pointer<
Get the drawing scale for the current target.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getTarget(
) → Pointer< renderSdlTexture> -
Available on Pointer<
Get the current render target.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getViewport(
SdlxRect rect) → bool render -
Available on Pointer<
Get the drawing area for the current target.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getVSync(
) → int render -
Available on Pointer<
Get VSync of the given renderer.SdlRenderer> , provided by the SdlRendererPointerEx extension -
getWindow(
) → Pointer< renderSdlWindow> -
Available on Pointer<
Get the window associated with a renderer.SdlRenderer> , provided by the SdlRendererPointerEx extension -
line(
SdlxFPoint p1, SdlxFPoint p2) → bool render -
Available on Pointer<
Draw a line on the current rendering target at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension -
lines(
List< renderSdlxFPoint> points) → bool -
Available on Pointer<
Draw a series of connected lines on the current rendering target at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension -
point(
SdlxFPoint point) → bool render -
Available on Pointer<
Draw a point on the current rendering target at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension -
points(
List< renderSdlxFPoint> points) → bool -
Available on Pointer<
Draw multiple points on the current rendering target at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension -
present(
) → bool render -
Available on Pointer<
Update the screen with any rendering performed since the previous call.SdlRenderer> , provided by the SdlRendererPointerEx extension -
readPixels(
SdlxRect? rect) → Pointer< renderSdlSurface> -
Available on Pointer<
Read pixels from the current rendering target.SdlRenderer> , provided by the SdlRendererPointerEx extension -
rect(
SdlxFRect? rect) → bool render -
Available on Pointer<
Draw a rectangle on the current rendering target at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension -
rects(
List< renderSdlxFRect> rects) → bool -
Available on Pointer<
Draw some number of rectangles on the current rendering target at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension -
setClipRect(
SdlxRect? rect) → bool render -
Available on Pointer<
Set the clip rectangle for rendering on the specified target.SdlRenderer> , provided by the SdlRendererPointerEx extension -
setColorScale(
double scale) → bool render -
Available on Pointer<
Set the color scale used for render operations.SdlRenderer> , provided by the SdlRendererPointerEx extension -
setDrawBlendMode(
int blendMode) → bool render -
Available on Pointer<
Set the blend mode used for drawing operations (Fill and Line).SdlRenderer> , provided by the SdlRendererPointerEx extension -
setDrawColor(
SdlxColor color) → bool render -
Available on Pointer<
Set the color used for drawing operations.SdlRenderer> , provided by the SdlRendererPointerEx extension -
setDrawColorFloat(
SdlxFColor color) → bool render -
Available on Pointer<
Set the color used for drawing operations (Rect, Line and Clear).SdlRenderer> , provided by the SdlRendererPointerEx extension -
setLogicalPresentation(
SdlxRenderLogicalPresentationInfo info) → bool render -
Available on Pointer<
Set a device-independent resolution and presentation mode for rendering.SdlRenderer> , provided by the SdlRendererPointerEx extension -
setScale(
SdlxFPoint scale) → bool render -
Available on Pointer<
Set the drawing scale for rendering on the current target.SdlRenderer> , provided by the SdlRendererPointerEx extension -
setTarget(
Pointer< renderSdlTexture> texture) → bool -
Available on Pointer<
Set a texture as the current rendering target.SdlRenderer> , provided by the SdlRendererPointerEx extension -
setVierport(
SdlxRect? rect) → bool render -
Available on Pointer<
Set the drawing area for rendering on the current target.SdlRenderer> , provided by the SdlRendererPointerEx extension -
setVSync(
int vsync) → bool render -
Available on Pointer<
Toggle VSync of the given renderer.SdlRenderer> , provided by the SdlRendererPointerEx extension -
texture(
Pointer< renderSdlTexture> texture, {SdlxFRect? srcrect, SdlxFRect? dstrect}) → bool -
Available on Pointer<
Copy a portion of the texture to the current rendering target at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension -
texture9Grid(
Pointer< renderSdlRenderer> renderer, Pointer<SdlTexture> texture, {required double leftWidth, required double rightWidth, required double topHeight, required double bottomHeight, SdlxFRect? srcrect, double scale = 1, SdlxFRect? dstrect}) → bool -
Available on Pointer<
Perform a scaled copy using the 9-grid algorithm to the current rendering target at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension -
textureAffine(
Pointer< renderSdlTexture> texture, {SdlxFRect? srcrect, SdlxFPoint? origin, SdlxFPoint? right, SdlxFPoint? down}) → bool -
Available on Pointer<
Copy a portion of the source texture to the current rendering target, with affine transform, at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension -
textureRotated(
Pointer< renderSdlTexture> texture, {SdlxFRect? srcrect, SdlxFRect? dstrect, double angle = 0, SdlxFPoint? center, int flip = SdlkFlip.none}) → bool -
Available on Pointer<
Copy a portion of the source texture to the current rendering target, with rotation and flipping, at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension -
textureTiled(
Pointer< renderSdlTexture> texture, {SdlxFRect? srcrect, double scale = 1, SdlxFRect? dstrect}) → bool -
Available on Pointer<
Tile a portion of the texture to the current rendering target at subpixel precision.SdlRenderer> , provided by the SdlRendererPointerEx extension