openFile static method
Opens up a container for local filesystem storage.
This is provided for development and tools. Portable applications should use SDL_OpenTitleStorage() for access to game data and SDL_OpenUserStorage() for access to user data.
\param path the base path prepended to all storage paths, or NULL for no base path. \returns a filesystem storage container on success or NULL on failure; call SDL_GetError() for more information.
\since This function is available since SDL 3.2.0.
\sa SDL_CloseStorage \sa SDL_GetStorageFileSize \sa SDL_GetStorageSpaceRemaining \sa SDL_OpenTitleStorage \sa SDL_OpenUserStorage \sa SDL_ReadStorageFile \sa SDL_WriteStorageFile
extern SDL_DECLSPEC SDL_Storage * SDLCALL SDL_OpenFileStorage(const char *path)
Implementation
static Pointer<SdlStorage> openFile(String path) => sdlOpenFileStorage(path);