SdlStorageInterface class final storage

Inheritance
Implemented types
Available extensions

Constructors

SdlStorageInterface()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
close Pointer<NativeFunction<SdlIoStreamInterfaceClose>>
getter/setter pair
copy Pointer<NativeFunction<SdlStorageInterfaceCopy>>
getter/setter pair
enumerate Pointer<NativeFunction<SdlStorageInterfaceEnumerate>>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
info Pointer<NativeFunction<SdlStorageInterfaceInfo>>
getter/setter pair
mkdir Pointer<NativeFunction<SdlStorageInterfaceMkdir>>
getter/setter pair
readFile Pointer<NativeFunction<SdlStorageInterfaceReadFile>>
getter/setter pair
ready Pointer<NativeFunction<SdlIoStreamInterfaceClose>>
getter/setter pair
remove Pointer<NativeFunction<SdlStorageInterfaceMkdir>>
getter/setter pair
rename Pointer<NativeFunction<SdlStorageInterfaceCopy>>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spaceRemaining Pointer<NativeFunction<SdlStorageInterfaceSpaceRemaining>>
getter/setter pair
version int
getter/setter pair
writeFile Pointer<NativeFunction<SdlStorageInterfaceReadFile>>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited