SdlStoragePointerEx extension
- on
Methods
-
close(
) → bool storage -
Available on Pointer<
Closes and frees a storage container.SdlStorage> , provided by the SdlStoragePointerEx extension -
copyFile(
String oldpath, String newpath) → bool storage -
Available on Pointer<
Copy a file in a writable storage container.SdlStorage> , provided by the SdlStoragePointerEx extension -
createDirectory(
String path) → bool storage -
Available on Pointer<
Create a directory in a writable storage container.SdlStorage> , provided by the SdlStoragePointerEx extension -
enumerateDirectory(
String path, Pointer< storageNativeFunction< callback, Pointer<SdlEnumerateDirectoryCallback> >Void> userdata) → bool -
Available on Pointer<
Enumerate a directory in a storage container through a callback function.SdlStorage> , provided by the SdlStoragePointerEx extension -
getFileSize(
String path) → int? storage -
Available on Pointer<
Query the size of a file within a storage container.SdlStorage> , provided by the SdlStoragePointerEx extension -
getPathInfo(
String path, SdlxPathInfo info) → bool storage -
Available on Pointer<
Get information about a filesystem path in a storage container.SdlStorage> , provided by the SdlStoragePointerEx extension -
getSpaceRemaining(
) → int storage -
Available on Pointer<
Queries the remaining space in a storage container.SdlStorage> , provided by the SdlStoragePointerEx extension -
globDirectory(
String path, {String? pattern, int flags = 0}) → List< storageString> -
Available on Pointer<
Enumerate a directory tree, filtered by pattern, and return a list.SdlStorage> , provided by the SdlStoragePointerEx extension -
readFile(
String path) → Uint8List? storage -
Available on Pointer<
Synchronously read a file from a storage container into a client-provided buffer.SdlStorage> , provided by the SdlStoragePointerEx extension -
ready(
) → bool storage -
Available on Pointer<
Checks if the storage container is ready to use.SdlStorage> , provided by the SdlStoragePointerEx extension -
removePath(
String path) → bool storage -
Available on Pointer<
Remove a file or an empty directory in a writable storage container.SdlStorage> , provided by the SdlStoragePointerEx extension -
renamePath(
String oldpath, String newpath) → bool storage -
Available on Pointer<
Rename a file or directory in a writable storage container.SdlStorage> , provided by the SdlStoragePointerEx extension -
writeFile(
String path, Uint8List source) → bool storage -
Available on Pointer<
Synchronously write a file from client memory into a storage container.SdlStorage> , provided by the SdlStoragePointerEx extension