ready method
Checks if the storage container is ready to use.
This function should be called in regular intervals until it returns true - however, it is not recommended to spinwait on this call, as the backend may depend on a synchronous message loop. You might instead poll this in your game's main loop while processing events and drawing a loading screen.
\param storage a storage container to query. \returns true if the container is ready, false otherwise.
\since This function is available since SDL 3.2.0.
extern SDL_DECLSPEC bool SDLCALL SDL_StorageReady(SDL_Storage *storage)
Implementation
bool ready() => sdlStorageReady(this);