removePath method
Remove a file or an empty directory in a writable storage container.
\param storage a storage container. \param path the path to remove from the filesystem. \returns true on success or false on failure; call SDL_GetError() for more information.
\since This function is available since SDL 3.2.0.
\sa SDL_StorageReady
extern SDL_DECLSPEC bool SDLCALL SDL_RemoveStoragePath(SDL_Storage *storage, const char *path)
Implementation
bool removePath(String path) => sdlRemoveStoragePath(this, path);