getColorMod method
Get the additional color value multiplied into render copy operations.
\param texture the texture to query. \param r a pointer filled in with the current red color value. \param g a pointer filled in with the current green color value. \param b a pointer filled in with the current blue color value. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function should only be called on the main thread.
\since This function is available since SDL 3.2.0.
\sa SDL_GetTextureAlphaMod \sa SDL_GetTextureColorModFloat \sa SDL_SetTextureColorMod
extern SDL_DECLSPEC bool SDLCALL SDL_GetTextureColorMod(SDL_Texture *texture, Uint8 *r, Uint8 *g, Uint8 *b)
Implementation
bool getColorMod(SdlxColor color) => sdlxGetTextureColorMod(this, color);