getColorModFloat method

bool getColorModFloat(
  1. SdlxFColor color
)

Get the additional color value multiplied into render copy operations.

\param texture the texture to query. \param r a pointer filled in with the current red color value. \param g a pointer filled in with the current green color value. \param b a pointer filled in with the current blue color value. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_GetTextureAlphaModFloat \sa SDL_GetTextureColorMod \sa SDL_SetTextureColorModFloat

extern SDL_DECLSPEC bool SDLCALL SDL_GetTextureColorModFloat(SDL_Texture *texture, float *r, float *g, float *b)

Implementation

bool getColorModFloat(SdlxFColor color) =>
    sdlxGetTextureColorModFloat(this, color);