getChecked method
Gets whether or not an entry is checked.
The entry must have been created with the SDL_TRAYENTRY_CHECKBOX flag.
\param entry the entry to be read. \returns true if the entry is checked; false otherwise.
\threadsafety This function should be called on the thread that created the tray.
\since This function is available since SDL 3.2.0.
\sa SDL_GetTrayEntries \sa SDL_InsertTrayEntryAt \sa SDL_SetTrayEntryChecked
extern SDL_DECLSPEC bool SDLCALL SDL_GetTrayEntryChecked(SDL_TrayEntry *entry)
Implementation
bool getChecked() => sdlGetTrayEntryChecked(this);