setEnabled method
Sets whether or not an entry is enabled.
\param entry the entry to be updated. \param enabled true if the entry should be enabled; false otherwise.
\threadsafety This function should be called on the thread that created the tray.
\since This function is available since SDL 3.2.0.
\sa SDL_GetTrayEntries \sa SDL_InsertTrayEntryAt \sa SDL_GetTrayEntryEnabled
extern SDL_DECLSPEC void SDLCALL SDL_SetTrayEntryEnabled(SDL_TrayEntry *entry, bool enabled)
Implementation
void setEnabled(bool enabled) => sdlSetTrayEntryEnabled(this, enabled);