SdlTrayMenuPointerEx extension
- on
Methods
-
getParentEntry(
) → Pointer< traySdlTrayEntry> -
Available on Pointer<
Gets the entry for which the menu is a submenu, if the current menu is a submenu.SdlTrayMenu> , provided by the SdlTrayMenuPointerEx extension -
getParentTray(
) → Pointer< traySdlTray> -
Available on Pointer<
Gets the tray for which this menu is the first-level menu, if the current menu isn't a submenu.SdlTrayMenu> , provided by the SdlTrayMenuPointerEx extension -
insertEntryAt(
int pos, String? label, int flags) → Pointer< traySdlTrayEntry> -
Available on Pointer<
Insert a tray entry at a given position.SdlTrayMenu> , provided by the SdlTrayMenuPointerEx extension