SdlWindowPointerEx extension
Methods
-
createPopupWindow(
int offsetX, int offsetY, int w, int h, int flags) → Pointer< videoSdlWindow> -
Available on Pointer<
Create a child popup window of the specified parent window.SdlWindow> , provided by the SdlWindowPointerEx extension -
destroy(
) → bool video -
Available on Pointer<
Destroy a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
destroySurface(
) → bool video -
Available on Pointer<
Destroy the surface associated with the window.SdlWindow> , provided by the SdlWindowPointerEx extension -
eglGetSurface(
) → Pointer< videoVoid> -
Available on Pointer<
Get the EGL surface associated with the window.SdlWindow> , provided by the SdlWindowPointerEx extension -
flash(
int operation) → bool video -
Available on Pointer<
Request a window to demand attention from the user.SdlWindow> , provided by the SdlWindowPointerEx extension -
getAspectRatio(
) → ({double maxAspect, double minAspect})? video -
Available on Pointer<
Get the aspect ratio of a window's client area.SdlWindow> , provided by the SdlWindowPointerEx extension -
getBordersSize(
) → ({int bottom, int left, int right, int top})? video -
Available on Pointer<
Get the size of a window's borders (decorations) around the client area.SdlWindow> , provided by the SdlWindowPointerEx extension -
getDisplayFor(
) → int video -
Available on Pointer<
Get the display associated with a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
getDisplayScale(
) → double video -
Available on Pointer<
Get the content display scale relative to a window's pixel size.SdlWindow> , provided by the SdlWindowPointerEx extension -
getFlags(
) → int video -
Available on Pointer<
Get the window flags.SdlWindow> , provided by the SdlWindowPointerEx extension -
getFullscreenMode(
) → SdlxDisplayMode? video -
Available on Pointer<
Query the display mode to use when a window is visible at fullscreen.SdlWindow> , provided by the SdlWindowPointerEx extension -
getIccProfile(
) → ({Pointer< videoVoid> profile, int size})? -
Available on Pointer<
Get the raw ICC profile data for the screen the window is currently on.SdlWindow> , provided by the SdlWindowPointerEx extension -
getId(
) → int video -
Available on Pointer<
Get the numeric ID of a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
getKeyboardGrab(
) → bool video -
Available on Pointer<
Get a window's keyboard grab mode.SdlWindow> , provided by the SdlWindowPointerEx extension -
getMaximumSize(
) → ({int h, int w})? video -
Available on Pointer<
Get the maximum size of a window's client area.SdlWindow> , provided by the SdlWindowPointerEx extension -
getMinimumSize(
) → ({int h, int w})? video -
Available on Pointer<
Get the minimum size of a window's client area.SdlWindow> , provided by the SdlWindowPointerEx extension -
getMouseGrab(
) → bool video -
Available on Pointer<
Get a window's mouse grab mode.SdlWindow> , provided by the SdlWindowPointerEx extension -
getMouseRect(
) → SdlxRect? video -
Available on Pointer<
Get the mouse confinement rectangle of a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
getOpacity(
) → double video -
Available on Pointer<
Get the opacity of a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
getParent(
) → Pointer< videoSdlWindow> -
Available on Pointer<
Get parent of a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
getPixelDensity(
) → double video -
Available on Pointer<
Get the pixel density of a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
getPixelFormat(
) → int video -
Available on Pointer<
Get the pixel format associated with the window.SdlWindow> , provided by the SdlWindowPointerEx extension -
getPosition(
) → ({int x, int y})? video -
Available on Pointer<
Get the position of a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
getProgressState(
) → int video -
Available on Pointer<
Get the state of the progress bar for the given windowâs taskbar icon.SdlWindow> , provided by the SdlWindowPointerEx extension -
getProgressValue(
) → double video -
Available on Pointer<
Get the value of the progress bar for the given windowâs taskbar icon.SdlWindow> , provided by the SdlWindowPointerEx extension -
getProperties(
) → int video -
Available on Pointer<
Get the properties associated with a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
getSafeArea(
) → SdlxRect? video -
Available on Pointer<
Get the safe area for this window.SdlWindow> , provided by the SdlWindowPointerEx extension -
getSize(
) → ({int h, int w})? video -
Available on Pointer<
Get the size of a window's client area.SdlWindow> , provided by the SdlWindowPointerEx extension -
getSizeInPixels(
) → ({int h, int w})? video -
Available on Pointer<
Get the size of a window's client area, in pixels.SdlWindow> , provided by the SdlWindowPointerEx extension -
getSurface(
) → Pointer< videoSdlSurface> -
Available on Pointer<
Get the SDL surface associated with the window.SdlWindow> , provided by the SdlWindowPointerEx extension -
getSurfaceVSync(
) → int? video -
Available on Pointer<
Get VSync for the window surface.SdlWindow> , provided by the SdlWindowPointerEx extension -
getTitle(
) → String? video -
Available on Pointer<
Get the title of a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
glCreateContext(
) → Pointer< videoSdlGlContext> -
Available on Pointer<
Create an OpenGL context for an OpenGL window, and make it current.SdlWindow> , provided by the SdlWindowPointerEx extension -
glMakeCurrent(
Pointer< videoSdlGlContext> context) → bool -
Available on Pointer<
Set up an OpenGL context for rendering into an OpenGL window.SdlWindow> , provided by the SdlWindowPointerEx extension -
glSwap(
) → bool video -
Available on Pointer<
Update a window with OpenGL rendering.SdlWindow> , provided by the SdlWindowPointerEx extension -
hasSurface(
) → bool video -
Available on Pointer<
Return whether the window has a surface associated with it.SdlWindow> , provided by the SdlWindowPointerEx extension -
hide(
) → bool video -
Available on Pointer<
Hide a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
maximize(
) → bool video -
Available on Pointer<
Request that the window be made as large as possible.SdlWindow> , provided by the SdlWindowPointerEx extension -
minimize(
) → bool video -
Available on Pointer<
Request that the window be minimized to an iconic representation.SdlWindow> , provided by the SdlWindowPointerEx extension -
raise(
) → bool video -
Available on Pointer<
Request that a window be raised above other windows and gain the input focus.SdlWindow> , provided by the SdlWindowPointerEx extension -
restore(
) → bool video -
Available on Pointer<
Request that the size and position of a minimized or maximized window be restored.SdlWindow> , provided by the SdlWindowPointerEx extension -
sdlSetWindowFullscreenMode(
SdlxDisplayMode mode) → bool video -
Available on Pointer<
Set the display mode to use when a window is visible and fullscreen.SdlWindow> , provided by the SdlWindowPointerEx extension -
setAlwaysOnTop(
bool onTop) → bool video -
Available on Pointer<
Set the window to always be above the others.SdlWindow> , provided by the SdlWindowPointerEx extension -
setAspectRatio(
double minAspect, double maxAspect) → bool video -
Available on Pointer<
Request that the aspect ratio of a window's client area be set.SdlWindow> , provided by the SdlWindowPointerEx extension -
setBordered(
bool bordered) → bool video -
Available on Pointer<
Set the border state of a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
setFillDocument(
bool fill) → bool video -
Available on Pointer<
Set the window to fill the current document space (Emscripten only).SdlWindow> , provided by the SdlWindowPointerEx extension -
setFocasable(
bool focusable) → bool video -
Available on Pointer<
Set whether the window may have input focus.SdlWindow> , provided by the SdlWindowPointerEx extension -
setFullscreen(
bool fullscreen) → bool video -
Available on Pointer<
Request that the window's fullscreen state be changed.SdlWindow> , provided by the SdlWindowPointerEx extension -
setHitTest(
Pointer< videoNativeFunction< callback, Pointer<SdlHitTest> >Void> callbackData) → bool -
Available on Pointer<
Provide a callback that decides if a window region has special properties.SdlWindow> , provided by the SdlWindowPointerEx extension -
setIcon(
Pointer< videoSdlSurface> icon) → bool -
Available on Pointer<
Set the icon for a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
setKeyboardGrab(
bool grabbed) → bool video -
Available on Pointer<
Set a window's keyboard grab mode.SdlWindow> , provided by the SdlWindowPointerEx extension -
setMaximumSize(
int w, int h) → bool video -
Available on Pointer<
Set the maximum size of a window's client area.SdlWindow> , provided by the SdlWindowPointerEx extension -
setMinimumSize(
int w, int h) → bool video -
Available on Pointer<
Set the minimum size of a window's client area.SdlWindow> , provided by the SdlWindowPointerEx extension -
setModal(
bool modal) → bool video -
Available on Pointer<
Toggle the state of the window as modal.SdlWindow> , provided by the SdlWindowPointerEx extension -
setMouseGrab(
bool grabbed) → bool video -
Available on Pointer<
Set a window's mouse grab mode.SdlWindow> , provided by the SdlWindowPointerEx extension -
setMouseRect(
SdlxRect rect) → bool video -
Available on Pointer<
Confines the cursor to the specified area of a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
setOpacity(
double opacity) → bool video -
Available on Pointer<
Set the opacity for a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
setParent(
Pointer< videoSdlWindow> parent) → bool -
Available on Pointer<
Set the window as a child of a parent window.SdlWindow> , provided by the SdlWindowPointerEx extension -
setPosition(
int x, int y) → bool video -
Available on Pointer<
Request that the window's position be set.SdlWindow> , provided by the SdlWindowPointerEx extension -
setProgressState(
int state) → bool video -
Available on Pointer<
Sets the state of the progress bar for the given windowâs taskbar icon.SdlWindow> , provided by the SdlWindowPointerEx extension -
setProgressValue(
double value) → bool video -
Available on Pointer<
Sets the value of the progress bar for the given windowâs taskbar icon.SdlWindow> , provided by the SdlWindowPointerEx extension -
setResizable(
bool resizable) → bool video -
Available on Pointer<
Set the user-resizable state of a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
setShape(
Pointer< videoSdlSurface> shape) → bool -
Available on Pointer<
Set the shape of a transparent window.SdlWindow> , provided by the SdlWindowPointerEx extension -
setSize(
int w, int h) → bool video -
Available on Pointer<
Request that the size of a window's client area be set.SdlWindow> , provided by the SdlWindowPointerEx extension -
setSurfaceVSync(
int vsync) → bool video -
Available on Pointer<
Toggle VSync for the window surface.SdlWindow> , provided by the SdlWindowPointerEx extension -
setTitle(
String title) → bool video -
Available on Pointer<
Set the title of a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
show(
) → bool video -
Available on Pointer<
Show a window.SdlWindow> , provided by the SdlWindowPointerEx extension -
showSystemMenu(
int x, int y) → bool video -
Available on Pointer<
Display the system-level window menu.SdlWindow> , provided by the SdlWindowPointerEx extension -
sync(
) → bool video -
Available on Pointer<
Block until any pending window state is finalized.SdlWindow> , provided by the SdlWindowPointerEx extension -
updateSurface(
) → bool video -
Available on Pointer<
Copy the window surface to the screen.SdlWindow> , provided by the SdlWindowPointerEx extension -
updateSurfaceRects(
List< videoSdlxRect> rects) → bool -
Available on Pointer<
Copy areas of the window surface to the screen.SdlWindow> , provided by the SdlWindowPointerEx extension