getMaximumSize method

bool getMaximumSize(
  1. SdlxPoint maxSize
)

Get the maximum size of a window's client area.

\param window the window to query. \param w a pointer filled in with the maximum width of the window, may be NULL. \param h a pointer filled in with the maximum height of the window, may be NULL. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_GetWindowMinimumSize \sa SDL_SetWindowMaximumSize

extern SDL_DECLSPEC bool SDLCALL SDL_GetWindowMaximumSize(SDL_Window *window, int *w, int *h)

Implementation

bool getMaximumSize(SdlxPoint maxSize) =>
    sdlxGetWindowMaximumSize(this, maxSize);