getPixelFormat method
Get the pixel format associated with the window.
\param window the window to query. \returns the pixel format of the window on success or SDL_PIXELFORMAT_UNKNOWN on failure; call SDL_GetError() for more information.
\threadsafety This function should only be called on the main thread.
\since This function is available since SDL 3.2.0.
extern SDL_DECLSPEC SDL_PixelFormat SDLCALL SDL_GetWindowPixelFormat(SDL_Window *window)
See also:
Implementation
int getPixelFormat() => sdlGetWindowPixelFormat(this);