SdlWindowPointerFromKeyboardEx extension

on

Methods

clearComposition() bool keyboard

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerFromKeyboardEx extension

Dismiss the composition window/IME without disabling the subsystem.
getTextInputArea() → ({int cursor, SdlxRect rect})? keyboard

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerFromKeyboardEx extension

Get the area used to type Unicode text input.
screenKeyboardShown() bool keyboard

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerFromKeyboardEx extension

Check whether the screen keyboard is shown for given window.
setTextInputArea(SdlxRect rect, int cursor) bool keyboard

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerFromKeyboardEx extension

Set the area used to type Unicode text input.
startTextInput() bool keyboard

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerFromKeyboardEx extension

Start accepting Unicode text input events in a window.
startTextInputWithProperties(int props) bool keyboard

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerFromKeyboardEx extension

Start accepting Unicode text input events in a window, with properties describing the input.
stopTextInput() bool keyboard

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerFromKeyboardEx extension

Stop receiving any text input events in a window.
textInputActive() bool keyboard

Available on Pointer<SdlWindow>, provided by the SdlWindowPointerFromKeyboardEx extension

Check whether or not Unicode text input events are enabled for a window.