SdlWindowPointerFromKeyboardEx extension
Methods
-
clearComposition(
) → bool keyboard -
Available on Pointer<
Dismiss the composition window/IME without disabling the subsystem.SdlWindow> , provided by the SdlWindowPointerFromKeyboardEx extension -
getTextInputArea(
) → ({int cursor, SdlxRect rect})? keyboard -
Available on Pointer<
Get the area used to type Unicode text input.SdlWindow> , provided by the SdlWindowPointerFromKeyboardEx extension -
screenKeyboardShown(
) → bool keyboard -
Available on Pointer<
Check whether the screen keyboard is shown for given window.SdlWindow> , provided by the SdlWindowPointerFromKeyboardEx extension -
setTextInputArea(
SdlxRect rect, int cursor) → bool keyboard -
Available on Pointer<
Set the area used to type Unicode text input.SdlWindow> , provided by the SdlWindowPointerFromKeyboardEx extension -
startTextInput(
) → bool keyboard -
Available on Pointer<
Start accepting Unicode text input events in a window.SdlWindow> , provided by the SdlWindowPointerFromKeyboardEx extension -
startTextInputWithProperties(
int props) → bool keyboard -
Available on Pointer<
Start accepting Unicode text input events in a window, with properties describing the input.SdlWindow> , provided by the SdlWindowPointerFromKeyboardEx extension -
stopTextInput(
) → bool keyboard -
Available on Pointer<
Stop receiving any text input events in a window.SdlWindow> , provided by the SdlWindowPointerFromKeyboardEx extension -
textInputActive(
) → bool keyboard -
Available on Pointer<
Check whether or not Unicode text input events are enabled for a window.SdlWindow> , provided by the SdlWindowPointerFromKeyboardEx extension