SdlxDateTime class
Constructors
Properties
- day ↔ int
-
getter/setter pair
- dayOfWeek ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hour ↔ int
-
getter/setter pair
- minute ↔ int
-
getter/setter pair
- month ↔ int
-
getter/setter pair
- nanosecond ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- second ↔ int
-
getter/setter pair
- utcOffset ↔ int
-
getter/setter pair
- year ↔ int
-
getter/setter pair
Methods
-
calloc(
) → Pointer< SdlDateTime> -
loadFromPointer(
Pointer< SdlDateTime> pointer) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromPointer(
Pointer< SdlDateTime> pointer) → SdlxDateTime