SdlxGpuComputePipelineCreateInfo class
Constructors
-
SdlxGpuComputePipelineCreateInfo({int codeSize = 0, Pointer<
Uint8> ? code, String? entrypoint, int format = 0, int numSamplers = 0, int numReadonlyStorageTextures = 0, int numReadonlyStorageBuffers = 0, int numReadwriteStorageTextures = 0, int numReadwriteStorageBuffers = 0, int numUniformBuffers = 0, int threadcountX = 0, int threadcountY = 0, int threadcountZ = 0, int props = 0})
Properties
-
code
↔ Pointer<
Uint8> -
getter/setter pair
- codeSize ↔ int
-
getter/setter pair
- entrypoint ↔ String
-
getter/setter pair
- format ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- numReadonlyStorageBuffers ↔ int
-
getter/setter pair
- numReadonlyStorageTextures ↔ int
-
getter/setter pair
- numReadwriteStorageBuffers ↔ int
-
getter/setter pair
- numReadwriteStorageTextures ↔ int
-
getter/setter pair
- numSamplers ↔ int
-
getter/setter pair
- numUniformBuffers ↔ int
-
getter/setter pair
- props ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threadcountX ↔ int
-
getter/setter pair
- threadcountY ↔ int
-
getter/setter pair
- threadcountZ ↔ int
-
getter/setter pair
Methods
-
calloc(
) → Pointer< SdlGpuComputePipelineCreateInfo> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited