SdlxGpuMultisampleState class

Constructors

SdlxGpuMultisampleState({int sampleCount = 0, int sampleMask = 0, bool enableMask = false, bool enableAlphaToCoverage = false})

Properties

enableAlphaToCoverage bool
getter/setter pair
enableMask bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleCount int
getter/setter pair
sampleMask int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited