SdlxGpuStorageBufferReadWriteBinding class
Constructors
-
SdlxGpuStorageBufferReadWriteBinding({Pointer<
SdlGpuBuffer> ? buffer, int cycle = 0})
Properties
-
buffer
↔ Pointer<
SdlGpuBuffer> -
getter/setter pair
- cycle ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
calloc(
) → Pointer< SdlGpuStorageBufferReadWriteBinding> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited