SdlxMessageBoxColorScheme class

Constructors

SdlxMessageBoxColorScheme({required SdlxColor background, required SdlxColor text, required SdlxColor buttonBorder, required SdlxColor buttonBackground, required SdlxColor buttonSelected})

Properties

background ↔ SdlxColor
getter/setter pair
buttonBackground ↔ SdlxColor
getter/setter pair
buttonBorder ↔ SdlxColor
getter/setter pair
buttonSelected ↔ SdlxColor
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ SdlxColor
getter/setter pair

Methods

calloc() → Pointer<SdlMessageBoxColorScheme>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited