SdlxTouchFingerEvent class
Constructors
- SdlxTouchFingerEvent({int type = 0, int reserved = 0, int timestamp = 0, int touchId = 0, int fingerId = 0, double x = 0, double y = 0, double dx = 0, double dy = 0, double pressure = 0, int windowId = 0})
- SdlxTouchFingerEvent.canceled({int reserved = 0, int timestamp = 0, int touchId = 0, int fingerId = 0, double x = 0, double y = 0, double dx = 0, double dy = 0, double pressure = 0, int windowId = 0})
-
factory
- SdlxTouchFingerEvent.down({int reserved = 0, int timestamp = 0, int touchId = 0, int fingerId = 0, double x = 0, double y = 0, double dx = 0, double dy = 0, double pressure = 0, int windowId = 0})
-
factory
- SdlxTouchFingerEvent.motion({int reserved = 0, int timestamp = 0, int touchId = 0, int fingerId = 0, double x = 0, double y = 0, double dx = 0, double dy = 0, double pressure = 0, int windowId = 0})
-
factory
- SdlxTouchFingerEvent.up({int reserved = 0, int timestamp = 0, int touchId = 0, int fingerId = 0, double x = 0, double y = 0, double dx = 0, double dy = 0, double pressure = 0, int windowId = 0})
-
factory
Properties
- dx ↔ double
-
getter/setter pair
- dy ↔ double
-
getter/setter pair
- fingerId ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- pressure ↔ double
-
getter/setter pair
- reserved ↔ int
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp ↔ int
-
getter/setter pairinherited
- touchId ↔ int
-
getter/setter pair
- type ↔ int
-
getter/setter pairinherited
- windowId ↔ int
-
getter/setter pair
- x ↔ double
-
getter/setter pair
- y ↔ double
-
getter/setter pair
Methods
-
calloc(
) → Pointer< SdlEvent> -
override
-
isTargetWindow(
int targetId, {bool ifNoWindow = true}) → bool -
override
-
loadFromPointer(
Pointer< SdlEvent> pointer) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromPointer(
Pointer< SdlEvent> pointer) → SdlxTouchFingerEvent -
override