sdlDestroyRwLock function mutex
Destroy a read/write lock created with SDL_CreateRWLock().
This function must be called on any read/write lock that is no longer needed. Failure to destroy a rwlock will result in a system memory or resource leak. While it is safe to destroy a rwlock that is unlocked, it is not safe to attempt to destroy a locked rwlock, and may result in undefined behavior depending on the platform.
\param rwlock the rwlock to destroy.
\threadsafety It is safe to call this function from any thread.
\since This function is available since SDL 3.2.0.
\sa SDL_CreateRWLock
extern SDL_DECLSPEC void SDLCALL SDL_DestroyRWLock(SDL_RWLock *rwlock)
Implementation
void sdlDestroyRwLock(Pointer<SdlRwLock> rwlock) {
final sdlDestroyRwLockLookupFunction = _libSdl
.lookupFunction<
Void Function(Pointer<SdlRwLock> rwlock),
void Function(Pointer<SdlRwLock> rwlock)
>('SDL_DestroyRWLock');
return sdlDestroyRwLockLookupFunction(rwlock);
}