sdlJoystickSensorEnabled function joystick

bool sdlJoystickSensorEnabled(
  1. Pointer<SdlJoystick> joystick,
  2. int type
)

Query whether sensor data reporting is enabled for a joystick.

\param joystick the joystick to query. \param type the type of sensor to query. \returns true if the sensor is enabled, false otherwise.

\threadsafety It is safe to call this function from any thread.

\since This function is available since SDL 3.6.0.

\sa SDL_SetJoystickSensorEnabled

extern SDL_DECLSPEC bool SDLCALL SDL_JoystickSensorEnabled(SDL_Joystick *joystick, SDL_SensorType type)

See also:

Implementation

bool sdlJoystickSensorEnabled(Pointer<SdlJoystick> joystick, int type) {
  final sdlJoystickSensorEnabledLookupFunction = _libSdl
      .lookupFunction<
        Bool Function(Pointer<SdlJoystick> joystick, Int32 type),
        bool Function(Pointer<SdlJoystick> joystick, int type)
      >('SDL_JoystickSensorEnabled');
  return sdlJoystickSensorEnabledLookupFunction(joystick, type);
}