sdlSetGpuRenderStateStorageTextures function render
bool
sdlSetGpuRenderStateStorageTextures(
- Pointer<
SdlGpuRenderState> state, - int numStorageTextures,
- Pointer<
Pointer< storageTexturesSdlGpuTexture> >
Set storage textures variables in a custom GPU render state.
The data is copied and will be binded using SDL_BindGPUFragmentStorageTextures() during draw call execution.
\param state the state to modify. \param num_storage_textures The number of storage textures to bind. \param storage_textures Storage textures to bind. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function should be called on the thread that created the renderer.
\since This function is available since SDL 3.6.0.
extern SDL_DECLSPEC bool SDLCALL SDL_SetGPURenderStateStorageTextures(SDL_GPURenderState *state, int num_storage_textures, SDL_GPUTexture *const *storage_textures)
Implementation
bool sdlSetGpuRenderStateStorageTextures(
Pointer<SdlGpuRenderState> state,
int numStorageTextures,
Pointer<Pointer<SdlGpuTexture>> storageTextures,
) {
final sdlSetGpuRenderStateStorageTexturesLookupFunction = _libSdl
.lookupFunction<
Uint8 Function(
Pointer<SdlGpuRenderState> state,
Int32 numStorageTextures,
Pointer<Pointer<SdlGpuTexture>> storageTextures,
),
int Function(
Pointer<SdlGpuRenderState> state,
int numStorageTextures,
Pointer<Pointer<SdlGpuTexture>> storageTextures,
)
>('SDL_SetGPURenderStateStorageTextures');
return sdlSetGpuRenderStateStorageTexturesLookupFunction(
state,
numStorageTextures,
storageTextures,
) ==
1;
}