sdlxBlitGpuTexture function gpu
Blits from a source texture region to a destination texture region.
This function must not be called inside of any pass.
\param command_buffer a command buffer. \param info the blit info struct containing the blit parameters.
\since This function is available since SDL 3.2.0.
extern SDL_DECLSPEC void SDLCALL SDL_BlitGPUTexture( SDL_GPUCommandBuffer *command_buffer, const SDL_GPUBlitInfo *info)
Implementation
void sdlxBlitGpuTexture(
Pointer<SdlGpuCommandBuffer> commandBuffer,
SdlxGpuBlitInfo info,
) {
final pointer = info.calloc();
sdlBlitGpuTexture(commandBuffer, pointer);
pointer.callocFree();
}