sdlxGetDisplayBounds function video
Get the desktop area represented by a display.
The primary display is often located at (0,0), but may be placed at a different location depending on monitor layout.
\param displayID the instance ID of the display to query. \param rect the SDL_Rect structure filled in with the display bounds. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function should only be called on the main thread.
\since This function is available since SDL 3.2.0.
\sa SDL_GetDisplayUsableBounds \sa SDL_GetDisplays
extern SDL_DECLSPEC bool SDLCALL SDL_GetDisplayBounds(SDL_DisplayID displayID, SDL_Rect *rect)
Implementation
bool sdlxGetDisplayBounds(int displayId, SdlxRect rect) {
final rectPointer = calloc<SdlRect>();
final result = sdlGetDisplayBounds(displayId, rectPointer);
if (result) {
rect.loadFromPointer(rectPointer);
}
rectPointer.callocFree();
return result;
}