sdlxGetPrimarySelectionText function clipboard
Get UTF-8 text from the primary selection.
This function returns an empty string if there is not enough memory left for a copy of the primary selection's content.
\returns the primary selection text on success or an empty string on failure; call SDL_GetError() for more information. This should be freed with SDL_free() when it is no longer needed.
\threadsafety This function should only be called on the main thread.
\since This function is available since SDL 3.2.0.
\sa SDL_HasPrimarySelectionText \sa SDL_SetPrimarySelectionText
extern SDL_DECLSPEC char * SDLCALL SDL_GetPrimarySelectionText(void)
Implementation
String? sdlxGetPrimarySelectionText() {
final result = sdlGetPrimarySelectionText();
if (result == nullptr) {
return null;
}
final text = result.cast<Utf8>().toDartString();
sdlFree(result);
return text;
}