sdlxGetWindowMinimumSize function video

bool sdlxGetWindowMinimumSize(
  1. Pointer<SdlWindow> window,
  2. SdlxPoint minSize
)

Get the minimum size of a window's client area.

\param window the window to query. \param w a pointer filled in with the minimum width of the window, may be NULL. \param h a pointer filled in with the minimum height of the window, may be NULL. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_GetWindowMaximumSize \sa SDL_SetWindowMinimumSize

extern SDL_DECLSPEC bool SDLCALL SDL_GetWindowMinimumSize(SDL_Window *window, int *w, int *h)

Implementation

bool sdlxGetWindowMinimumSize(Pointer<SdlWindow> window, SdlxPoint minSize) {
  var result = false;
  final wPointer = calloc<Int32>();
  final hPointer = calloc<Int32>();
  result = sdlGetWindowMinimumSize(window, wPointer, hPointer);
  if (result) {
    minSize
      ..x = wPointer.value
      ..y = hPointer.value;
  }
  wPointer.callocFree();
  hPointer.callocFree();
  return result;
}