sdlxGetWindowPosition function video

bool sdlxGetWindowPosition(
  1. Pointer<SdlWindow> window,
  2. SdlxPoint position
)

Get the position of a window.

This is the current position of the window as last reported by the windowing system.

If you do not need the value for one of the positions a NULL may be passed in the x or y parameter.

\param window the window to query. \param x a pointer filled in with the x position of the window, may be NULL. \param y a pointer filled in with the y position of the window, may be NULL. \returns true on success or false on failure; call SDL_GetError() for more information.

\threadsafety This function should only be called on the main thread.

\since This function is available since SDL 3.2.0.

\sa SDL_SetWindowPosition

extern SDL_DECLSPEC bool SDLCALL SDL_GetWindowPosition(SDL_Window *window, int *x, int *y)

Implementation

bool sdlxGetWindowPosition(Pointer<SdlWindow> window, SdlxPoint position) {
  var result = false;
  final xPointer = calloc<Int32>();
  final yPointer = calloc<Int32>();
  result = sdlGetWindowPosition(window, xPointer, yPointer);
  position
    ..x = xPointer.value
    ..y = yPointer.value;
  xPointer.callocFree();
  yPointer.callocFree();
  return result;
}