sdl3/sdl_camera library
Classes
Extensions
Functions
-
sdlAcquireCameraFrame(
Pointer< cameraSdlCamera> camera, Pointer<Uint64> timestampNs) → Pointer<SdlSurface> - Acquire a frame.
-
sdlCloseCamera(
Pointer< cameraSdlCamera> camera) → void - Use this function to shut down camera processing and close the camera device.
-
sdlGetCameraDriver(
int index) → String? camera - Use this function to get the name of a built in camera driver.
-
sdlGetCameraFormat(
Pointer< cameraSdlCamera> camera, Pointer<SdlCameraSpec> spec) → bool - Get the spec that a camera is using when generating images.
-
sdlGetCameraId(
Pointer< cameraSdlCamera> camera) → int - Get the instance ID of an opened camera.
-
sdlGetCameraName(
int instanceId) → String? camera - Get the human-readable device name for a camera.
-
sdlGetCameraPermissionState(
Pointer< cameraSdlCamera> camera) → int - Query if camera access has been approved by the user.
-
sdlGetCameraPosition(
int instanceId) → int camera - Get the position of the camera in relation to the system.
-
sdlGetCameraProperties(
Pointer< cameraSdlCamera> camera) → int - Get the properties associated with an opened camera.
-
sdlGetCameras(
Pointer< cameraInt32> count) → Pointer<Uint32> - Get a list of currently connected camera devices.
-
sdlGetCameraSupportedFormats(
int instanceId, Pointer< cameraInt32> count) → Pointer<Pointer< SdlCameraSpec> > - Get the list of native formats/sizes a camera supports.
-
sdlGetCurrentCameraDriver(
) → String? camera - Get the name of the current camera driver.
-
sdlGetNumCameraDrivers(
) → int camera - Use this function to get the number of built-in camera drivers.
-
sdlOpenCamera(
int instanceId, Pointer< cameraSdlCameraSpec> spec) → Pointer<SdlCamera> - Open a video recording device (a "camera").
-
sdlReleaseCameraFrame(
Pointer< cameraSdlCamera> camera, Pointer<SdlSurface> frame) → void - Release a frame of video acquired from a camera.
-
sdlxAcquireCameraFrame(
Pointer< cameraSdlCamera> camera) → ({Pointer<SdlSurface> surface, int timestampNs})? - Acquire a frame.
-
sdlxGetCameraFormat(
Pointer< cameraSdlCamera> camera) → SdlxCameraSpec? - Get the spec that a camera is using when generating images.
-
sdlxGetCameras(
) → List< cameraint> - Get a list of currently connected camera devices.
-
sdlxGetCameraSupportedFormats(
int instanceId) → List< cameraSdlxCameraSpec> - Get the list of native formats/sizes a camera supports.
-
sdlxOpenCamera(
int instanceId, [SdlxCameraSpec? spec]) → Pointer< cameraSdlCamera> - Open a video recording device (a "camera").