SdlxCameraSpec class
Constructors
- SdlxCameraSpec({int format = 0, int colorspace = 0, int width = 0, int height = 0, int framerateNumerator = 0, int framerateDenominator = 0})
-
const
-
SdlxCameraSpec.fromPointer(Pointer<
SdlCameraSpec> pointer) -
factory
Properties
- colorspace → int
-
final
- format → int
-
final
- framerateDenominator → int
-
final
- framerateNumerator → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
final
Methods
-
calloc(
) → Pointer< SdlCameraSpec> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited