releaseBuffer method
Frees the given buffer as soon as it is safe to do so.
You must not reference the buffer after calling this function.
It is safe to pass NULL for buffer, in that case this function is a
no-op.
\param device a GPU context. \param buffer a buffer to be destroyed.
\since This function is available since SDL 3.2.0.
extern SDL_DECLSPEC void SDLCALL SDL_ReleaseGPUBuffer( SDL_GPUDevice *device, SDL_GPUBuffer *buffer)
See also:
Implementation
void releaseBuffer(Pointer<SdlGpuBuffer> buffer) =>
sdlReleaseGpuBuffer(this, buffer);