releaseFence method
Releases a fence obtained from SDL_SubmitGPUCommandBufferAndAcquireFence.
You must not reference the fence after calling this function.
It is safe to pass NULL for fence, in that case this function is a no-op.
\param device a GPU context. \param fence a fence.
\since This function is available since SDL 3.2.0.
\sa SDL_SubmitGPUCommandBufferAndAcquireFence
extern SDL_DECLSPEC void SDLCALL SDL_ReleaseGPUFence( SDL_GPUDevice *device, SDL_GPUFence *fence)
See also:
Implementation
void releaseFence(Pointer<SdlGpuFence> fence) =>
sdlReleaseGpuFence(this, fence);