SdlxGpuBlitRegion class
Constructors
-
SdlxGpuBlitRegion({Pointer<
SdlGpuTexture> ? texture, int mipLevel = 0, int layerOrDepthPlane = 0, int x = 0, int y = 0, int w = 0, int h = 0})
Properties
- h → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layerOrDepthPlane → int
-
final
- mipLevel → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
texture
→ Pointer<
SdlGpuTexture> -
final
- w → int
-
final
- x → int
-
final
- y → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited