SdlxGpuGraphicsPipelineCreateInfo class
Constructors
-
SdlxGpuGraphicsPipelineCreateInfo({Pointer<
SdlGpuShader> ? vertexShader, Pointer<SdlGpuShader> ? fragmentShader, int primitiveType = 0, int props = 0})
Properties
- depthStencilState → SdlxGpuDepthStencilState
-
final
-
fragmentShader
→ Pointer<
SdlGpuShader> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- multisampleState → SdlxGpuMultisampleState
-
final
- primitiveType → int
-
final
- props → int
-
final
- rasterizerState → SdlxGpuRasterizerState
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetInfo → SdlxGpuGraphicsPipelineTargetInfo
-
final
- vertexInputState → SdlxGpuVertexInputState
-
final
-
vertexShader
→ Pointer<
SdlGpuShader> -
final
Methods
-
calloc(
) → Pointer< SdlGpuGraphicsPipelineCreateInfo> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited