SdlxGpuGraphicsPipelineTargetInfo class
Constructors
-
SdlxGpuGraphicsPipelineTargetInfo({List<
SdlxGpuColorTargetDescription> colorTargetDescriptions = const [], int depthStencilFormat = 0, bool hasDepthStencilTarget = false})
Properties
-
colorTargetDescriptions
→ List<
SdlxGpuColorTargetDescription> -
final
- depthStencilFormat → int
-
final
- hasDepthStencilTarget → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited