SdlxGpuShaderCreateInfo class
Constructors
Properties
- code → Uint8List
-
final
- entrypoint → String
-
final
- format → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- numSamplers → int
-
final
- numStorageBuffers → int
-
final
- numStorageTextures → int
-
final
- numUniformBuffers → int
-
final
- props → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stage → int
-
final
Methods
-
calloc(
) → Pointer< SdlGpuShaderCreateInfo> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited