SdlxHapticCustom class
- Inheritance
-
- Object
- SdlxHapticEffect
- SdlxHapticCustom
Constructors
- SdlxHapticCustom({int type = 0, SdlxHapticDirection direction = const SdlxHapticDirection(), int length = 0, int delay = 0, int button = 0, int interval = 0, int channels = 0, int period = 0, int samples = 0, Uint16List? data, int attackLength = 0, int attackLevel = 0, int fadeLength = 0, int fadeLevel = 0})
-
const
-
SdlxHapticCustom.fromPointer(Pointer<
SdlHapticEffect> pointer) -
factory
Properties
- attackLength → int
-
final
- attackLevel → int
-
final
-
final
- channels → int
-
final
- data → Uint16List?
-
final
- delay → int
-
final
- direction → SdlxHapticDirection
-
final
- fadeLength → int
-
final
- fadeLevel → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval → int
-
final
- length → int
-
final
- period → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samples → int
-
final
- type → int
-
finalinherited
Methods
-
calloc(
) → Pointer< SdlHapticEffect> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
[Allocator allocator = ffi.calloc]) → Pointer< SdlHapticEffect> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited