ImgAnimationDecoderEx extension
Static Methods
-
create(
String file) → Pointer< imageImgAnimationDecoder> -
Available on ImgAnimationDecoder, provided by the ImgAnimationDecoderEx extension
Create a decoder to read a series of images from a file. -
createIo(
Pointer< imageSdlIoStream> src, String type, {bool closeio = false}) → Pointer<ImgAnimationDecoder> -
Available on ImgAnimationDecoder, provided by the ImgAnimationDecoderEx extension
Create a decoder to read a series of images from an IOStream. -
createWithProperties(
int props) → Pointer< imageImgAnimationDecoder> -
Available on ImgAnimationDecoder, provided by the ImgAnimationDecoderEx extension
Create an animation decoder with the specified properties.