ImgAnimationEncoderEx extension
Static Methods
-
create(
String file) → Pointer< imageImgAnimationEncoder> -
Available on ImgAnimationEncoder, provided by the ImgAnimationEncoderEx extension
Create an encoder to save a series of images to a file. -
createIo(
Pointer< imageSdlIoStream> dst, String type, {bool closeio = false}) → Pointer<ImgAnimationEncoder> -
Available on ImgAnimationEncoder, provided by the ImgAnimationEncoderEx extension
Create an encoder to save a series of images to an IOStream. -
createWithProperties(
int props) → Pointer< imageImgAnimationEncoder> -
Available on ImgAnimationEncoder, provided by the ImgAnimationEncoderEx extension
Create an animation encoder with the specified properties.