saveTypeIo method
Save an animation to an SDL_IOStream.
If you just want to save to a filename, you can use IMG_SaveAnimation() instead.
If closeio is true, dst will be closed before returning, whether this
function succeeds or not.
For formats that accept a quality, a default quality of 90 will be used.
\param anim the animation to save. \param dst an SDL_IOStream that data will be written to. \param closeio true to close/free the SDL_IOStream before returning, false to leave it open. \param type a filename extension that represent this data ("GIF", etc). \returns true on success or false on failure; call SDL_GetError() for more information.
\since This function is available since SDL_image 3.4.0.
\sa IMG_SaveAnimation \sa IMG_SaveANIAnimation_IO \sa IMG_SaveAPNGAnimation_IO \sa IMG_SaveAVIFAnimation_IO \sa IMG_SaveGIFAnimation_IO \sa IMG_SaveWEBPAnimation_IO
extern SDL_DECLSPEC bool SDLCALL IMG_SaveAnimationTyped_IO(IMG_Animation *anim, SDL_IOStream *dst, bool closeio, const char *type)
Implementation
bool saveTypeIo(
Pointer<SdlIoStream> dst,
String type, {
bool closeio = false,
}) => imgSaveAnimationTypedIo(this, dst, closeio, type);