saveWebpIo method
Save an animation in WEBP format to an SDL_IOStream.
If closeio is true, dst will be closed before returning, whether this
function succeeds or not.
\param anim the animation to save. \param dst an SDL_IOStream from which data will be written to. \param closeio true to close/free the SDL_IOStream before returning, false to leave it open. \param quality between 0 and 100. For lossy, 0 gives the smallest size and 100 the largest. For lossless, this parameter is the amount of effort put into the compression: 0 is the fastest but gives larger files compared to the slowest, but best, 100. \returns true on success or false on failure; call SDL_GetError() for more information.
\since This function is available since SDL_image 3.4.0.
\sa IMG_SaveAnimation \sa IMG_SaveAnimationTyped_IO \sa IMG_SaveANIAnimation_IO \sa IMG_SaveAPNGAnimation_IO \sa IMG_SaveAVIFAnimation_IO \sa IMG_SaveGIFAnimation_IO
extern SDL_DECLSPEC bool SDLCALL IMG_SaveWEBPAnimation_IO(IMG_Animation *anim, SDL_IOStream *dst, bool closeio, int quality)
Implementation
bool saveWebpIo(
Pointer<SdlIoStream> dst,
int quality, {
bool closeio = false,
}) => imgSaveWebpAnimationIo(this, dst, closeio, quality);