sdl3/sdl_init library
Functions
-
sdlGetAppMetadataProperty(
String? name) → String? init - Get metadata about your app.
-
sdlInit(
int flags) → bool init - Initialize the SDL library.
-
sdlInitSubSystem(
int flags) → bool init - Compatibility function to initialize the SDL library.
-
sdlIsMainThread(
) → bool init - Return whether this is the main thread.
-
sdlQuit(
) → void init - Clean up all initialized subsystems.
-
sdlQuitSubSystem(
int flags) → void init - Shut down specific SDL subsystems.
-
sdlRunOnMainThread(
Pointer< initNativeFunction< callback, Pointer<SdlMainThreadCallback> >Void> userdata, bool waitComplete) → bool - Call a function on the main thread during event processing.
-
sdlSetAppMetadata(
String? appname, String? appversion, String? appidentifier) → bool init - Specify basic metadata about your app.
-
sdlSetAppMetadataProperty(
String? name, String? value) → bool init - Specify metadata about your app through a set of properties.
-
sdlWasInit(
int flags) → int init - Get a mask of the specified subsystems which are currently initialized.