sdl3/sdl_mouse
library
Functions
-
sdlCaptureMouse(bool enabled)
→ bool
mouse
-
Capture the mouse and to track input outside an SDL window.
-
sdlCreateAnimatedCursor(Pointer<SdlCursorFrameInfo> frames, int frameCount, int hotX, int hotY)
→ Pointer<SdlCursor>
mouse
-
Create an animated color cursor.
-
sdlCreateColorCursor(Pointer<SdlSurface> surface, int hotX, int hotY)
→ Pointer<SdlCursor>
mouse
-
Create a color cursor.
-
sdlCreateCursor(Pointer<Uint8> data, Pointer<Uint8> mask, int w, int h, int hotX, int hotY)
→ Pointer<SdlCursor>
mouse
-
Create a cursor using the specified bitmap data and mask (in MSB format).
-
sdlCreateSystemCursor(int id)
→ Pointer<SdlCursor>
mouse
-
Create a system cursor.
-
sdlCursorVisible()
→ bool
mouse
-
Return whether the cursor is currently being shown.
-
sdlDestroyCursor(Pointer<SdlCursor> cursor)
→ void
mouse
-
Free a previously-created cursor.
-
sdlGetCursor()
→ Pointer<SdlCursor>
mouse
-
Get the active cursor.
-
sdlGetDefaultCursor()
→ Pointer<SdlCursor>
mouse
-
Get the default cursor.
-
sdlGetGlobalMouseState(Pointer<Float> x, Pointer<Float> y)
→ int
mouse
-
Query the platform for the asynchronous mouse button state and the
desktop-relative platform-cursor position.
-
sdlGetMice(Pointer<Int32> count)
→ Pointer<Uint32>
mouse
-
Get a list of currently connected mice.
-
sdlGetMouseFocus()
→ Pointer<SdlWindow>
mouse
-
Get the window which currently has mouse focus.
-
sdlGetMouseNameForId(int instanceId)
→ String?
mouse
-
Get the name of a mouse.
-
sdlGetMouseState(Pointer<Float> x, Pointer<Float> y)
→ int
mouse
-
Query SDL's cache for the synchronous mouse button state and the
window-relative SDL-cursor position.
-
sdlGetRelativeMouseState(Pointer<Float> x, Pointer<Float> y)
→ int
mouse
-
Query SDL's cache for the synchronous mouse button state and accumulated
mouse delta since last call.
-
sdlGetWindowRelativeMouseMode(Pointer<SdlWindow> window)
→ bool
mouse
-
Query whether relative mouse mode is enabled for a window.
-
sdlHasMouse()
→ bool
mouse
-
Return whether a mouse is currently connected.
-
sdlHideCursor()
→ bool
mouse
-
Hide the cursor.
-
sdlSetCursor(Pointer<SdlCursor> cursor)
→ bool
mouse
-
Set the active cursor.
-
sdlSetRelativeMouseTransform(Pointer<NativeFunction<SdlMouseMotionTransformCallback>> callback, Pointer<Void> userdata)
→ bool
mouse
-
Set a user-defined function by which to transform relative mouse inputs.
-
sdlSetWindowRelativeMouseMode(Pointer<SdlWindow> window, bool enabled)
→ bool
mouse
-
Set relative mouse mode for a window.
-
sdlShowCursor()
→ bool
mouse
-
Show the cursor.
-
sdlWarpMouseGlobal(double x, double y)
→ bool
mouse
-
Move the mouse to the given position in global screen space.
-
sdlWarpMouseInWindow(Pointer<SdlWindow> window, double x, double y)
→ void
mouse
-
Move the mouse cursor to the given position within the window.
-
sdlxCreateAnimatedCursor(List<SdlxCursorFrameInfo> frames, SdlxPoint hot)
→ Pointer<SdlCursor>
mouse
-
Create an animated color cursor.
-
sdlxCreateColorCursor(Pointer<SdlSurface> surface, SdlxPoint hot)
→ Pointer<SdlCursor>
mouse
-
Create a color cursor.
-
sdlxGetGlobalMouseState()
→ ({int button, double x, double y})
mouse
-
Query the platform for the asynchronous mouse button state and the
desktop-relative platform-cursor position.
-
sdlxGetMice()
→ List<int>
mouse
-
Get a list of currently connected mice.
-
sdlxGetMouseState()
→ ({int button, double x, double y})
mouse
-
Query SDL's cache for the synchronous mouse button state and the
window-relative SDL-cursor position.
-
sdlxGetRelativeMouseState()
→ ({int button, double x, double y})
mouse
-
Query SDL's cache for the synchronous mouse button state and accumulated
mouse delta since last call.
-
sdlxWarpMouseGlobal(SdlxFPoint position)
→ bool
mouse
-
Move the mouse to the given position in global screen space.
-
sdlxWarpMouseInWindow(Pointer<SdlWindow> window, SdlxFPoint position)
→ void
mouse
-
Move the mouse cursor to the given position within the window.