NetDatagramSocketPointerEx extension
Methods
-
destroy(
) → void net -
Available on Pointer<
Dispose of a previously-created datagram socket.NetDatagramSocket> , provided by the NetDatagramSocketPointerEx extension -
receive(
{bool refAddress = true}) → NetxDatagram? net -
Available on Pointer<
Receive a new packet that a remote system sent to a datagram socket.NetDatagramSocket> , provided by the NetDatagramSocketPointerEx extension -
send(
Pointer< netNetAddress> address, int port, Uint8List buf) → bool -
Available on Pointer<
Send a new packet over a datagram socket to a remote system.NetDatagramSocket> , provided by the NetDatagramSocketPointerEx extension -
simulatePacketLoss(
int percentLoss) → void net -
Available on Pointer<
Enable simulated datagram socket failures.NetDatagramSocket> , provided by the NetDatagramSocketPointerEx extension