NetxDatagram class
Constructors
-
NetxDatagram({Pointer<
NetAddress> ? addr, int port = 0, Uint8List? buf})
Properties
-
addr
↔ Pointer<
NetAddress> -
getter/setter pair
- buf ↔ Uint8List?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasRefed ↔ bool
-
getter/setter pair
- port ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
destroy(
) → void -
loadFromPointer(
Pointer< NetDatagram> pointer, {bool refAddress = true}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited