SdlxVertex class
Constructors
- SdlxVertex({SdlxFPoint position = const SdlxFPoint(0, 0), SdlxFColor color = const SdlxFColor(0, 0, 0), SdlxFPoint texCoord = const SdlxFPoint(0, 0)})
-
const
Properties
- color → SdlxFColor
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- position → SdlxFPoint
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- texCoord → SdlxFPoint
-
final
Methods
-
calloc(
) → Pointer< SdlVertex> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited