sdl3/sdl_storage
library
Functions
-
sdlCloseStorage(Pointer<SdlStorage> storage)
→ bool
storage
-
Closes and frees a storage container.
-
sdlCopyStorageFile(Pointer<SdlStorage> storage, String? oldpath, String? newpath)
→ bool
storage
-
Copy a file in a writable storage container.
-
sdlCreateStorageDirectory(Pointer<SdlStorage> storage, String? path)
→ bool
storage
-
Create a directory in a writable storage container.
-
sdlEnumerateStorageDirectory(Pointer<SdlStorage> storage, String? path, Pointer<NativeFunction<SdlEnumerateDirectoryCallback>> callback, Pointer<Void> userdata)
→ bool
storage
-
Enumerate a directory in a storage container through a callback function.
-
sdlGetStorageFileSize(Pointer<SdlStorage> storage, String? path, Pointer<Uint64> length)
→ bool
storage
-
Query the size of a file within a storage container.
-
sdlGetStoragePathInfo(Pointer<SdlStorage> storage, String? path, Pointer<SdlPathInfo> info)
→ bool
storage
-
Get information about a filesystem path in a storage container.
-
sdlGetStorageSpaceRemaining(Pointer<SdlStorage> storage)
→ int
storage
-
Queries the remaining space in a storage container.
-
sdlGlobStorageDirectory(Pointer<SdlStorage> storage, String? path, String? pattern, int flags, Pointer<Int32> count)
→ Pointer<Pointer<Int8>>
storage
-
Enumerate a directory tree, filtered by pattern, and return a list.
-
sdlOpenFileStorage(String? path)
→ Pointer<SdlStorage>
storage
-
Opens up a container for local filesystem storage.
-
sdlOpenStorage(Pointer<SdlStorageInterface> iface, Pointer<Void> userdata)
→ Pointer<SdlStorage>
storage
-
Opens up a container using a client-provided storage interface.
-
sdlOpenTitleStorage(String? override, int props)
→ Pointer<SdlStorage>
storage
-
Opens up a read-only container for the application's filesystem.
-
sdlOpenUserStorage(String? org, String? app, int props)
→ Pointer<SdlStorage>
storage
-
Opens up a container for a user's unique read/write filesystem.
-
sdlReadStorageFile(Pointer<SdlStorage> storage, String? path, Pointer<Void> destination, int length)
→ bool
storage
-
Synchronously read a file from a storage container into a client-provided
buffer.
-
sdlRemoveStoragePath(Pointer<SdlStorage> storage, String? path)
→ bool
storage
-
Remove a file or an empty directory in a writable storage container.
-
sdlRenameStoragePath(Pointer<SdlStorage> storage, String? oldpath, String? newpath)
→ bool
storage
-
Rename a file or directory in a writable storage container.
-
sdlStorageReady(Pointer<SdlStorage> storage)
→ bool
storage
-
Checks if the storage container is ready to use.
-
sdlWriteStorageFile(Pointer<SdlStorage> storage, String? path, Pointer<Void> source, int length)
→ bool
storage
-
Synchronously write a file from client memory into a storage container.
-
sdlxGetStorageFileSize(Pointer<SdlStorage> storage, String path)
→ int?
storage
-
Query the size of a file within a storage container.
-
sdlxGetStoragePathInfo(Pointer<SdlStorage> storage, String path)
→ SdlxPathInfo?
storage
-
Get information about a filesystem path in a storage container.
-
sdlxGlobStorageDirectory(Pointer<SdlStorage> storage, String path, {String? pattern, int flags = 0})
→ List<String>
storage
-
Enumerate a directory tree, filtered by pattern, and return a list.
-
sdlxOpenStorage(SdlxStorageInterface iface, Pointer<Void> userdata)
→ Pointer<SdlStorage>
storage
-
Opens up a container using a client-provided storage interface.
-
sdlxReadStorageFile(Pointer<SdlStorage> storage, String path)
→ Uint8List?
storage
-
Synchronously read a file from a storage container into a client-provided
buffer.
-
sdlxWriteStorageFile(Pointer<SdlStorage> storage, String path, Uint8List source)
→ bool
storage
-
Synchronously write a file from client memory into a storage container.