SdlxDateTime class
Constructors
- SdlxDateTime({int year = 0, int month = 0, int day = 0, int hour = 0, int minute = 0, int second = 0, int nanosecond = 0, int dayOfWeek = 0, int utcOffset = 0})
-
const
-
SdlxDateTime.fromPointer(Pointer<
SdlDateTime> pointer) -
factory
Properties
- day → int
-
final
- dayOfWeek → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hour → int
-
final
- minute → int
-
final
- month → int
-
final
- nanosecond → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- second → int
-
final
- utcOffset → int
-
final
- year → int
-
final
Methods
-
calloc(
) → Pointer< SdlDateTime> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited