sdl3/sdl_touch library
Classes
Functions
-
sdlGetTouchDeviceName(
int touchId) → String? touch - Get the touch device name as reported from the driver.
-
sdlGetTouchDevices(
Pointer< touchInt32> count) → Pointer<Uint64> - Get a list of registered touch devices.
-
sdlGetTouchDeviceType(
int touchId) → int touch - Get the type of the given touch device.
-
sdlGetTouchFingers(
int touchId, Pointer< touchInt32> count) → Pointer<Pointer< SdlFinger> > - Get a list of active fingers for a given touch device.
-
sdlxGetTouchDevices(
) → List< touchint> - Get a list of registered touch devices.
-
sdlxGetTouchFingers(
int touchID) → List< touchSdlxFinger> - Get a list of active fingers for a given touch device.