TtfFontPointerEx extension
Methods
-
addFallback(
Pointer< ttfTtfFont> fallback) → bool -
Available on Pointer<
Add a fallback font.TtfFont> , provided by the TtfFontPointerEx extension -
clearFallbacks(
) → void ttf -
Available on Pointer<
Remove all fallback fonts.TtfFont> , provided by the TtfFontPointerEx extension -
close(
) → void ttf -
Available on Pointer<
Dispose of a previously-created font.TtfFont> , provided by the TtfFontPointerEx extension -
copy(
) → Pointer< ttfTtfFont> -
Available on Pointer<
Create a copy of an existing font.TtfFont> , provided by the TtfFontPointerEx extension -
getAscent(
) → int ttf -
Available on Pointer<
Query the offset from the baseline to the top of a font.TtfFont> , provided by the TtfFontPointerEx extension -
getCharSpacing(
) → int ttf -
Available on Pointer<
Get the additional character spacing in pixels to be applied between any two rendered characters.TtfFont> , provided by the TtfFontPointerEx extension -
getDescent(
) → int ttf -
Available on Pointer<
Query the offset from the baseline to the bottom of a font.TtfFont> , provided by the TtfFontPointerEx extension -
getDirection(
) → int ttf -
Available on Pointer<
Get the direction to be used for text shaping by a font.TtfFont> , provided by the TtfFontPointerEx extension -
getDpi(
) → ({int hdpi, int vdpi})? ttf -
Available on Pointer<
Get font target resolutions, in dots per inch.TtfFont> , provided by the TtfFontPointerEx extension -
getFamilyName(
) → String? ttf -
Available on Pointer<
Query a font's family name.TtfFont> , provided by the TtfFontPointerEx extension -
getGeneration(
) → int ttf -
Available on Pointer<
Get the font generation.TtfFont> , provided by the TtfFontPointerEx extension -
getGlyphImage(
int ch) → ({int imageType, Pointer< ttfSdlSurface> surface})? -
Available on Pointer<
Get the pixel image for a UNICODE codepoint.TtfFont> , provided by the TtfFontPointerEx extension -
getGlyphImageForIndex(
int glyphIndex) → ({int imageType, Pointer< ttfSdlSurface> surface})? -
Available on Pointer<
Get the pixel image for a character index.TtfFont> , provided by the TtfFontPointerEx extension -
getGlyphKerning(
int previousCh, int ch) → int? ttf -
Available on Pointer<
Query the kerning size between the glyphs of two UNICODE codepoints.TtfFont> , provided by the TtfFontPointerEx extension -
getGlyphMetrics(
int ch) → ({int advance, int maxx, int maxy, int minx, int miny})? ttf -
Available on Pointer<
Query the metrics (dimensions) of a font's glyph for a UNICODE codepoint.TtfFont> , provided by the TtfFontPointerEx extension -
getHeight(
) → int ttf -
Available on Pointer<
Query the total height of a font.TtfFont> , provided by the TtfFontPointerEx extension -
getHinting(
) → int ttf -
Available on Pointer<
Query a font's current FreeType hinter setting.TtfFont> , provided by the TtfFontPointerEx extension -
getKerning(
) → bool ttf -
Available on Pointer<
Query whether or not kerning is enabled for a font.TtfFont> , provided by the TtfFontPointerEx extension -
getLineSkip(
) → int ttf -
Available on Pointer<
Query the spacing between lines of text for a font.TtfFont> , provided by the TtfFontPointerEx extension -
getNumFaces(
) → int ttf -
Available on Pointer<
Query the number of faces of a font.TtfFont> , provided by the TtfFontPointerEx extension -
getOutline(
) → int ttf -
Available on Pointer<
Query a font's current outline.TtfFont> , provided by the TtfFontPointerEx extension -
getProperties(
) → int ttf -
Available on Pointer<
Get the properties associated with a font.TtfFont> , provided by the TtfFontPointerEx extension -
getScript(
) → int ttf -
Available on Pointer<
Get the script used for text shaping a font.TtfFont> , provided by the TtfFontPointerEx extension -
getSdf(
) → bool ttf -
Available on Pointer<
Query whether Signed Distance Field rendering is enabled for a font.TtfFont> , provided by the TtfFontPointerEx extension -
getSize(
) → double ttf -
Available on Pointer<
Get the size of a font.TtfFont> , provided by the TtfFontPointerEx extension -
getStringSize(
String text) → ({int h, int w})? ttf -
Available on Pointer<
Calculate the dimensions of a rendered string of UTF-8 text.TtfFont> , provided by the TtfFontPointerEx extension -
getStringSizeWrapped(
String text, int wrapWidth) → ({int h, int w})? ttf -
Available on Pointer<
Calculate the dimensions of a rendered string of UTF-8 text.TtfFont> , provided by the TtfFontPointerEx extension -
getStyle(
) → int ttf -
Available on Pointer<
Query a font's current style.TtfFont> , provided by the TtfFontPointerEx extension -
getStyleName(
) → String? ttf -
Available on Pointer<
Query a font's style name.TtfFont> , provided by the TtfFontPointerEx extension -
getWeight(
) → int ttf -
Available on Pointer<
Query a font's weight, in terms of the lightness/heaviness of the strokes.TtfFont> , provided by the TtfFontPointerEx extension -
getWrapAlignment(
) → int ttf -
Available on Pointer<
Query a font's current wrap alignment option.TtfFont> , provided by the TtfFontPointerEx extension -
hasGlyph(
int ch) → bool ttf -
Available on Pointer<
Check whether a glyph is provided by the font for a UNICODE codepoint.TtfFont> , provided by the TtfFontPointerEx extension -
isFixedWidth(
) → bool ttf -
Available on Pointer<
Query whether a font is fixed-width.TtfFont> , provided by the TtfFontPointerEx extension -
isScalable(
) → bool ttf -
Available on Pointer<
Query whether a font is scalable or not.TtfFont> , provided by the TtfFontPointerEx extension -
measureString(
String text, int maxWidth) → ({int measuredLength, int measuredWidth})? ttf -
Available on Pointer<
Calculate how much of a UTF-8 string will fit in a given width.TtfFont> , provided by the TtfFontPointerEx extension -
removeFallback(
Pointer< ttfTtfFont> fallback) → void -
Available on Pointer<
Remove a fallback font.TtfFont> , provided by the TtfFontPointerEx extension -
renderGlyphBlended(
int ch, SdlxColor fg) → Pointer< ttfSdlSurface> -
Available on Pointer<
Render a single UNICODE codepoint at high quality to a new ARGB surface.TtfFont> , provided by the TtfFontPointerEx extension -
renderGlyphLcd(
int ch, SdlxColor fg, SdlxColor bg) → Pointer< ttfSdlSurface> -
Available on Pointer<
Render a single UNICODE codepoint at LCD subpixel quality to a new ARGB surface.TtfFont> , provided by the TtfFontPointerEx extension -
renderGlyphShaded(
int ch, SdlxColor fg, SdlxColor bg) → Pointer< ttfSdlSurface> -
Available on Pointer<
Render a single UNICODE codepoint at high quality to a new 8-bit surface.TtfFont> , provided by the TtfFontPointerEx extension -
renderGlyphSolid(
int ch, SdlxColor fg) → Pointer< ttfSdlSurface> -
Available on Pointer<
Render a single 32-bit glyph at fast quality to a new 8-bit surface.TtfFont> , provided by the TtfFontPointerEx extension -
renderTextBlended(
String text, SdlxColor fg) → Pointer< ttfSdlSurface> -
Available on Pointer<
Render UTF-8 text at high quality to a new ARGB surface.TtfFont> , provided by the TtfFontPointerEx extension -
renderTextBlendedWrapped(
String? text, SdlxColor fg, int wrapLength) → Pointer< ttfSdlSurface> -
Available on Pointer<
Render word-wrapped UTF-8 text at high quality to a new ARGB surface.TtfFont> , provided by the TtfFontPointerEx extension -
renderTextLcd(
String? text, int length, SdlxColor fg, SdlxColor bg) → Pointer< ttfSdlSurface> -
Available on Pointer<
Render UTF-8 text at LCD subpixel quality to a new ARGB surface.TtfFont> , provided by the TtfFontPointerEx extension -
renderTextLcdWrapped(
String? text, int length, SdlxColor fg, SdlxColor bg, int wrapLength) → Pointer< ttfSdlSurface> -
Available on Pointer<
Render word-wrapped UTF-8 text at LCD subpixel quality to a new ARGB surface.TtfFont> , provided by the TtfFontPointerEx extension -
renderTextShaded(
String? text, SdlxColor fg, SdlxColor bg) → Pointer< ttfSdlSurface> -
Available on Pointer<
Render UTF-8 text at high quality to a new 8-bit surface.TtfFont> , provided by the TtfFontPointerEx extension -
renderTextShadedWrapped(
String? text, SdlxColor fg, SdlxColor bg, int wrapLength) → Pointer< ttfSdlSurface> -
Available on Pointer<
Render UTF-8 text at high quality to a new 8-bit surface.TtfFont> , provided by the TtfFontPointerEx extension -
renderTextSolid(
String? text, SdlxColor fg) → Pointer< ttfSdlSurface> -
Available on Pointer<
Render UTF-8 text at fast quality to a new 8-bit surface.TtfFont> , provided by the TtfFontPointerEx extension -
renderTextSolidWrapped(
String? text, SdlxColor fg, int wrapLength) → Pointer< ttfSdlSurface> -
Available on Pointer<
Render word-wrapped UTF-8 text at fast quality to a new 8-bit surface.TtfFont> , provided by the TtfFontPointerEx extension -
setCharSpacing(
int spacing) → bool ttf -
Available on Pointer<
Set additional space in pixels to be applied between any two rendered characters.TtfFont> , provided by the TtfFontPointerEx extension -
setDirection(
int direction) → bool ttf -
Available on Pointer<
Set the direction to be used for text shaping by a font.TtfFont> , provided by the TtfFontPointerEx extension -
setHinting(
int hinting) → void ttf -
Available on Pointer<
Set a font's current hinter setting.TtfFont> , provided by the TtfFontPointerEx extension -
setKerning(
bool allowed) → void ttf -
Available on Pointer<
Set if kerning is enabled for a font.TtfFont> , provided by the TtfFontPointerEx extension -
setLanguage(
String? languageBcp47) → bool ttf -
Available on Pointer<
Set language to be used for text shaping by a font.TtfFont> , provided by the TtfFontPointerEx extension -
setLineSkip(
int lineskip) → void ttf -
Available on Pointer<
Set the spacing between lines of text for a font.TtfFont> , provided by the TtfFontPointerEx extension -
setOutline(
int outline) → bool ttf -
Available on Pointer<
Set a font's current outline.TtfFont> , provided by the TtfFontPointerEx extension -
setScript(
int script) → bool ttf -
Available on Pointer<
Set the script to be used for text shaping by a font.TtfFont> , provided by the TtfFontPointerEx extension -
setSdf(
bool enabled) → bool ttf -
Available on Pointer<
Enable Signed Distance Field rendering for a font.TtfFont> , provided by the TtfFontPointerEx extension -
setSize(
double ptsize) → bool ttf -
Available on Pointer<
Set a font's size dynamically.TtfFont> , provided by the TtfFontPointerEx extension -
setSizeDpi(
double ptsize, int hdpi, int vdpi) → bool ttf -
Available on Pointer<
Set font size dynamically with target resolutions, in dots per inch.TtfFont> , provided by the TtfFontPointerEx extension -
setStyle(
int style) → void ttf -
Available on Pointer<
Set a font's current style.TtfFont> , provided by the TtfFontPointerEx extension -
setWrapAlignment(
int align) → void ttf -
Available on Pointer<
Set a font's current wrap alignment option.TtfFont> , provided by the TtfFontPointerEx extension