removeFallback method
Remove a fallback font.
This updates any TTF_Text objects using this font.
\param font the font to modify. \param fallback the font to remove as a fallback.
\threadsafety This function should be called on the thread that created both fonts.
\since This function is available since SDL_ttf 3.0.0.
\sa TTF_AddFallbackFont \sa TTF_ClearFallbackFonts
extern SDL_DECLSPEC void SDLCALL TTF_RemoveFallbackFont(TTF_Font *font, TTF_Font *fallback)
Implementation
void removeFallback(Pointer<TtfFont> fallback) =>
ttfRemoveFallbackFont(this, fallback);