destroyGpu method
void
destroyGpu()
Destroy a text engine created for drawing text with the SDL GPU API.
All text created by this engine should be destroyed before calling this function.
\param engine a TTF_TextEngine object created with TTF_CreateGPUTextEngine().
\threadsafety This function should be called on the thread that created the engine.
\since This function is available since SDL_ttf 3.0.0.
\sa TTF_CreateGPUTextEngine
extern SDL_DECLSPEC void SDLCALL TTF_DestroyGPUTextEngine(TTF_TextEngine *engine)
Implementation
void destroyGpu() => ttfDestroyGpuTextEngine(this);