destroyRenderer method
void
destroyRenderer()
Destroy a text engine created for drawing text on an SDL renderer.
All text created by this engine should be destroyed before calling this function.
\param engine a TTF_TextEngine object created with TTF_CreateRendererTextEngine().
\threadsafety This function should be called on the thread that created the engine.
\since This function is available since SDL_ttf 3.0.0.
\sa TTF_CreateRendererTextEngine
extern SDL_DECLSPEC void SDLCALL TTF_DestroyRendererTextEngine(TTF_TextEngine *engine)
Implementation
void destroyRenderer() => ttfDestroyRendererTextEngine(this);