setGlWinding method
Sets the winding order of the vertices returned by TTF_GetGLTextDrawData for a particular GL text engine.
\param engine a TTF_TextEngine object created with TTF_CreateGLTextEngine(). \param winding the new winding order option.
\threadsafety This function should be called on the thread that created the engine.
\since This function is available since SDL_ttf 3.3.0.
\sa TTF_GetGLTextEngineWinding
extern SDL_DECLSPEC void SDLCALL TTF_SetGLTextEngineWinding(TTF_TextEngine *engine, TTF_GLTextEngineWinding winding)
Implementation
void setGlWinding(int winding) => ttfSetGlTextEngineWinding(this, winding);