TtfTextPointerEx extension
Methods
-
appendString(
String string) → bool ttf -
Available on Pointer<
Append UTF-8 text to a text object.TtfText> , provided by the TtfTextPointerEx extension -
deleteString(
int offset, int length) → bool ttf -
Available on Pointer<
Delete UTF-8 text from a text object.TtfText> , provided by the TtfTextPointerEx extension -
destroy(
) → void ttf -
Available on Pointer<
Destroy a text object created by a text engine.TtfText> , provided by the TtfTextPointerEx extension -
drawRenderer(
double x, double y) → bool ttf -
Available on Pointer<
Draw text to an SDL renderer.TtfText> , provided by the TtfTextPointerEx extension -
drawSurface(
int x, int y, Pointer< ttfSdlSurface> surface) → bool -
Available on Pointer<
Draw text to an SDL surface.TtfText> , provided by the TtfTextPointerEx extension -
getColor(
) → SdlxColor? ttf -
Available on Pointer<
Get the color of a text object.TtfText> , provided by the TtfTextPointerEx extension -
getColorFloat(
) → SdlxFColor? ttf -
Available on Pointer<
Get the color of a text object.TtfText> , provided by the TtfTextPointerEx extension -
getDirection(
) → int ttf -
Available on Pointer<
Get the direction to be used for text shaping a text object.TtfText> , provided by the TtfTextPointerEx extension -
getEngine(
) → Pointer< ttfTtfTextEngine> -
Available on Pointer<
Get the text engine used by a text object.TtfText> , provided by the TtfTextPointerEx extension -
getFont(
) → Pointer< ttfTtfFont> -
Available on Pointer<
Get the font used by a text object.TtfText> , provided by the TtfTextPointerEx extension -
getGlDrawData(
) → Pointer< ttfTtfGlAtlasDrawSequence> -
Available on Pointer<
Get the geometry data needed for drawing the text.TtfText> , provided by the TtfTextPointerEx extension -
getGpuDrawData(
) → Pointer< ttfTtfGpuAtlasDrawSequence> -
Available on Pointer<
Get the geometry data needed for drawing the text.TtfText> , provided by the TtfTextPointerEx extension -
getNextSubString(
TtfxSubString substring) → TtfxSubString? ttf -
Available on Pointer<
Get the next substring in a text objectTtfText> , provided by the TtfTextPointerEx extension -
getPosition(
) → SdlxPoint? ttf -
Available on Pointer<
Get the position of a text object.TtfText> , provided by the TtfTextPointerEx extension -
getPreviousSubString(
TtfxSubString substring) → TtfxSubString? ttf -
Available on Pointer<
Get the previous substring in a text objectTtfText> , provided by the TtfTextPointerEx extension -
getProperties(
) → int ttf -
Available on Pointer<
Get the properties associated with a text object.TtfText> , provided by the TtfTextPointerEx extension -
getScript(
) → int ttf -
Available on Pointer<
Get the script used for text shaping a text object.TtfText> , provided by the TtfTextPointerEx extension -
getSize(
) → SdlxPoint? ttf -
Available on Pointer<
Get the size of a text object.TtfText> , provided by the TtfTextPointerEx extension -
getSubString(
int offset) → TtfxSubString? ttf -
Available on Pointer<
Get the substring of a text object that surrounds a text offset.TtfText> , provided by the TtfTextPointerEx extension -
getSubStringForLine(
int offset) → TtfxSubString? ttf -
Available on Pointer<
Get the substring of a text object that contains the given line.TtfText> , provided by the TtfTextPointerEx extension -
getSubStringForPoint(
int x, int y) → TtfxSubString? ttf -
Available on Pointer<
Get the portion of a text string that is closest to a point.TtfText> , provided by the TtfTextPointerEx extension -
getSubStringsForRange(
int offset, int length) → List< ttfTtfxSubString> -
Available on Pointer<
Get the substrings of a text object that contain a range of text.TtfText> , provided by the TtfTextPointerEx extension -
getWrapWidth(
) → int? ttf -
Available on Pointer<
Get whether wrapping is enabled on a text object.TtfText> , provided by the TtfTextPointerEx extension -
insertString(
int offset, String string) → bool ttf -
Available on Pointer<
Insert UTF-8 text into a text object.TtfText> , provided by the TtfTextPointerEx extension -
setColor(
SdlxColor color) → bool ttf -
Available on Pointer<
Set the color of a text object.TtfText> , provided by the TtfTextPointerEx extension -
setColorFloat(
SdlxFColor color) → bool ttf -
Available on Pointer<
Set the color of a text object.TtfText> , provided by the TtfTextPointerEx extension -
setDirection(
int direction) → bool ttf -
Available on Pointer<
Set the direction to be used for text shaping a text object.TtfText> , provided by the TtfTextPointerEx extension -
setEngine(
Pointer< ttfTtfTextEngine> engine) → bool -
Available on Pointer<
Set the text engine used by a text object.TtfText> , provided by the TtfTextPointerEx extension -
setFont(
Pointer< ttfTtfFont> font) → bool -
Available on Pointer<
Set the font used by a text object.TtfText> , provided by the TtfTextPointerEx extension -
setPosition(
SdlxPoint position) → bool ttf -
Available on Pointer<
Set the position of a text object.TtfText> , provided by the TtfTextPointerEx extension -
setScript(
int script) → bool ttf -
Available on Pointer<
Set the script to be used for text shaping a text object.TtfText> , provided by the TtfTextPointerEx extension -
setString(
String string) → bool ttf -
Available on Pointer<
Set the UTF-8 text used by a text object.TtfText> , provided by the TtfTextPointerEx extension -
setWrapWidth(
int wrapWidth) → bool ttf -
Available on Pointer<
Set whether wrapping is enabled on a text object.TtfText> , provided by the TtfTextPointerEx extension -
update(
) → bool ttf -
Available on Pointer<
Update the layout of a text object.TtfText> , provided by the TtfTextPointerEx extension -
wrapWhitespaceVisible(
) → bool ttf -
Available on Pointer<
Return whether whitespace is shown when wrapping a text object.TtfText> , provided by the TtfTextPointerEx extension