getPreviousSubString method
Get the previous substring in a text object
If called at the start of the text, this will return a zero length substring with the TTF_SUBSTRING_TEXT_START flag set.
\param text the TTF_Text to query. \param substring the TTF_SubString to query. \param previous a pointer filled in with the previous substring in the text object. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function should be called on the thread that created the text.
\since This function is available since SDL_ttf 3.0.0.
extern SDL_DECLSPEC bool SDLCALL TTF_GetPreviousTextSubString(TTF_Text *text, const TTF_SubString *substring, TTF_SubString *previous)
Implementation
TtfxSubString? getPreviousSubString(TtfxSubString substring) =>
ttfxGetPreviousTextSubString(this, substring);