setEngine method
Set the text engine used by a text object.
This function may cause the internal text representation to be rebuilt.
\param text the TTF_Text to modify. \param engine the text engine to use for drawing. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function should be called on the thread that created the text.
\since This function is available since SDL_ttf 3.0.0.
\sa TTF_GetTextEngine
extern SDL_DECLSPEC bool SDLCALL TTF_SetTextEngine(TTF_Text *text, TTF_TextEngine *engine)
Implementation
bool setEngine(Pointer<TtfTextEngine> engine) =>
ttfSetTextEngine(this, engine);