ttfDestroyGlTextEngine function ttf
Destroy a text engine created for drawing text with OpenGL.
All text created by this engine should be destroyed before calling this function.
\param engine a TTF_TextEngine object created with TTF_CreateGLTextEngine().
\threadsafety This function should be called on the thread that created the engine.
\since This function is available since SDL_ttf 3.3.0.
\sa TTF_CreateGLTextEngine
extern SDL_DECLSPEC void SDLCALL TTF_DestroyGLTextEngine(TTF_TextEngine *engine)
Implementation
void ttfDestroyGlTextEngine(Pointer<TtfTextEngine> engine) {
final ttfDestroyGlTextEngineLookupFunction = _libTtf
.lookupFunction<
Void Function(Pointer<TtfTextEngine> engine),
void Function(Pointer<TtfTextEngine> engine)
>('TTF_DestroyGLTextEngine');
return ttfDestroyGlTextEngineLookupFunction(engine);
}