ttfxGetTextWrapWidth function ttf
Get whether wrapping is enabled on a text object.
\param text the TTF_Text to query. \param wrap_width a pointer filled in with the maximum width in pixels or 0 if the text is being wrapped on newline characters. \returns true on success or false on failure; call SDL_GetError() for more information.
\threadsafety This function should be called on the thread that created the text.
\since This function is available since SDL_ttf 3.0.0.
\sa TTF_SetTextWrapWidth
extern SDL_DECLSPEC bool SDLCALL TTF_GetTextWrapWidth(TTF_Text *text, int *wrap_width)
Implementation
int? ttfxGetTextWrapWidth(Pointer<TtfText> text) {
int? result;
final wrapWidthPointer = ffi.calloc<Int32>();
final bl = ttfGetTextWrapWidth(text, wrapWidthPointer);
if (bl) {
result = wrapWidthPointer.value;
}
wrapWidthPointer.callocFree();
return result;
}